@@ -1,9 +1,9 @@
-<?
+<?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balanceview.php,v 1.19.2.1 2007/08/17 13:14:51 alec Exp $
+ *  $Id: balanceview.php,v 1.23 2009/02/11 11:37:14 alec Exp $
  */
 
 include_once('class.php');
