@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,12 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: strings.php,v 1.5.2.1 2007/08/17 13:14:51 alec Exp $
+ *  $Id: strings.php,v 1.9 2009/01/13 07:45:29 alec Exp $
  */
 
 $_LANG['All payments send on account:'] = 'Wszystkie płatności prosimy przesyłać na konto:';
 $_LANG['Bank:'] = 'Bank:';
-$_LANG['Customer Informations:'] = 'Informacje o kliencie:';
+$_LANG['Customer Information:'] = 'Informacje o kliencie:';
 $_LANG['Customer Logon'] = 'Panel Klienta';
 $_LANG['Customer Logon: $0'] = 'Panel Klienta: $0';
 $_LANG['Errornous data was entered!'] = 'Wprowadzono niepoprawne dane!';
