@@ -1,7 +1,7 @@
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: db.c,v 1.15.2.1 2007/08/17 13:14:53 alec Exp $
+ *  $Id: db.c,v 1.19 2009/01/13 07:45:31 alec Exp $
  */
 
 #include <string.h>
@@ -305,6 +305,19 @@ char *db_escape(ConnHandle *c, const char *str)
     return escstr;
 }
 
+/* Gets last insert id. Returns int. */
+int db_last_insert_id(ConnHandle *c, const char *str)
+{
+    int id = 0;
+    QueryHandle *res = db_query(c, "SELECT LAST_INSERT_ID() AS id");
+
+    if(db_nrows(res))
+        id = atoi(db_get_data(res, 0, "id"));
+    db_free(&res);
+
+    return id;
+}
+
 /* Starts transaction */
 int db_begin(ConnHandle *c)
 {
