@@ -1,7 +1,7 @@
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: db.c,v 1.10.2.1 2007/08/17 13:14:54 alec Exp $
+ *  $Id: db.c,v 1.18 2009/02/02 17:58:09 alec Exp $
  */
 
 #include <string.h>
@@ -229,7 +229,7 @@ QueryHandle * db_pquery(ConnHandle *conn, char *q, ... )
 	    result = (char*) strdup(s);
     } 
     va_end(ap);
-    
+
     // execute prepared query
     query = db_query(conn, result);
     // free temporary vars
@@ -257,7 +257,8 @@ int db_exec(ConnHandle *conn, char *q)
     syslog(LOG_INFO,"DEBUG: [SQL] %s.", stmt);
 #endif
     res = PQexec(conn,stmt);
-    if( res==NULL || PQresultStatus(res)!=PGRES_COMMAND_OK ) {
+    if( res==NULL || (PQresultStatus(res)!=PGRES_COMMAND_OK && PQresultStatus(res)!=PGRES_TUPLES_OK) )
+    {
 	syslog(LOG_ERR,"ERROR: [db_exec] Query failed. %s",PQerrorMessage(conn));
 	PQclear(res);
 	free(stmt);
@@ -315,6 +316,19 @@ char * db_escape(ConnHandle *c, const char *str)
     return escstr;
 }
 
+/* Gets last insert id. Returns int. */
+int db_last_insert_id(ConnHandle *c, const char *str)
+{
+	int id = 0;
+	QueryHandle *res = db_pquery(c, "SELECT currval('?_id_seq') AS id", str);
+
+	if(db_nrows(res))
+                id = atoi(db_get_data(res, 0, "id"));
+	db_free(&res);
+
+	return id;
+}
+
 /* Starts transaction */
 int db_begin(ConnHandle *conn)
 {
