@@ -1,7 +1,7 @@
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -20,7 +20,7 @@
  *  USA.
  */
 
-#define REVISION "$Id: lmsd.c,v 1.33.2.1 2007/08/17 13:14:53 alec Exp $"
+#define REVISION "$Id: lmsd.c,v 1.38 2009/01/13 07:45:30 alec Exp $"
 
 #include <time.h>
 #include <stdlib.h>
@@ -63,7 +63,7 @@ int main(int argc, char *argv[], char **envp)
 	time_t tt;
 	GLOBAL *g;
 	INSTANCE *instances;
-	int fval = 0, i = 0, reload = 0, i_no = 0;
+	int fval = 0, i = 0, reload = 0;
 	char *inst, *instance; 
 #ifdef CONFIGFILE
 	Config *ini;
@@ -102,6 +102,7 @@ int main(int argc, char *argv[], char **envp)
 	g->db_pquery = &db_pquery;
     	g->db_exec = &db_exec;
 	g->db_pexec = &db_pexec;
+	g->db_last_insert_id = &db_last_insert_id;
 	g->db_free = &db_free;
     	g->db_begin = &db_begin;
     	g->db_commit = &db_commit;
@@ -154,7 +155,7 @@ int main(int argc, char *argv[], char **envp)
     	// main loop ****************************************************
     	for(;;)
 	{
-		i_no = 0;
+		int i_no = 0;
 		
 		if( quit ) 
 		{
@@ -212,7 +213,7 @@ int main(int argc, char *argv[], char **envp)
 				if( db_nrows(res) )
 				{
 					char *crontab = db_get_data(res, 0, "crontab");
-					if( crontab_match(tt, crontab) || (!strlen(crontab) && reload) || runall )
+					if( runall || (reload && !strlen(crontab)) || (!quit && crontab_match(tt, crontab)) )
 					{
 						instances = (INSTANCE *) realloc(instances, sizeof(INSTANCE)*(i_no+1));
 						instances[i_no].name = strdup(name);
@@ -232,7 +233,7 @@ int main(int argc, char *argv[], char **envp)
 			for(i=0; i<db_nrows(res); i++)
 			{
 				char *crontab = db_get_data(res, i, "crontab");
-				if( crontab_match(tt, crontab) || (!strlen(crontab) && reload) || runall )
+				if( runall || (reload && !strlen(crontab)) || (!quit && crontab_match(tt, crontab)) )
 				{
 					instances = (INSTANCE *) realloc(instances, sizeof(INSTANCE)*(i_no+1));
 					instances[i_no].name = strdup(db_get_data(res, i, "name"));
@@ -255,7 +256,7 @@ int main(int argc, char *argv[], char **envp)
 				str_replace(&name, "\\s", " ");
 				
 				char *crontab = config_getstring(ini, name, "crontab", "");
-				if( crontab_match(tt, crontab) || (!strlen(crontab) && reload) || runall )
+				if( runall || (reload && !strlen(crontab)) || (!quit && crontab_match(tt, crontab)) )
 				{
 					instances = (INSTANCE *) realloc(instances, sizeof(INSTANCE)*(i_no+1));
 					instances[i_no].name = strdup(name);
@@ -273,7 +274,7 @@ int main(int argc, char *argv[], char **envp)
 			for( instance=strtok(inst," "); instance!=NULL; instance=strtok(NULL, " ") )
 			{
 				char *crontab = config_getstring(ini, instance, "crontab", "");
-				if( crontab_match(tt, crontab) || (!strlen(crontab) && reload) || runall )
+				if( runall || (reload && !strlen(crontab)) || (!quit && crontab_match(tt, crontab)) )
 				{
 					instances = (INSTANCE *) realloc(instances, sizeof(INSTANCE)*(i_no+1));
 					instances[i_no].name = strdup(instance);
@@ -437,7 +438,7 @@ static void parse_command_line(int argc, char **argv)
 		switch(opt) 
 		{
     		case 'v':
-            		printf("LMS Daemon version 1.10.2 Roham (%s)\nCopyright (c) 2001-2007 LMS Developers\n", revision);
+            		printf("LMS Daemon version 1.11.7 Bastet (%s)\nCopyright (c) 2001-2009 LMS Developers\n", revision);
             		exit(0);
     		case 's':
             		ssl = 1;
@@ -474,7 +475,7 @@ static void parse_command_line(int argc, char **argv)
 			command = strdup(optarg);
 			break;
         	default:
-			printf("LMS Daemon version 1.10.2 Roham (%s). Command line options:\n", revision);
+			printf("LMS Daemon version 1.11.7 Bastet (%s). Command line options:\n", revision);
         		printf(" --dbhost -h host[:port]\tdatabase host (default: 'localhost')\n");
         		printf(" --dbname -d db_name\t\tdatabase name (default: 'lms')\n");
         		printf(" --dbuser -u db_user\t\tdatabase user (default: 'lms')\n");
