@@ -1,7 +1,7 @@
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dhcp.c,v 1.31.2.2 2007/11/07 07:58:34 alec Exp $
+ *  $Id: dhcp.c,v 1.37 2009/01/13 07:45:31 alec Exp $
  */
 
 #include <stdio.h>
@@ -150,8 +150,8 @@ void reload(GLOBAL *g, struct dhcp_module *dhcp)
 
 		for(i=0; i<g->db_nrows(res); i++)
 		{
-			char *s, *d, *d2, *e;
-			unsigned long netmask, network;
+			char *s, *d, *d2, *e, *b;
+			unsigned long netmask, network, broadcast;
 			char iface[MAXIFN] = "";
 			
 			e = g->db_get_data(res,i,"address");
@@ -171,7 +171,7 @@ void reload(GLOBAL *g, struct dhcp_module *dhcp)
 			}
 			
 			// shared (interface) network ?
-			sscanf(g->db_get_data(res,i,"interface"), "%[a-zA-Z0-9]", iface);
+			sscanf(g->db_get_data(res,i,"interface"), "%[a-zA-Z0-9.]", iface);
 			
 			if( strlen(lastif) && strlen(iface) && strcmp(iface, lastif)!=0 )
 			{
@@ -184,10 +184,15 @@ void reload(GLOBAL *g, struct dhcp_module *dhcp)
 				strcpy(lastif, iface);
 			}
 
+			// broadcast address
+			broadcast = network | (~netmask);
+			b = inet_ntoa(inet_makeaddr(htonl(broadcast), 0));
+			
 			// start subnet record				
 			s = strdup(dhcp->subnetstart);
 			g->str_replace(&s, "%m", d);
 			g->str_replace(&s, "%a", e);
+			g->str_replace(&s, "%b", b);
 			fprintf(fh, "%s\n", s);
 			free(s); 
 
