@@ -1,7 +1,7 @@
 /*
- * LMS version 1.11-cvs
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: ewx-stm.c,v 1.5.2.3 2007/12/03 11:20:27 alec Exp $
+ *  $Id: ewx-stm.c,v 1.14 2009/01/13 07:45:31 alec Exp $
  */
 
 #include <stdio.h>
@@ -48,6 +48,17 @@ char * itoa(int i)
 	return string;
 }
 
+int find_asterisk(const char *str)
+{
+	int i, len;
+	
+	for(i=0, len = strlen(str); i<len; i++)
+		if(str[i] == '*')
+			return 1;
+	
+	return 0;
+}
+
 void reload(GLOBAL *g, struct ewx_module *ewx)
 {
 	struct snmp_session 	session, *sh=NULL;
@@ -56,19 +67,22 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 	int	pathuplink=0, pathdownlink=0;
 	int 	globaluprate=0, globaldownrate=0; 
 	int	maxupceil=0, maxdownceil=0;
-	int 	status, i, j, k=2, n=2, cc=0, sc=0;
-	int	nc=0, anc=0, mnc=0, inc=0;
-	char 	*errstr;
-	char 	*netnames;
-	char	*netname;
-
+	int 	status, i, j, k, n, o, cc=0, sc=0;
+	int	nc=0, anc=0, mnc=0, inc=0, emnc=0, einc=0;
+	char 	*errstr, *query;
+	char 	*netnames, *netname;
+	char 	*enets, *enetsql;
+	
 	QueryHandle *res;
 	
-        struct customer *customers = (struct customer *) malloc(sizeof(struct customer));
-        struct net *nets = (struct net *) malloc(sizeof(struct net));
-        struct net *all_nets = (struct net *) malloc(sizeof(struct net));
-        struct net *mac_nets = (struct net *) malloc(sizeof(struct net));
-        struct net *ip_nets = (struct net *) malloc(sizeof(struct net));
+        struct customer *customers;
+        struct channel *channels;
+	struct net *nets;
+        struct net *all_nets;
+        struct net *mac_nets;
+        struct net *ip_nets;
+        struct net *emac_nets;
+        struct net *eip_nets;
 
 	if(!ewx->path)
 	{
@@ -157,9 +171,17 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 	snmp_close(sh);
 
 	// If communication works, we can do the job...
+        customers = (struct customer *) malloc(sizeof(struct customer));
+        nets = (struct net *) malloc(sizeof(struct net));
+        all_nets = (struct net *) malloc(sizeof(struct net));
+        mac_nets = (struct net *) malloc(sizeof(struct net));
+        ip_nets = (struct net *) malloc(sizeof(struct net));
+        emac_nets = (struct net *) malloc(sizeof(struct net));
+        eip_nets = (struct net *) malloc(sizeof(struct net));
 
 	// get all networks params
-        res = g->db_pquery(g->conn, "SELECT UPPER(name) AS name, address, INET_ATON(mask) AS mask, interface FROM networks");
+        res = g->db_pquery(g->conn, "SELECT UPPER(name) AS name, address, "
+			"INET_ATON(mask) AS mask, interface FROM networks");
 	
 	for(anc=0; anc<g->db_nrows(res); anc++)
 	{
@@ -169,9 +191,11 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 	        all_nets[anc].mask = inet_addr(g->db_get_data(res, anc, "mask"));
 	}
 	g->db_free(&res);
-																												 
+	
+	n = 2;																							 
 	netnames = strdup(ewx->networks);
 	netname = strdup(netnames);
+	
 	// get networks for filter if any specified in 'networks' option
 	while( n>1 )
 	{
@@ -197,8 +221,21 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 	n = 2;
 	netnames = strdup(ewx->dummy_mac_networks);
 	netname = strdup(netnames);
-	// get networks for filter if any specified in 'dummy_mac_networks' option
-	while( n>1 )
+	
+	// get networks for filter if any specified in 'dummy_mac_networks' 
+	// option, use '*' for all networks
+	if(find_asterisk(ewx->dummy_mac_networks))
+	{
+		for(i=0; i<anc; i++)
+	        {
+			mac_nets = (struct net *) realloc(mac_nets, (sizeof(struct net) * (mnc+1)));
+			mac_nets[mnc].address = all_nets[i].address;
+			mac_nets[mnc].mask = all_nets[i].mask;
+			mac_nets[mnc].name = strdup(all_nets[i].name);
+			mnc++;
+		}
+	}
+	else while( n>1 )
 	{
         	n = sscanf(netnames, "%s %[._a-zA-Z0-9- ]", netname, netnames);
 	        if(strlen(netname))
@@ -222,8 +259,21 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 	n = 2;
 	netnames = strdup(ewx->dummy_ip_networks);
 	netname = strdup(netnames);
-	// get networks for filter if any specified in 'dummy_ip_networks' option
-	while( n>1 )
+	
+	// get networks for filter if any specified in 'dummy_ip_networks'
+	// option, use '*' for all networks
+	if(find_asterisk(ewx->dummy_ip_networks))
+	{
+		for(i=0; i<anc; i++)
+	        {
+			ip_nets = (struct net *) realloc(ip_nets, (sizeof(struct net) * (inc+1)));
+			ip_nets[inc].address = all_nets[i].address;
+			ip_nets[inc].mask = all_nets[i].mask;
+			ip_nets[inc].name = strdup(all_nets[i].name);
+			inc++;
+		}
+	}
+	else while( n>1 )
 	{
         	n = sscanf(netnames, "%s %[._a-zA-Z0-9- ]", netname, netnames);
 	        if(strlen(netname))
@@ -255,17 +305,107 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 	}
 	free(netname); free(netnames);
 
+	n = 2;
+	netnames = strdup(ewx->excluded_dummy_ip_networks);
+	netname = strdup(netnames);
+	
+	// get networks for filter if any specified in 'excluded_dummy_ip_networks'
+	while( n>1 )
+	{
+        	n = sscanf(netnames, "%s %[._a-zA-Z0-9- ]", netname, netnames);
+	        if(strlen(netname))
+		{
+			for(i=0; i<anc; i++)
+	            		if(strcmp(all_nets[i].name, g->str_upc(netname))==0)
+	                    		break;
+		
+			if(i != anc)
+			{
+				eip_nets = (struct net *) realloc(eip_nets, (sizeof(struct net) * (einc+1)));
+				eip_nets[einc].address = all_nets[i].address;
+				eip_nets[einc].mask = all_nets[i].mask;
+				eip_nets[einc].name = strdup(all_nets[i].name);
+				einc++;
+			}
+		}
+	}
+	free(netname); free(netnames);
+
+	n = 2;
+	netnames = strdup(ewx->excluded_dummy_mac_networks);
+	netname = strdup(netnames);
+	
+	// get networks for filter if any specified in 'excluded_dummy_mac_networks'
+	while( n>1 )
+	{
+        	n = sscanf(netnames, "%s %[._a-zA-Z0-9- ]", netname, netnames);
+	        if(strlen(netname))
+		{
+			for(i=0; i<anc; i++)
+	            		if(strcmp(all_nets[i].name, g->str_upc(netname))==0)
+	                    		break;
+		
+			if(i != anc)
+			{
+				emac_nets = (struct net *) realloc(emac_nets, (sizeof(struct net) * (emnc+1)));
+				emac_nets[emnc].address = all_nets[i].address;
+				emac_nets[emnc].mask = all_nets[i].mask;
+				emac_nets[emnc].name = strdup(all_nets[i].name);
+				emnc++;
+			}
+		}
+	}
+	free(netname); free(netnames);
+
+	// excluded networks filter
+	enets = strdup(" AND NOT EXISTS (SELECT 1 FROM networks net "
+			"WHERE (%enets) "
+	                "AND ((n.ipaddr > net.address AND n.ipaddr < broadcast(net.address, inet_aton(net.mask))) "
+			"OR (n.ipaddr_pub > net.address AND n.ipaddr_pub < broadcast(net.address, inet_aton(net.mask)))) "
+			")");
+				
+	netnames = strdup(ewx->excluded_networks);
+	netname = strdup(netnames);
+	enetsql = strdup("");
+	o = 2;
+			
+	while( o>1 )
+	{
+    		o = sscanf(netnames, "%s %[._a-zA-Z0-9- ]", netname, netnames);
+
+		if( strlen(netname) )
+		{
+			enetsql = realloc(enetsql, sizeof(char *) * (strlen(enetsql) + strlen(netname) + 30));
+			if(strlen(enetsql))
+				strcat(enetsql, " OR UPPER(net.name) = UPPER('");
+			else
+				strcat(enetsql, "UPPER(net.name) = UPPER('");
+			
+			strcat(enetsql, netname);
+			strcat(enetsql, "')");
+		}
+	}
+	free(netname); free(netnames);
+	
+	if(strlen(enetsql))
+		g->str_replace(&enets, "%enets", enetsql);
+
 	// get customers with tariffs rates summaries (ie. channels)
-	res = g->db_query(g->conn, 
-			"SELECT a.customerid AS id, SUM(uprate) AS uprate, SUM(upceil) AS upceil, "
+	query = strdup("SELECT a.customerid AS id, SUM(uprate) AS uprate, SUM(upceil) AS upceil, "
 				"SUM(downrate) AS downrate, SUM(downceil) AS downceil "
 			"FROM assignments a "
 			"LEFT JOIN tariffs ON (a.tariffid = tariffs.id) "
 			"WHERE (datefrom <= %NOW% OR datefrom = 0) AND (dateto >= %NOW% OR dateto = 0) "
 				"AND EXISTS (SELECT 1 FROM nodeassignments JOIN nodes n ON (n.id = nodeid) " 
-					"WHERE a.id = assignmentid AND n.access = 1) "
-			"GROUP BY a.customerid");
+					"WHERE a.id = assignmentid AND n.access = 1"
+					"%enets)"
+			"GROUP BY a.customerid"
+	);
 
+	g->str_replace(&query, "%enets", strlen(enetsql) ? enets : "");	
+	
+	res = g->db_query(g->conn, query);
+	
 	for(i=0; i<g->db_nrows(res); i++) 
 	{	
 		int cid = atoi(g->db_get_data(res,i,"id"));
@@ -288,6 +428,7 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 		}
 	}
 	g->db_free(&res);
+	free(query);
 
 	if(!cc)
 	{
@@ -296,8 +437,7 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 	}
 
 	// hosts
-	res = g->db_query(g->conn, 
-		"SELECT t.downrate, t.downceil, t.uprate, t.upceil, n.mac, n.chkmac, "
+	query = strdup("SELECT t.downrate, t.downceil, t.uprate, t.upceil, n.mac, n.chkmac, "
 			"n.id, n.ownerid, INET_NTOA(n.ipaddr) AS ip, n.halfduplex, cn.cnt " 
 		"FROM nodeassignments na "
 		"JOIN assignments a ON (na.assignmentid = a.id)"
@@ -307,15 +447,21 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 		"JOIN ( "
 			"SELECT count(*) AS cnt, assignmentid "
 			"FROM nodeassignments "
-			"LEFT JOIN nodes ON (nodeid = nodes.id) "
-			"WHERE access = 1 "
+			"LEFT JOIN nodes n ON (nodeid = n.id) "
+			"WHERE n.access = 1 "
+//			"%enets "
 			"GROUP BY assignmentid "
 			") cn ON (cn.assignmentid = na.assignmentid) "
 		"WHERE "
 			"(a.datefrom <= %NOW% OR a.datefrom = 0) AND (a.dateto >= %NOW% OR a.dateto = 0) "
-			"AND n.access = 1"
+			"AND n.access = 1 "
+			"%enets"
 	);
 
+	g->str_replace(&query, "%enets", strlen(enetsql) ? enets : "");	
+
+	res = g->db_query(g->conn,  query);
+
 	// adding hosts to customers array
 	for(i=0; i<g->db_nrows(res); i++)
         {
@@ -366,8 +512,17 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 
 				if(n != mnc) dummy_mac = 1;
 			}
+
+			if(dummy_mac && emnc)
+			{	
+				for(n=0; n<emnc; n++)
+	            			if(emac_nets[n].address == (inet & emac_nets[n].mask))
+						break;
+
+				if(n != emnc) dummy_mac = 0;
+			}
 			
-			if(!atoi(g->db_get_data(res,i,"chkmac")))
+			if(!dummy_mac && !atoi(g->db_get_data(res,i,"chkmac")))
 			{
 				dummy_mac = 1;
 			}
@@ -382,6 +537,15 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 				if(n != inc) dummy_ip = 1;
 			}
 
+			if(dummy_ip && einc && !dummy_mac)
+			{	
+				for(n=0; n<einc; n++)
+	            			if(eip_nets[n].address == (inet & eip_nets[n].mask))
+	                    			break;
+		
+				if(n != einc) dummy_ip = 0;
+			}
+
 			customers[j].hosts = (struct host *) realloc(customers[j].hosts, (sizeof(struct host) * (k+1)));
 			customers[j].hosts[k].id = hostid;
 			customers[j].hosts[k].uprate = uprate;
@@ -424,7 +588,8 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 		maxdownceil = maxdownceil < customers[j].downceil ? customers[j].downceil : maxdownceil;
 	}
 	g->db_free(&res);
-
+	free(query);
+	
 	// path limits checking
 	if(globaluprate>pathuplink || globaldownrate>pathdownlink)
 	{
@@ -439,14 +604,20 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 
 	// Reading hosts/channels definitions from ewx_stm_* tables
 	// NOTE: to re-create device configuration do DELETE FROM ewx_stm_nodes; DELETE FROM ewx_stm_channels;
-	res = g->db_query(g->conn, "SELECT nodeid, mac, INET_NTOA(ipaddr) AS ip, channelid, halfduplex, "
-					    "n.uprate, n.upceil, n.downrate, n.downceil, customerid, "
-					    "c.upceil AS cupceil, c.downceil AS cdownceil "
-				    "FROM ewx_stm_nodes n "
-				    "LEFT JOIN ewx_stm_channels c ON (c.id = n.channelid) "
-				    );
+	query = strdup("SELECT nodeid, mac, INET_NTOA(ipaddr) AS ip, channelid, halfduplex, "
+				"n.uprate, n.upceil, n.downrate, n.downceil, customerid, "
+				"c.upceil AS cupceil, c.downceil AS cdownceil "
+			"FROM ewx_stm_nodes n "
+			"LEFT JOIN ewx_stm_channels c ON (c.id = n.channelid) "
+//			"WHERE 1=1"
+//			"%enets"
+	);
 
-        struct channel *channels = (struct channel *) malloc(sizeof(struct channel));
+//	g->str_replace(&query, "%enets", strlen(enetsql) ? enets : "");	
+
+	res = g->db_query(g->conn, query);
+        
+	channels = (struct channel *) malloc(sizeof(struct channel));
 
 	// Creating current config array
 	for(i=0; i<g->db_nrows(res); i++)
@@ -500,7 +671,8 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 		channels[j].no++;
 	}
 	g->db_free(&res);
-
+	free(query);
+	
 	// Open the session again
 	sh = snmp_open(&session);
 
@@ -686,6 +858,10 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 
 	snmp_close(sh);
 
+#ifdef DEBUG1
+	syslog(LOG_INFO, "DEBUG: [%s/ewx-stm] reloaded", ewx->base.instance);
+#endif
+
         for(i=0; i<sc; i++)
 	{
 		for(j=0; j<channels[i].no; j++)
@@ -695,6 +871,8 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 		}
 	        free(channels[i].hosts);
 	}
+        free(channels);
+
         for(i=0; i<cc; i++)
 	{
 		for(j=0; j<customers[i].no; j++)
@@ -704,8 +882,6 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 		}
 	        free(customers[i].hosts);
 	}
-
-        free(channels);
         free(customers);
 
 	for(i=0;i<nc;i++)
@@ -731,15 +907,29 @@ void reload(GLOBAL *g, struct ewx_module *ewx)
 		free(ip_nets[i].name);
 	}
 	free(ip_nets);
+
+	for(i=0;i<emnc;i++)
+        {
+		free(emac_nets[i].name);
+	}
+	free(emac_nets);
+
+	for(i=0;i<einc;i++)
+        {
+		free(eip_nets[i].name);
+	}
+	free(eip_nets);
 		
-#ifdef DEBUG1
-	syslog(LOG_INFO, "DEBUG: [%s/ewx-stm] reloaded", ewx->base.instance);
-#endif
+	free(enets);
+	free(enetsql);
 	free(ewx->community);
 	free(ewx->host);
 	free(ewx->networks);
 	free(ewx->dummy_mac_networks);
 	free(ewx->dummy_ip_networks);
+	free(ewx->excluded_networks);
+	free(ewx->excluded_dummy_mac_networks);
+	free(ewx->excluded_dummy_ip_networks);
 }
 
 struct ewx_module * init(GLOBAL *g, MODULE *m)
@@ -759,8 +949,11 @@ struct ewx_module * init(GLOBAL *g, MODULE *m)
 	ewx->host = strdup(g->config_getstring(ewx->base.ini, ewx->base.instance, "snmp_host", ""));
 	ewx->port = g->config_getint(ewx->base.ini, ewx->base.instance, "snmp_port", 161);
 	ewx->networks = strdup(g->config_getstring(ewx->base.ini, ewx->base.instance, "networks", ""));
+	ewx->excluded_networks = strdup(g->config_getstring(ewx->base.ini, ewx->base.instance, "excluded_networks", ""));
 	ewx->dummy_mac_networks = strdup(g->config_getstring(ewx->base.ini, ewx->base.instance, "dummy_mac_networks", ""));
 	ewx->dummy_ip_networks = strdup(g->config_getstring(ewx->base.ini, ewx->base.instance, "dummy_ip_networks", ""));
+	ewx->excluded_dummy_mac_networks = strdup(g->config_getstring(ewx->base.ini, ewx->base.instance, "excluded_dummy_mac_networks", ""));
+	ewx->excluded_dummy_ip_networks = strdup(g->config_getstring(ewx->base.ini, ewx->base.instance, "excluded_dummy_ip_networks", ""));
 
 	// node/channel ID's offset, e.g. for testing
 	ewx->offset = g->config_getint(ewx->base.ini, ewx->base.instance, "offset", 0);
