@@ -1,7 +1,7 @@
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: pinger.c,v 1.15.2.1 2007/08/17 13:14:57 alec Exp $
+ *  $Id: pinger.c,v 1.20 2009/01/13 07:45:32 alec Exp $
  */
 
 #include <string.h>
@@ -280,6 +280,7 @@ void reload(GLOBAL *g, struct pinger_module *p)
 {
 	QueryHandle *res;
 	int i, j, nc=0, n=2;
+	char *hoststr;
 
 	struct net *nets = (struct net *) malloc(sizeof(struct net));
 	char *netnames = strdup(p->networks);	
@@ -363,9 +364,29 @@ void reload(GLOBAL *g, struct pinger_module *p)
 		default:
 			signal(SIGINT, sig_int);
 			recv_arp_reply();
+
+			hoststr = strdup("0");
+			j = 0;
+
 			for(i=0; i<nh; i++) 
-				if(hosts[i].active) 
-					g->db_pexec(g->conn, "UPDATE nodes SET lastonline=%NOW% WHERE id=?", hosts[i].id);
+				if(hosts[i].active)
+				{ 
+					hoststr = realloc(hoststr, sizeof(char *) * (strlen(hoststr) + strlen(hosts[i].id) + 1));
+	                    		strcat(hoststr, ",");
+					strcat(hoststr, hosts[i].id);
+					j++;
+				}	
+			
+			if(j)
+			{
+				if(p->use_secure_function)
+					// works with postgres only
+					g->db_pexec(g->conn, "SELECT set_lastonline(ARRAY[?])", hoststr);
+				else
+					g->db_pexec(g->conn, "UPDATE nodes SET lastonline=%NOW% WHERE id IN (?)", hoststr);
+			}
+			
+			free(hoststr);
 		break;
 	}
 
@@ -394,6 +415,12 @@ struct pinger_module * init(GLOBAL *g, MODULE *m)
 	p->base.reload = (void (*)(GLOBAL *, MODULE *)) &reload;
 	
 	p->networks = strdup(g->config_getstring(p->base.ini, p->base.instance, "networks", ""));
+	// on PostgreSQL we can use "security definer" function:
+	// CREATE OR REPLACE FUNCTION set_lastonline(int[]) RETURNS void AS $$
+	// UPDATE nodes SET lastonline = EXTRACT(EPOCH FROM CURRENT_TIMESTAMP(0))
+	// WHERE id = ANY($1);
+	// $$ LANGUAGE SQL SECURITY DEFINER;
+	p->use_secure_function = g->config_getbool(p->base.ini, p->base.instance, "use_secure_function", 0);
 	
 #ifdef DEBUG1
 	syslog(LOG_INFO,"DEBUG: [%s/pinger] initialized", p->base.instance);
