@@ -1,7 +1,7 @@
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tc.c,v 1.36.2.1 2007/08/17 13:14:57 alec Exp $
+ *  $Id: tc.c,v 1.41 2009/01/13 07:45:32 alec Exp $
  */
 
 #include <stdio.h>
@@ -202,14 +202,19 @@ void reload(GLOBAL *g, struct tc_module *tc)
 						int h_climit = (int) n_climit/nres->nrows;
 						
 						unsigned long iplong = inet_addr(ipaddr);
-						// IP's last octet in hex
-						char *i16 = itoha((ntohl(iplong) & 0xff));
+						unsigned int hostip = ntohl(iplong);
+						
+						char *o1 = strdup(itoa((hostip >> 24) & 0xff)); // 1st octet
+						char *o2 = strdup(itoa((hostip >> 16) & 0xff)); // 2nd octet
+						char *o3 = strdup(itoa((hostip >> 8) & 0xff)); // 3rd octet
+						char *o4 = strdup(itoa(hostip & 0xff)); // 4th octet
+						char *i16 = strdup(itoha(hostip & 0xff)); // 4th octet in hex
 
 						// test node's membership in networks
 						for(v=0; v<nc; v++)
 							if(nets[v].address == (iplong & nets[v].mask)) 
 								break;
-																	
+															
 						if(v!=nc)
 						{
 							got_node = 1;
@@ -221,6 +226,10 @@ void reload(GLOBAL *g, struct tc_module *tc)
 								g->str_replace(&mark_up, "%i16", i16);
 								g->str_replace(&mark_up, "%i", ipaddr);
 								g->str_replace(&mark_up, "%m", mac);
+								g->str_replace(&mark_up, "%o1", o1);
+								g->str_replace(&mark_up, "%o2", o2);
+								g->str_replace(&mark_up, "%o3", o3);
+								g->str_replace(&mark_up, "%o4", o4);
 								g->str_replace(&mark_up, "%x", itoa(x));
 								fprintf(fh, "%s", mark_up);
 								
@@ -229,6 +238,10 @@ void reload(GLOBAL *g, struct tc_module *tc)
 								g->str_replace(&mark_down, "%i16", i16);
 								g->str_replace(&mark_down, "%i", ipaddr);
 								g->str_replace(&mark_down, "%m", mac);
+								g->str_replace(&mark_down, "%o1", o1);
+								g->str_replace(&mark_down, "%o2", o2);
+								g->str_replace(&mark_down, "%o3", o3);
+								g->str_replace(&mark_down, "%o4", o4);
 								g->str_replace(&mark_down, "%x", itoa(x));
 								fprintf(fh, "%s", mark_down);
 					
@@ -264,29 +277,73 @@ void reload(GLOBAL *g, struct tc_module *tc)
 								}
 							}
 							
-							if(h_climit)
+							if(!tc->limit_per_host)
 							{
+							    if(h_climit)
+							    {
 								g->str_replace(&cl, "%climit", itoa(h_climit));
 								g->str_replace(&cl, "%n", name);
 								g->str_replace(&cl, "%if", nets[v].interface);
     								g->str_replace(&cl, "%i16", i16);
 								g->str_replace(&cl, "%i", ipaddr);
 								g->str_replace(&cl, "%m", mac);
+								g->str_replace(&cl, "%o1", o1);
+								g->str_replace(&cl, "%o2", o2);
+								g->str_replace(&cl, "%o3", o3);
+								g->str_replace(&cl, "%o4", o4);
 								g->str_replace(&cl, "%x", itoa(x));
 								fprintf(fh, "%s", cl);
-							}
+							    }
 							
-							if(h_plimit)
-							{
+							    if(h_plimit)
+							    {
 								g->str_replace(&pl, "%plimit", itoa(h_plimit));
 								g->str_replace(&pl, "%n", name);
 								g->str_replace(&pl, "%if", nets[v].interface);
 								g->str_replace(&pl, "%i16", i16);
 								g->str_replace(&pl, "%i", ipaddr);
 								g->str_replace(&pl, "%m", mac);
+								g->str_replace(&pl, "%o1", o1);
+								g->str_replace(&pl, "%o2", o2);
+								g->str_replace(&pl, "%o3", o3);
+								g->str_replace(&pl, "%o4", o4);
 								g->str_replace(&pl, "%x", itoa(x));
 								fprintf(fh, "%s", pl);
-							}	
+							    }
+							} else
+							{
+							    if(n_climit)
+							    {
+								g->str_replace(&cl, "%climit", itoa(n_climit));
+								g->str_replace(&cl, "%n", name);
+								g->str_replace(&cl, "%if", nets[v].interface);
+    								g->str_replace(&cl, "%i16", i16);
+								g->str_replace(&cl, "%i", ipaddr);
+								g->str_replace(&cl, "%m", mac);
+								g->str_replace(&cl, "%o1", o1);
+								g->str_replace(&cl, "%o2", o2);
+								g->str_replace(&cl, "%o3", o3);
+								g->str_replace(&cl, "%o4", o4);
+								g->str_replace(&cl, "%x", itoa(x));
+								fprintf(fh, "%s", cl);
+							    }
+							
+							    if(n_plimit)
+							    {
+								g->str_replace(&pl, "%plimit", itoa(n_plimit));
+								g->str_replace(&pl, "%n", name);
+								g->str_replace(&pl, "%if", nets[v].interface);
+								g->str_replace(&pl, "%i16", i16);
+								g->str_replace(&pl, "%i", ipaddr);
+								g->str_replace(&pl, "%m", mac);
+								g->str_replace(&pl, "%o1", o1);
+								g->str_replace(&pl, "%o2", o2);
+								g->str_replace(&pl, "%o3", o3);
+								g->str_replace(&pl, "%o4", o4);
+								g->str_replace(&pl, "%x", itoa(x));
+								fprintf(fh, "%s", pl);
+							    }
+							}
 					
 							if(tc->one_class_per_host) x++;
 						}
@@ -318,6 +375,7 @@ void reload(GLOBAL *g, struct tc_module *tc)
 						free(cl); free(pl); 
 						free(mark_up); free(mark_down);
 						free(htb_up); free(htb_down);
+						free(o1); free(o2); free(o3); free(o4); free(i16);
 					}
 					g->db_free(&nres);
 				}
@@ -490,6 +548,7 @@ $IPT -t filter -I FORWARD -p tcp -s %i -m limit --limit %plimit/s -m ipp2p --ipp
 	tc->networks = strdup(g->config_getstring(tc->base.ini, tc->base.instance, "networks", ""));
 	tc->customergroups = strdup(g->config_getstring(tc->base.ini, tc->base.instance, "customergroups", ""));
 	tc->one_class_per_host = g->config_getbool(tc->base.ini, tc->base.instance, "one_class_per_host", 0);
+	tc->limit_per_host = g->config_getbool(tc->base.ini, tc->base.instance, "limit_per_host", 0);
 #ifdef DEBUG1
 	syslog(LOG_INFO, "DEBUG: [%s/tc] initialized", tc->base.instance);
 #endif
