@@ -3,6 +3,8 @@ struct traffic_module
 {
 	MODULE base;
 	char *file;
+	char *begin_command;
+	char *end_command;
 };
 
 typedef struct
