@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Auth.class.php,v 1.19.2.1 2007/08/17 13:15:10 alec Exp $
+ *  $Id: Auth.class.php,v 1.23 2009/01/13 07:45:33 alec Exp $
  */
 
 class Auth {
@@ -37,8 +37,8 @@ class Auth {
 	var $ip;
 	var $lastip;
 	var $error;
-	var $_version = '1.10.2 Roham';
-	var $_revision = '$Revision: 1.19.2.1 $';
+	var $_version = '1.11.7 Bastet';
+	var $_revision = '$Revision: 1.23 $';
 	var $DB = NULL;
 	var $SESSION = NULL;
 
@@ -72,7 +72,6 @@ class Auth {
 		{
 			$this->login = $loginform['login'];
 			$this->passwd = $loginform['pwd'];
-			$this->SESSION->save('session_timestamp', time());
 			writesyslog('Login attempt by '.$this->login, LOG_INFO);
 		}
 		elseif($this->DB->GetOne('SELECT COUNT(id) FROM users') == 0)
