@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB.php,v 1.14.2.1 2007/08/17 13:15:11 alec Exp $
+ *  $Id: LMSDB.php,v 1.18 2009/01/13 07:45:34 alec Exp $
  */
 
 /*
@@ -37,15 +37,19 @@ require_once(LMSDB_DIR.'/LMSDB_common.class.php');
 
 function DBInit($dbtype,$dbhost,$dbuser,$dbpasswd,$dbname)
 {
-	if(! file_exists(LMSDB_DIR.'/LMSDB_driver_'.strtolower($dbtype).'.class.php') )
-		trigger_error('Unable to load driver for "'.$dbtype.'" database!');
+	if(!file_exists(LMSDB_DIR.'/LMSDB_driver_'.strtolower($dbtype).'.class.php') )
+		trigger_error('Unable to load driver for "'.$dbtype.'" database!', E_USER_WARNING);
 	else
 	{
 		require_once(LMSDB_DIR.'/LMSDB_driver_'.strtolower($dbtype).'.class.php');
 		$drvname = 'LMSDB_driver_'.strtolower($dbtype);
 		$DB =& new $drvname($dbhost,$dbuser,$dbpasswd,$dbname);
-		if(! $DB->_loaded)
-			trigger_error('Failed to load driver for "'.$dbtype.'" database: driver doesn\'t seems to be loaded.');
+		
+		if(!$DB->_loaded)
+			trigger_error('Failed to load driver for "'
+				.$dbtype.'" database: driver doesn\'t seems to be loaded.', E_USER_WARNING);
+		elseif(!$DB->_dblink)
+			trigger_error('Unable to connect to database!', E_USER_WARNING);
 		else
 			return $DB;
 	}
