@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,25 +21,25 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_common.class.php,v 1.42.2.1 2007/08/17 13:15:11 alec Exp $
+ *  $Id: LMSDB_common.class.php,v 1.47 2009/02/09 19:22:31 alec Exp $
  */
 
 /*
- * LMSDB - klasa wsplna.
+ * LMSDB - klasa wspólna.
  */
 
 Class LMSDB_common
 {
-	var $_version = '1.10.2 Roham';
-	var $_revision = '$Revision: 1.42.2.1 $';
+	var $_version = '1.11.7 Bastet';
+	var $_revision = '$Revision: 1.47 $';
 	
-	// Driver powinien nadpisa t zmienn wartoci TRUE, eby
-	// funkcja inicjujca baze danych wiedziaa e driver si poprawnie
-	// zaadowa
+	// Driver powinien nadpisać tą zmienną wartością TRUE, żeby
+	// funkcja inicjująca baze danych wiedziała że driver się poprawnie
+	// załadował
 	
 	var $_loaded = FALSE;
 
-	// Wewntrzne zmienne bazy danych, tj, resource, link, itp.
+	// Wewnętrzne zmienne bazy danych, tj, resource, link, itp.
 
 	var $_dbtype = 'NONE';
 	var $_dblink = NULL;
@@ -55,7 +55,7 @@ Class LMSDB_common
 
 	function LMSDB_common()
 	{
-		// zabezpieczmy si przed inicjowaniem tej klasy samej w sobie
+		// zabezpieczmy się przed inicjowaniem tej klasy samej w sobie
 		die();
 	}
 	
@@ -64,8 +64,8 @@ Class LMSDB_common
 		if(method_exists($this, '_driver_shutdown'))
 			register_shutdown_function(array($this, '_driver_shutdown'));
 		
-		// Inicjuje poczenie do bazy danych, nie musimy zwraca
-		// dblinka na zewntrz gdy jest to niepotrzebne.
+		// Inicjuje połączenie do bazy danych, nie musimy zwracać
+		// dblinka na zewnątrz gdyż jest to niepotrzebne.
 		
 		if($this->_driver_connect($dbhost,$dbuser,$dbpasswd,$dbname))
 			return $this->_dblink;
@@ -209,9 +209,9 @@ Class LMSDB_common
 		return $this->_driver_committrans();
 	}
 
-	function LockTables($table)
+	function LockTables($table, $locktype=null)
 	{
-		return $this->_driver_locktables($table);
+		return $this->_driver_locktables($table, $locktype);
 	}
 
 	function UnLockTables()
@@ -231,7 +231,7 @@ Class LMSDB_common
 
 	function _query_parser($query, $inputarray = NULL)
 	{
-		// najpierw sparsujmy wszystkie specjalne meta mieci.
+		// najpierw sparsujmy wszystkie specjalne meta śmieci.
 		$query = eregi_replace('\?NOW\?',$this->_driver_now(),$query);
 		$query = eregi_replace('\?LIKE\?',$this->_driver_like(),$query);
 
@@ -254,8 +254,8 @@ Class LMSDB_common
 
 	function _quote_value($input)
 	{
-		// jeeli baza danych wymaga innego eskejpowania ni to, driver
-		// powinien nadpisa t funkcj
+		// jeżeli baza danych wymaga innego eskejpowania niż to, driver
+		// powinien nadpisać tą funkcję
 
 		if($input === NULL)
 			return 'NULL';
@@ -265,8 +265,8 @@ Class LMSDB_common
 			return $input;
 	}
 
-	// Funkcje bezpieczestwa, tj. na wypadek gdyby driver ich nie
-	// zdefiniowa.
+	// Funkcje bezpieczeństwa, tj. na wypadek gdyby driver ich nie
+	// zdefiniował.
 
 	function _driver_now()
 	{
