@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_mysql.class.php,v 1.48.2.1 2007/08/17 13:15:11 alec Exp $
+ *  $Id: LMSDB_driver_mysql.class.php,v 1.54 2009/02/09 19:22:31 alec Exp $
  */
 
 /*
@@ -36,14 +36,14 @@ class LMSDB_driver_mysql extends LMSDB_common
 	function LMSDB_driver_mysql($dbhost, $dbuser, $dbpasswd, $dbname)
 	{
 		if(!extension_loaded('mysql'))
-		        die('MySQL extension not loaded!');
-	
-		$this->_version .= ' ('.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).'/'.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.48.2.1 $').')';
+		{
+		        trigger_error('MySQL extension not loaded!', E_USER_WARNING);
+			$this->_loaded = FALSE;
+	                return;
+	        }
+	                                        
+		$this->_version .= ' ('.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).'/'.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.54 $').')';
 		$this->Connect($dbhost, $dbuser, $dbpasswd, $dbname);
-
-		if($this->_dblink)
-			if(version_compare($this->_driver_dbversion(), '5') < 0)
-				die('MySQL version not supported!');
 	}
 	
 	function _driver_dbversion()
@@ -63,13 +63,14 @@ class LMSDB_driver_mysql extends LMSDB_common
 		{
 			$this->_error = TRUE;
 		}
+
 		return $this->_dblink;
 	}
 
 	function _driver_shutdown()
 	{
 		$this->_loaded = FALSE;
-		// mysql_close($this->_dblink); - apparently, mysql_close() is automagicly called after end of the script...
+		@mysql_close($this->_dblink); // apparently, mysql_close() is automagicly called after end of the script...
 	}
 	
 	function _driver_geterror()
@@ -162,7 +163,7 @@ class LMSDB_driver_mysql extends LMSDB_common
 
 	function _driver_begintrans()
 	{
-		// mysql nie obsuguje transakcji
+		// MyISAM nie obsługuje transakcji
 		return TRUE;
 	}
 
@@ -171,12 +172,14 @@ class LMSDB_driver_mysql extends LMSDB_common
 		return TRUE;
 	}
 
-	function _driver_locktables($table)
+	function _driver_locktables($table, $locktype=null)
 	{
+		$locktype = $locktype ? strtoupper($locktype) : 'WRITE';
+	
 		if(is_array($table))
-			$this->Execute('LOCK TABLES '.implode(', ', $table));
+			$this->Execute('LOCK TABLES '.implode(' '.$locktype.', ', $table).' '.$locktype);
 		else
-			$this->Execute('LOCK TABLES '.$table);		
+			$this->Execute('LOCK TABLES '.$table.' '.$locktype);
 	}
 
 	function _driver_unlocktables()
