@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_postgres.class.php,v 1.38.2.1 2007/08/17 13:15:11 alec Exp $
+ *  $Id: LMSDB_driver_postgres.class.php,v 1.46 2009/02/10 10:32:09 alec Exp $
  */
 
 /*
@@ -36,27 +36,31 @@ class LMSDB_driver_postgres extends LMSDB_common
 	function LMSDB_driver_postgres($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
 		if(!extension_loaded('pgsql'))
-			die('PostgreSQL extension not loaded!');
+		{
+			trigger_error('PostgreSQL extension not loaded!', E_USER_WARNING);
+			$this->_loaded = FALSE;
+			return;
+		}
 
-		$this->_version .= ' ('.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).'/'.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.38.2.1 $').')';
+		$this->_version .= ' ('.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).'/'.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.46 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
 	function _driver_dbversion()
 	{
-		return $this->GetOne("SELECT substring(substring(version() from 1+position(' ' in version())) for position(' ' in substring(version() from 1+position(' ' in version())))-1)");
+		return $this->GetOne("SELECT split_part(version(),' ',2)");
 	}
 
 	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
 		$cstring = join(' ',array(
-			($dbhost != '' ? 'host='.$dbhost : ''),
+			($dbhost != '' && $dbhost != 'localhost' ? 'host='.$dbhost : ''),
 			($dbuser != '' ? 'user='.$dbuser : ''),
 			($dbpasswd != '' ? 'password='.$dbpasswd : ''),
 			($dbname != '' ? 'dbname='.$dbname : '')
 		));
-		
-		if($this->_dblink = pg_connect($cstring))
+
+		if($this->_dblink = @pg_connect($cstring))
 		{
 			$this->_dbhost = $dbhost;
 			$this->_dbuser = $dbuser;
@@ -71,19 +75,23 @@ class LMSDB_driver_postgres extends LMSDB_common
 
 	function _driver_disconnect()
 	{
-		return pg_close($this->_dblink);
+		$this->_loaded = FALSE;
+		@pg_close($this->_dblink);
 	}
 
 	function _driver_geterror()
 	{
-		return pg_last_error($this->_dblink);
+		if($this->_dblink)
+                        return pg_last_error($this->_dblink);
+                else
+            		return 'We\'re not connected!';
 	}
 	
 	function _driver_execute($query)
 	{
 		$this->_query = $query;
 
-		if($this->_result = pg_query($this->_dblink,$query))
+		if($this->_result = @pg_query($this->_dblink,$query))
 			$this->_error = FALSE;
 		else
 			$this->_error = TRUE;
@@ -93,7 +101,7 @@ class LMSDB_driver_postgres extends LMSDB_common
 	function _driver_fetchrow_assoc($result = NULL)
 	{
 		if(! $this->_error)
-			return pg_fetch_array($result ? $result : $this->_result,NULL, PGSQL_ASSOC);
+			return @pg_fetch_array($result ? $result : $this->_result,NULL, PGSQL_ASSOC);
 		else
 			return FALSE;
 	}
@@ -101,7 +109,7 @@ class LMSDB_driver_postgres extends LMSDB_common
 	function _driver_fetchrow_num()
 	{
 		if(! $this->_error)
-			return pg_fetch_array($this->_result,NULL,PGSQL_NUM);
+			return @pg_fetch_array($this->_result,NULL,PGSQL_NUM);
 		else
 			return FALSE;
 	}
@@ -109,7 +117,7 @@ class LMSDB_driver_postgres extends LMSDB_common
 	function _driver_affected_rows()
 	{
 		if(! $this->_error)
-			return pg_affected_rows($this->_result);
+			return @pg_affected_rows($this->_result);
 		else
 			return FALSE;
 	}
@@ -117,11 +125,24 @@ class LMSDB_driver_postgres extends LMSDB_common
 	function _driver_num_rows()
 	{
 		if(! $this->_error)
-			return pg_num_rows($this->_result);
+			return @pg_num_rows($this->_result);
 		else
 			return FALSE;
 	}
-
+/*	
+	// added 'E' for postgresql 8.2 to skip warnings in error log:
+	// HINT:  Use the escape string syntax for backslashes, e.g., E'\\'.
+	// WARNING:  nonstandard use of escape in a string literal at character...
+	function _quote_value($input)
+        {
+                if($input === NULL)
+			return 'NULL';
+		elseif(gettype($input) == 'string')
+			return 'E\''.addcslashes($input,"'\\\0").'\'';
+		else
+			return $input;
+	}
+*/	
 	function _driver_now()
 	{
 		return 'EXTRACT(EPOCH FROM CURRENT_TIMESTAMP(0))';
@@ -152,7 +173,8 @@ class LMSDB_driver_postgres extends LMSDB_common
 		return $this->Execute('COMMIT');
 	}
 
-	function _driver_locktables($table)
+	// @todo: locktype
+	function _driver_locktables($table, $locktype=null)
         {
 	        if(is_array($table))
 		        $this->Execute('LOCK '.implode(', ', $table));
