@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.11-cvs
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: accesstable.php,v 1.100.2.3 2007/09/28 06:34:24 alec Exp $
+ *  $Id: accesstable.php,v 1.119 2009/01/13 07:45:34 alec Exp $
  */
 
 unset($access);
@@ -32,19 +32,19 @@ $access['table'][0]['name']		= trans('full access');
 $access['table'][0]['allow_reg']	= '^.*$';
 
 $access['table'][1]['name']		= trans('read only (excluding helpdesk)');
-$access['table'][1]['allow_reg']	= '^((user|balance|db|net|node|netdev|tariff|payment|customer|customergroup|account|alias|domain|config|event|taxrate|document|numberplan)(list|info|view|search|balance|infoshort)|netdevmap|eventprint|nodelistshort|number)$';
+$access['table'][1]['allow_reg']	= '^((user|balance|db|net|node|netdev|tariff|payment|customer|customergroup|nodegroup|account|alias|domain|config|event|taxrate|document|numberplan|state|host|division)(list|info|view|search|balance|infoshort)|netdevmap|eventprint|nodelistshort|number)$';
 
 $access['table'][2]['name']		= trans('nodes connection/disconnection');
 $access['table'][2]['allow_reg']	= '^nodeset$';
 
 $access['table'][3]['name']		= trans('finances management');
-$access['table'][3]['allow_reg']	= '^((tariff)(add|info|list|move|edit|del)|(payment)(add|del|edit|info|list)|(balance|customerbalance)(new|add|ok|del|list)|(cashreg(list|add|edit|del|info))|(invoice|invoice(list|new|edit|note|report|paid))|number|export|print|cashimport|cashimportparser|customerassignments|customerassignmentsedit)$';
+$access['table'][3]['allow_reg']	= '^((tariff)(add|info|list|move|edit|del)|(payment)(add|del|edit|info|list)|(balance|customerbalance)(new|add|ok|del|list)|(cashreg(list|add|edit|del|info))|(invoice|invoice(list|new|edit|del|note|report|paid))|number|export|print|cashimport|cashimportparser|customerassignments|customerassignmentsedit)$';
 
 $access['table'][4]['name']    		= trans('configuration reload');
 $access['table'][4]['allow_reg']    	= '^reload$';
 
 $access['table'][5]['name']		= trans('customers management');
-$access['table'][5]['allow_reg']	= '^((customer|document)(add|edit|info|infoshort|list|del|print|search|warn)|documentgen|documentview|nodewarn|choosenode)$';
+$access['table'][5]['allow_reg']	= '^((customer|document)(add|edit|info|infoshort|list|del|print|search|warn|cutoffstop|group)|documentgen|documentview|nodewarn|choosenode)$';
 
 $access['table'][6]['name'] 		= trans('nodes management');
 $access['table'][6]['allow_reg']  	= '^(node(add|info|infoshort|list|scan|search|del|edit|print|warn)|choose(mac|ip))$';
@@ -61,11 +61,11 @@ $access['table'][9]['allow_reg']    	= '^(rtsearch|rtprint|(rtqueue|rtticket|rtm
 $access['table'][10]['name']        	= trans('Helpdesk (RT) operation');
 $access['table'][10]['allow_reg']   	= '^(rtsearch|rtqueue(list|info|view)|(rtticket|rtmessage|rtnote)(add|edit|info|view|del|print))$';
 
-$access['table'][11]['name']        	= trans('accounts management');
-$access['table'][11]['allow_reg']   	= '^((account|domain|alias)(list|edit|add|del))$';
+$access['table'][11]['name']        	= trans('hosting management');
+$access['table'][11]['allow_reg']   	= '^(accountpasswd|(account|domain|alias)(list|edit|add|del|info|search))$';
 
 $access['table'][12]['name']        	= trans('configuration');
-$access['table'][12]['allow_reg']   	= '^((host|config|numberplan|taxrate)(list|edit|add|del|load))$';
+$access['table'][12]['allow_reg']   	= '^((host|config|numberplan|taxrate|state|division)(list|edit|add|del|load))$';
 
 $access['table'][13]['name']        	= trans('networks and devices management');
 $access['table'][13]['allow_reg']   	= '^((net|netdev)(info|list|edit|add|del|cmp|map|remap|search)|choose(mac|ip))$';
@@ -80,7 +80,16 @@ $access['table'][16]['name']        	= trans('cash operations');
 $access['table'][16]['allow_reg']   	= '^(cashreglist|receipt|receipt(list|edit|add|del|adv)|cashreglog(info|view|add|edit|del)|choosecustomer)$';
 
 $access['table'][17]['name']		= trans('customers groups management');
-$access['table'][17]['allow_reg']	= '^(customergroup(add|edit|del|info|list|move))$';
+$access['table'][17]['allow_reg']	= '^(customergroup|customergroup(add|edit|del|info|list|move))$';
+
+$access['table'][18]['name']		= trans('nodes groups management');
+$access['table'][18]['allow_reg']	= '^(nodegroup|nodegroup(add|edit|del|info|list|move))$';
+
+$access['table'][19]['name']		= trans('customers to groups assignment');
+$access['table'][19]['allow_reg']	= '^customergroup$';
+
+$access['table'][20]['name']		= trans('nodes to groups assignment');
+$access['table'][20]['allow_reg']	= '^nodegroup$';
 
 $access['table'][253]['name']		= trans('users edition and addition forbidden');
 $access['table'][253]['deny_reg']	= '^(user(add|del|edit|passwd))$';
@@ -90,6 +99,7 @@ $access['table'][255]['deny_reg']	= '^.*$';
 
 // read user-defined access rights table
 if(isset($CONFIG['phpui']['custom_accesstable']))
-	@include_once(LIB_DIR.'/'.$CONFIG['phpui']['custom_accesstable']);
+	if(is_readable($CONFIG['phpui']['custom_accesstable']))
+                @include_once($CONFIG['phpui']['custom_accesstable']);
 
 ?>
