@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: common.php,v 1.105.2.1 2007/08/17 13:15:12 alec Exp $
+ *  $Id: common.php,v 1.113 2009/01/24 13:17:56 alec Exp $
  */
 
 // Common functions, that making it in class would be nonsense :)
@@ -452,19 +452,19 @@ function get_producer($mac)
 
 function setunits($data)  // for traffic data
 {
-	if ( !($data < (1024*1024*1000)) )
+	if ( !($data < (1000*1000*1000)) )
 	{
-		$number = $data / (1024*1024*1024);
+		$number = $data / (1000*1000*1000);
 		$unit = "GB";
 	}
 	elseif ( !($data < (1024*1000) ) )
 	{
-		$number = $data / (1024*1024);
+		$number = $data / (1000*1000);
 		$unit = "MB";
 	} 
 	else
 	{
-		$number = $data / 1024;
+		$number = $data / 1000;
 		$unit = "KB";
 	}
 	return array($number, $unit);
@@ -573,6 +573,37 @@ function fetch_url($url)
 	return $out;
 }
 
+// quoted-printable encoding
+function qp_encode($string)
+{
+        // ASCII only - don't encode
+        if(!preg_match('#[\x80-\xFF]{1}#', $string))
+        	return $string;
+
+        $encoded = preg_replace('/([\x2C\x3F\x80-\xFF])/e', "'='.sprintf('%02X', ord('\\1'))", $string);
+        // replace spaces with _
+        $encoded = str_replace(' ', '_', $encoded);
+
+        return '=?UTF-8?Q?'.$encoded.'?=';
+}
+
+// escape quotes and backslashes, newlines, etc.
+function escape_js($string)
+{
+    	return strtr($string, array('\\'=>'\\\\',"'"=>"\\'",'"'=>'\\"',"\r"=>'\\r',"\n"=>'\\n','</'=>'<\/'));
+}
+
+function lms_ucwords($str)
+{
+	$result = array();
+	$arr = preg_split('/\s+/', $str);
+	
+	foreach($arr as $word)
+		$result[] = mb_strlen($word) > 1 ? mb_convert_case($word, MB_CASE_TITLE) : $word;
+	
+	return implode(' ', $result);
+}
+
 function plugin_handle($name)
 {
         global $PLUGINS;
