@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: definitions.php,v 1.20.2.1 2007/08/17 13:15:12 alec Exp $
+ *  $Id: definitions.php,v 1.27 2009/01/13 07:45:34 alec Exp $
  */
 
 // that definitions should be included before LMS.class.php but after Smarty
@@ -39,6 +39,7 @@ define('ACCOUNT_SHELL', 1);
 define('ACCOUNT_MAIL', 2);
 define('ACCOUNT_WWW', 4);
 define('ACCOUNT_FTP', 8);
+define('ACCOUNT_SQL', 16);
 
 // Document types
 $DOCTYPES = array(
@@ -67,14 +68,15 @@ define('DOC_ORDER', -4);
 define('DOC_SHEET', -5);
 define('DOC_OTHER', -10);
 
-// Accounting periods
-$PERIODS = array(
-    5	=>	trans('yearly'),
-    4	=>	trans('quarterly'),
-    3	=>	trans('monthly'),
-    2	=>	trans('weekly'),
-    1	=>	trans('daily'),
-    0	=>	trans('disposable')
+// Guarantee periods
+$GUARANTEEPERIODS = array(
+-1 => trans('lifetime'),
+ 0 => trans('none'),
+12 => trans('$0 months', 12), 
+24 => trans('24 months', 24), 
+36 => trans('$0 months', 36), 
+48 => trans('$0 months', 48), 
+60 => trans('$0 months', 60)
 );
 
 // Internet Messengers
@@ -88,16 +90,6 @@ $MESSENGERS = array(
     IM_SKYPE => trans('Skype'),
 );
 
-// Numbering periods
-$NUM_PERIODS = array(
-    6	=>	trans('continuously'),
-    5	=>	trans('yearly'),
-    4	=>	trans('quarterly'),
-    3	=>	trans('monthly'),
-    2	=>	trans('weekly'),
-    1	=>	trans('daily'),
-);
-
 define('DISPOSABLE', 0);
 define('DAILY', 1);
 define('WEEKLY', 2);
@@ -105,6 +97,43 @@ define('MONTHLY', 3);
 define('QUARTERLY', 4);
 define('YEARLY', 5);
 define('CONTINUOUS', 6);
+define('HALFYEARLY', 7);
+
+// Accounting periods
+$PERIODS = array(
+    YEARLY	=>	trans('yearly'),
+    HALFYEARLY  =>      trans('half-yearly'),
+    QUARTERLY	=>	trans('quarterly'),
+    MONTHLY	=>	trans('monthly'),
+    WEEKLY	=>	trans('weekly'),
+    DAILY	=>	trans('daily'),
+    DISPOSABLE	=>	trans('disposable')
+);
+
+// Numbering periods
+$NUM_PERIODS = array(
+    CONTINUOUS	=>	trans('continuously'),
+    YEARLY	=>	trans('yearly'),
+    HALFYEARLY	=>	trans('half-yearly'),
+    QUARTERLY	=>	trans('quarterly'),
+    MONTHLY	=>	trans('monthly'),
+    WEEKLY	=>	trans('weekly'),
+    DAILY	=>	trans('daily'),
+);
+
+
+// Tariff types
+$TARIFFTYPES = array(
+    1 	=>	trans('internet'),
+    2 	=>	trans('hosting'),
+    3 	=>	trans('service'),
+    -1	=>	trans('other'),
+);
+
+define('TARIFF_INTERNET', 1);
+define('TARIFF_HOSTING', 2);
+define('TARIFF_SERVICE', 3);
+define('TARIFF_OTHER', -1);
 
 define('DEFAULT_NUMBER_TEMPLATE', '%N/LMS/%Y');
 
@@ -112,9 +141,11 @@ if(isset($SMARTY))
 {
 	$SMARTY->assign('_DOCTYPES', $DOCTYPES);
 	$SMARTY->assign('_PERIODS', $PERIODS);
+	$SMARTY->assign('_GUARANTEEPERIODS', $GUARANTEEPERIODS);
 	$SMARTY->assign('_NUM_PERIODS', $NUM_PERIODS);
 	$SMARTY->assign('_RT_STATES', $RT_STATES);
 	$SMARTY->assign('_MESSENGERS', $MESSENGERS);
+	$SMARTY->assign('_TARIFFTYPES', $TARIFFTYPES);
 }
 
 ?>
