@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: language.php,v 1.36.2.1 2007/08/17 13:15:12 alec Exp $
+ *  $Id: language.php,v 1.46 2009/01/13 07:45:34 alec Exp $
  */
 
 function trans()
@@ -51,6 +51,14 @@ $LANGDEFS = array(
 			'html' => 'pl',
 			'money_format' => '%01.2f zł'
 			),
+		'lt' => array(
+			'name' => 'Lithuanian',
+			'orig' => 'Litewski',
+			'locale' => 'lt_LT.UTF-8',
+			'charset' => 'UTF-8',
+			'html' => 'lt',
+			'money_format' => '%01.2f LT'
+			),
 		'en' => array(
 			'name' => 'English',
 			'orig' => 'English',
@@ -59,8 +67,16 @@ $LANGDEFS = array(
 			'html' => 'en',
 			'money_format' => '$ %01.2f'
 			),
+		'sk' => array(
+			'name' => 'Slovak',
+			'orig' => 'Slovenský',
+			'locale' => 'sk_SK.UTF-8',
+			'charset' => 'UTF-8',
+			'html' => 'sk',
+			'money_format' => '%01.2f EUR'
+			),
 		'ro' => array(
-			'name' => 'Romainan',
+			'name' => 'Romanian',
 			'orig' => 'Romana',
 			'locale' => 'ro_RO.UTF-8',
 			'charset' => 'UTF-8',
@@ -71,7 +87,14 @@ $LANGDEFS = array(
 
 $_language = 'en'; // default language
 
-$langs = explode(',', (isset($CONFIG['phpui']['lang']) ? $CONFIG['phpui']['lang'] : $_SERVER['HTTP_ACCEPT_LANGUAGE']));
+if(!empty($CONFIG['phpui']['lang']))
+	$langs = $CONFIG['phpui']['lang'];
+elseif(!empty($_SERVER['HTTP_ACCEPT_LANGUAGE']))
+	$langs = $_SERVER['HTTP_ACCEPT_LANGUAGE'];
+else
+	$langs = '';
+
+$langs = explode(',', $langs);
 
 foreach ($langs as $val) 
 {
@@ -80,6 +103,12 @@ foreach ($langs as $val)
 		case 'pl':
 			$_language = 'pl';
     			break 2;
+		case 'lt':
+			$_language = 'lt';
+    			break 2;
+		case 'sk':
+			$_language = 'sk';
+			break 2;
 		case 'ro':
 			$_language = 'ro';
 			break 2;
@@ -99,4 +128,6 @@ setlocale(LC_CTYPE, $LANGDEFS[$_language]['locale']);
 setlocale(LC_TIME, $LANGDEFS[$_language]['locale']);
 setlocale(LC_NUMERIC, $LANGDEFS[$_language]['locale']);
 
+mb_internal_encoding('UTF-8');
+
 ?>
