@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,20 +21,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: functions.php,v 1.23.2.1 2007/08/17 13:15:14 alec Exp $
+ *  $Id: functions.php,v 1.27 2009/01/13 07:45:35 alec Exp $
  */
 
 function bankaccount($id)
 {
+	global $DB;
+	
+	$account = $DB->GetOne('SELECT account FROM divisions WHERE id IN (SELECT divisionid
+			FROM customers WHERE id = ?)', array($id));
+
 	// This function is for demonstration only, coz US don't support IBAN
-	global $CONFIG;
-	if(isset($CONFIG['finances']['iban']) && chkconfig($CONFIG['finances']['iban']))
+	if(!empty($account) && strlen($account) < 21 && strlen($account) >= 8) // mass-payments IBAN
 	{
 	        $cc = '3028';	// Country code - US
-		$account = 'US'.sprintf('%02d',98-bcmod($CONFIG['finances']['account'].sprintf('%012d',$id).$cc.'00',97)).$CONFIG['finances']['account'].sprintf('%012d', $id);
+		$account = 'US'.sprintf('%02d',98-bcmod($account.sprintf('%012d',$id).$cc.'00',97)).$account.sprintf('%012d', $id);
 	} 
-	else
-		$account = (!isset($CONFIG['finances']['account']) || !$CONFIG['finances']['account'] ? trans('Not set') : $CONFIG['finances']['account']);
+
 	return $account;
 }
 
