@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,25 +21,26 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: functions.php,v 1.27.2.1 2007/08/17 13:15:14 alec Exp $
+ *  $Id: functions.php,v 1.31 2009/01/13 07:45:35 alec Exp $
  */
 
 function bankaccount($id)
 {
-	global $CONFIG;
-	if(isset($CONFIG['finances']['iban']) && chkconfig($CONFIG['finances']['iban']))
+	global $DB;
+
+	$account = $DB->GetOne('SELECT account FROM divisions WHERE id IN (SELECT divisionid
+                        FROM customers WHERE id = ?)', array($id));	
+	
+	$acclen = strlen($account);
+	
+	if(!empty($account) && $acclen < 21 && $acclen >= 8)
 	{
 		$cc = '2521';	// Kod kraju - Polska
-		$acclen = strlen($CONFIG['finances']['account']);
-		
-		if($acclen > 20 && $acclen < 8)
-    			return trans('Invalid account!');
-
 		$format = '%0'.(24 - $acclen) .'d';
-		return sprintf('%02d',98-bcmod($CONFIG['finances']['account'].sprintf($format,$id).$cc.'00',97)).$CONFIG['finances']['account'].sprintf($format,$id);
+		return sprintf('%02d',98-bcmod($account.sprintf($format,$id).$cc.'00',97)).$account.sprintf($format,$id);
 	} 
 
-	return (!isset($CONFIG['finances']['account']) ? trans('Not set') : $CONFIG['finances']['account']);
+	return $account;
 }
 		
 function uptimef($ts)
