@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: accountlist.php,v 1.28.2.1 2007/08/17 13:15:20 alec Exp $
+ *  $Id: accountlist.php,v 1.34 2009/01/13 07:45:47 alec Exp $
  */
 
 function GetAccountList($order='login,asc', $customer=NULL, $type=NULL, $kind=NULL, $domain='')
@@ -35,7 +35,7 @@ function GetAccountList($order='login,asc', $customer=NULL, $type=NULL, $kind=NU
 	switch($order)
 	{
 		case 'id':
-			$sqlord = " ORDER BY passwd.id $direction";
+			$sqlord = " ORDER BY p.id $direction";
 		break;
 		case 'customername':
 			$sqlord = " ORDER BY customername $direction, login";
@@ -54,19 +54,18 @@ function GetAccountList($order='login,asc', $customer=NULL, $type=NULL, $kind=NU
 		break;
 	}
 
-	$list = $DB->GetAll(
-	        'SELECT passwd.id AS id, passwd.ownerid AS ownerid, login, lastlogin, 
-			expdate, domains.name AS domain, 
-			type, quota_www, quota_sh, quota_mail, quota_ftp, quota_sql, '
+	$list = $DB->GetAll('SELECT p.id, p.ownerid, p.login, p.lastlogin, 
+			p.expdate, d.name AS domain, p.type, 
+			p.quota_www, p.quota_sh, p.quota_mail, p.quota_ftp, p.quota_sql, '
 			.$DB->Concat('c.lastname', "' '",'c.name').' AS customername 
-		FROM passwd 
-		LEFT JOIN customers c ON c.id = passwd.ownerid 
-		LEFT JOIN domains ON domains.id = domainid WHERE 1=1'
-		.($customer != '' ? ' AND passwd.ownerid = '.$customer : '')
-		.($type ? ' AND type & '.$type.' = '.$type : '')
-		.($kind == 1 ? ' AND expdate!= 0 AND expdate < ?NOW?' : '')
-		.($kind == 2 ? ' AND (expdate=0 OR expdate > ?NOW?)' : '')
-		.($domain != '' ? ' AND domainid = '.$domain : '')
+		FROM passwd p
+		LEFT JOIN customers c ON c.id = p.ownerid 
+		LEFT JOIN domains d ON d.id = p.domainid WHERE 1=1'
+		.($customer != '' ? ' AND p.ownerid = '.$customer : '')
+		.($type ? ' AND p.type & '.$type.' = '.$type : '')
+		.($kind == 1 ? ' AND p.expdate!= 0 AND p.expdate < ?NOW?' : '')
+		.($kind == 2 ? ' AND (p.expdate=0 OR p.expdate > ?NOW?)' : '')
+		.($domain != '' ? ' AND p.domainid = '.$domain : '')
 		.($sqlord != '' ? $sqlord : '')
 		);
 	
@@ -114,15 +113,10 @@ $SESSION->save('ald', $d);
 if ($SESSION->is_set('alp') && !isset($_GET['page']))
 	$SESSION->restore('alp', $_GET['page']);
 	    
-$page = (!isset($_GET['page']) ? 1 : $_GET['page']);
-$pagelimit = (!isset($LMS->CONFIG['phpui']['accountlist_pagelimit']) ? $listdata['total'] : $LMS->CONFIG['phpui']['accountlist_pagelimit']);
-$start = ($page - 1) * $pagelimit;
-
-$SESSION->save('alp', $page);
-
 $layout['pagetitle'] = trans('Accounts List');
 
 $accountlist = GetAccountList($o, $u, $t, $k, $d);
+
 $listdata['total'] = $accountlist['total'];
 $listdata['order'] = $accountlist['order'];
 $listdata['direction'] = $accountlist['direction'];
@@ -130,6 +124,7 @@ $listdata['type'] = $accountlist['type'];
 $listdata['kind'] = $accountlist['kind'];
 $listdata['customer'] = $accountlist['customer'];
 $listdata['domain'] = $accountlist['domain'];
+
 unset($accountlist['total']);
 unset($accountlist['order']);
 unset($accountlist['type']);
@@ -138,6 +133,12 @@ unset($accountlist['customer']);
 unset($accountlist['domain']);
 unset($accountlist['direction']);
 
+$page = (empty($_GET['page']) ? 1 : $_GET['page']);
+$pagelimit = (empty($CONFIG['phpui']['accountlist_pagelimit']) ? $listdata['total'] : $CONFIG['phpui']['accountlist_pagelimit']);
+$start = ($page - 1) * $pagelimit;
+
+$SESSION->save('alp', $page);
+
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('pagelimit', $pagelimit);
@@ -145,7 +146,7 @@ $SMARTY->assign('page', $page);
 $SMARTY->assign('start', $start);
 $SMARTY->assign('accountlist',$accountlist);
 $SMARTY->assign('listdata',$listdata);
-$SMARTY->assign('customerlist',$LMS->GetCustomerNames());
+$SMARTY->assign('customerlist',$LMS->GetAllCustomerNames());
 $SMARTY->assign('domainlist',$DB->GetAll('SELECT id, name FROM domains ORDER BY name'));
 $SMARTY->display('accountlist.html');
 
