@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,16 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: aliasdel.php,v 1.8.2.1 2007/08/17 13:15:20 alec Exp $
+ *  $Id: aliasdel.php,v 1.13 2009/01/13 07:45:47 alec Exp $
  */
 
 $id = $_GET['id'];
 
 if($id && $_GET['is_sure']=='1')
 {
+	$DB->BeginTrans();
 	$DB->Execute('DELETE FROM aliases WHERE id = ?', array($id));
+	$DB->Execute('DELETE FROM aliasassignments WHERE aliasid = ?', array($id));
+	$DB->CommitTrans();
 }
 
-header('Location: ?m=aliaslist');
+$SESSION->redirect('?'.$SESSION->get('backto'));
 
 ?>
