@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,14 +21,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balanceadd.php,v 1.47.2.1 2007/08/17 13:15:20 alec Exp $
+ *  $Id: balanceadd.php,v 1.57 2009/01/13 07:45:47 alec Exp $
  */
 
 $addbalance = $_POST['addbalance'];
 
-$addbalance['value'] = str_replace(',','.',$addbalance['value']);
+foreach($addbalance as $key=>$value)
+	if(!is_array($value))
+		$addbalance[$key] = trim($value);		
 
-if(isset($addbalance['time']) && $addbalance['time'] != '' && ! ereg('^[0-9]{4}/[0-9]{2}/[0-9]{2} [0-9]{2}:[0-9]{2}$', $addbalance['time']))
+$addbalance['value'] = str_replace(',','.', $addbalance['value']);
+
+$currenttime = false;
+if(isset($addbalance['time']) && $addbalance['time'] != '' 
+	&& ! ereg('^[0-9]{4}/[0-9]{2}/[0-9]{2} [0-9]{2}:[0-9]{2}$', $addbalance['time'])
+	&& ! ereg('^[0-9]{4}/[0-9]{2}/[0-9]{2}$', $addbalance['time']))
 {
 	// here we should throw error back to user about fucked up date format or something
 	// otherwise mktime invokes error about expected parameters
@@ -36,40 +43,55 @@ if(isset($addbalance['time']) && $addbalance['time'] != '' && ! ereg('^[0-9]{4}/
 elseif(isset($addbalance['time']) && $addbalance['time']!='')
 {
 	// date format 'yyyy/mm/dd hh:mm'	
-	list($date,$time) = split(' ', $addbalance['time']);
-	$date = explode('/',$date);
-	$time = explode(':',$time);
-
+	$date = split(' ', $addbalance['time']);
+	if(isset($date[1]))
+		$time = explode(':',$date[1]);
+	else {
+		$time[0] = $time[1] = 0;
+	}	
+	$date = explode('/',$date[0]);
+	
 	if(checkdate($date[1],$date[2],(int)$date[0])) //if date is wrong, set today's date
 	{
-		if (!strlen($time[0]) || !strlen($time[1]))
-			$time[0] = $time[1] = 0;
 		$addbalance['time'] = mktime($time[0],$time[1],0,$date[1],$date[2],$date[0]);
 	}
 	else
+	{
 		// here too. geez, what the matter with you guys? if($user==E_LAME){ we_know_better(); } ???
 		// pls, fix it
 		$addbalance['time'] = time();
+		$currenttime = true;
+	}
 }
 else
+{
 	$addbalance['time'] = time();
+	$currenttime = true;
+}
 
 $SESSION->save('addbc', $addbalance['comment']);
-$SESSION->save('addbt', $addbalance['time']);
+if ($currenttime)
+	$SESSION->remove('addbt');
+else
+	$SESSION->save('addbt', $addbalance['time']);
+
 $SESSION->save('addbv', $addbalance['value']);
 $SESSION->save('addbtax', isset($addbalance['taxid']) ? $addbalance['taxid'] : 0);
 
+if(!isset($addbalance['type']))
+        $addbalance['type'] = 1;
+
+if($addbalance['type'] == 0)
+	$addbalance['value'] *= -1;
+else
+	$addbalance['taxid'] = 0;
+
 if(isset($addbalance['mcustomerid']))
 {
 	foreach($addbalance['mcustomerid'] as $value)
 		if($LMS->CustomerExists($value))
 		{
 			$addbalance['customerid'] = $value;
-			if($addbalance['type']) 
-				$addbalance['taxid'] = 0;
-			
-			if($addbalance['type'] == 0)
-				$addbalance['value'] *= -1;
 			if($addbalance['value'] != 0)
 				$LMS->AddBalance($addbalance);
 		}
@@ -78,11 +100,6 @@ elseif(isset($addbalance['customerid']))
 {
 	if($LMS->CustomerExists($addbalance['customerid']))
 	{
-		if($addbalance['type']) 
-			$addbalance['taxid'] = 0;
-			
-		if($addbalance['type'] == 0)
-			$addbalance['value'] *= -1;
 		if($addbalance['value'] != 0)
 			$LMS->AddBalance($addbalance);
 	}
