@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,13 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancelist.php,v 1.53.2.2 2007/08/23 07:56:27 alec Exp $
+ *  $Id: balancelist.php,v 1.61 2009/01/28 15:55:58 alec Exp $
  */
 
-function GetBalanceList($search=NULL, $cat=NULL, $group=NULL)
+function GetBalanceList($search=NULL, $cat=NULL, $group=NULL, $pagelimit=100, $page=NULL, $from, $to)
 {
 	global $DB;
 
+	$where = '';
+
 	if($search && $cat)
         {
 		switch($cat)
@@ -56,6 +58,19 @@ function GetBalanceList($search=NULL, $cat=NULL, $group=NULL)
 			break;
 		}
 	}
+	elseif($cat)
+	{
+		switch($cat)
+		{
+			case 'documented': $where = ' AND cash.docid > 0'; break;
+			case 'notdocumented': $where = ' AND cash.docid = 0'; break;
+		}
+	}
+
+	if($from)
+        	$where .= ' AND cash.time >= '.$from;
+	if($to)
+		$where .= ' AND cash.time <= '.$to;
 
 	if($res = $DB->Exec('SELECT cash.id AS id, time, cash.userid AS userid, cash.value AS value, 
 				cash.customerid AS customerid, comment, docid, cash.type AS type,
@@ -63,40 +78,37 @@ function GetBalanceList($search=NULL, $cat=NULL, $group=NULL)
 				.$DB->Concat('UPPER(c.lastname)',"' '",'c.name').' AS customername
 				FROM cash
 				LEFT JOIN customers c ON (cash.customerid = c.id)
-				LEFT JOIN documents ON (documents.id = docid) '
-				.' WHERE NOT EXISTS (
-				        SELECT 1 FROM customerassignments a
+				LEFT JOIN documents ON (documents.id = docid)
+				LEFT JOIN (
+				        SELECT DISTINCT a.customerid
+					FROM customerassignments a
 					JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
-					WHERE e.userid = lms_current_user() AND a.customerid = cash.customerid)'
-				.(isset($where) ? $where : '')
+					WHERE e.userid = lms_current_user()
+				) e ON (e.customerid = cash.customerid)
+				WHERE e.customerid IS NULL'
+				.$where
+				.(!empty($group['group']) ? 
+					' AND '.(!empty($group['exclude']) ? 'NOT' : '').' EXISTS (
+					SELECT 1 FROM customerassignments WHERE customergroupid = '.intval($group['group']).'
+					AND customerid = cash.customerid)' : '')
 				.' ORDER BY time, cash.id'))
 	{
 		$userlist = $DB->GetAllByKey('SELECT id, name FROM users','id');
 
-    		if($group['group'])
-		        $customers = $DB->GetAllByKey('SELECT customerid AS id
-					    FROM customerassignments WHERE customergroupid=?',
-					    'id', array($group['group']));
-
 		$balancelist['liability'] = 0;
 		$balancelist['expense'] = 0;
 		$balancelist['income'] = 0;
-
+		if ($page > 0) {
+		    $start =  ($page - 1) * $pagelimit;
+		    $stop = $start + $pagelimit;
+		}
 		$id = 0;
+		$after = 0;
+
 		while($row = $DB->FetchRow($res))
 		{
-			if($group['group'])
-			{
-				if(!$group['exclude'] && !isset($customers[$row['customerid']]))
-					continue;
-				elseif($group['exclude'] && isset($customers[$row['customerid']]))
-					continue;
-			}
-
-			$balancelist[$id] = $row;
 			$balancelist[$id]['user'] = isset($userlist[$row['userid']]['name']) ? $userlist[$row['userid']]['name'] : '';
-			$balancelist[$id]['before'] = isset($balancelist[$id-1]['after']) ? $balancelist[$id-1]['after'] : 0;
-			$balancelist[$id]['value'] = $row['value'];
+			$balancelist[$id]['before'] = $after;
 
 			if($row['customerid'] && $row['type'] == 0)
 			{
@@ -115,11 +127,26 @@ function GetBalanceList($search=NULL, $cat=NULL, $group=NULL)
 					//expense
 					$balancelist['expense'] += -$row['value'];
 			}
+
+			$balancelist[$id] = array_merge($balancelist[$id], $row);
+			$after = $balancelist[$id]['after'];
+
+			// free memory for rows which will not be displayed
+			if($page > 0)
+			{
+				if(($id < $start - 1 || $id > $stop) && isset($balancelist[$id]))
+					$balancelist[$id] = NULL;
+			}
+			elseif(isset($balancelist[$id-$pagelimit]))
+				$balancelist[$id-$pagelimit] = NULL;
+			
 			$id++;
 		}
 	
 		$balancelist['totalval'] = $balancelist['income'] - $balancelist['expense'];
-	
+		$balancelist['page'] = $page > 0 ? $page : ceil($id / $pagelimit);
+		$balancelist['total'] = $id;
+
 		return $balancelist;
 	}
 }
@@ -153,27 +180,53 @@ if($c == 'cdate' && $s)
 	$s = mktime(0,0,0, (int)$month, (int)$day, (int)$year);
 }
 
-$balancelist = GetBalanceList($s, $c, array('group' => $g, 'exclude'=> $ge));
+if(!empty($_POST['from']))
+{
+	list($year, $month, $day) = explode('/', $_POST['from']);
+	$from = mktime(0,0,0, $month, $day, $year);
+}
+elseif($SESSION->is_set('blf'))
+	$SESSION->restore('blf', $from);
+else
+	$from = '';
+$SESSION->save('blf', $from);
+
+if(!empty($_POST['to']))
+{
+	list($year, $month, $day) = explode('/', $_POST['to']);
+	$to = mktime(23,59,59, $month, $day, $year);
+}
+elseif($SESSION->is_set('blt'))
+	$SESSION->restore('blt', $to);
+else
+	$to = '';
+$SESSION->save('blt', $to);
+
+$pagelimit = $CONFIG['phpui']['balancelist_pagelimit'];
+$page = (empty($_GET['page']) ? 0 : intval($_GET['page']));
+
+$balancelist = GetBalanceList($s, $c, array('group' => $g, 'exclude'=> $ge), $pagelimit, $page, $from, $to);
 
 $listdata['liability'] = $balancelist['liability'];
 $listdata['income'] = $balancelist['income'];
 $listdata['expense'] = $balancelist['expense'];
 $listdata['totalval'] = $balancelist['totalval'];
+$listdata['total'] = $balancelist['total'];
+$page = $balancelist['page'];
+
 unset($balancelist['liability']);
 unset($balancelist['income']);
 unset($balancelist['expense']);
 unset($balancelist['totalval']);
-
-$listdata['total'] = sizeof($balancelist);
+unset($balancelist['total']);
+unset($balancelist['page']);
 
 $SESSION->restore('blc', $listdata['cat']);
 $SESSION->restore('bls', $listdata['search']);
 $SESSION->restore('blg', $listdata['group']);
 $SESSION->restore('blge', $listdata['groupexclude']);
-
-$pagelimit = $CONFIG['phpui']['balancelist_pagelimit'];
-$page = (! isset($_GET['page']) ? ceil($listdata['total']/$pagelimit) : intval($_GET['page'])); 
-$start = ($page - 1) * $pagelimit;
+$SESSION->restore('blf', $listdata['from']);
+$SESSION->restore('blt', $listdata['to']);
 
 $layout['pagetitle'] = trans('Balance Sheet');
 
@@ -181,7 +234,7 @@ $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('balancelist',$balancelist);
 $SMARTY->assign('listdata',$listdata);
-$SMARTY->assign('start',$start);
+$SMARTY->assign('start', ($page - 1) * $pagelimit);
 $SMARTY->assign('page',$page);
 $SMARTY->assign('pagelimit',$pagelimit);
 $SMARTY->assign('grouplist',$LMS->CustomergroupGetAll());
