@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,12 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chooseip.php,v 1.43.2.1 2007/08/17 13:15:21 alec Exp $
+ *  $Id: chooseip.php,v 1.50 2009/01/13 07:45:48 alec Exp $
  */
 
 $layout['pagetitle'] = trans('Select IP address');
 
-$networks = $LMS->GetNetworks();
+$networks = $LMS->GetNetworks(false);
 
 $p = isset($_GET['p']) ? $_GET['p'] : '';
 
@@ -50,32 +50,49 @@ if (isset($_POST['page']))
     $page = $_POST['page'];
 elseif (isset($_GET['page']))
     $page = $_GET['page'];
-elseif ($SESSION->is_set('ntlp.page.'.$netid))
+elseif($SESSION->is_set('ntlp.page.'.$netid))
     $SESSION->restore('ntlp.page.'.$netid, $page);
 else
+{
     $page = 1;
-
-$SESSION->save('netid', $netid);
-$SESSION->save('ntlp.page.'.$netid, $page);
+    $firstfree = true;
+}
 
 $network = array();
 
-if($p == 'main')
+switch($p)
 {
-	$network = $LMS->GetNetworkRecord($netid, $page, $CONFIG['phpui']['networkhosts_pagelimit']);
-	$SESSION->save('ntlp.pages.'.$netid, $network['pages']);
+	case 'main':
+		$network = $LMS->GetNetworkRecord($netid, $page, 
+			$CONFIG['phpui']['networkhosts_pagelimit'], 
+			isset($firstfree) ? true : false);
+
+		$page = $network['page'];
+		$SESSION->save('ntlp.pages.'.$netid, $network['pages']);
+		$SESSION->save('ntlp.page.'.$netid, $page);
+	break;
+	case 'top':
+		$SESSION->save('ntlp.page.'.$netid, $page);
+	break;
+	case 'down':
+		$SESSION->restore('ntlp.page.'.$netid, $network['page']);
+		$SESSION->restore('ntlp.pages.'.$netid, $network['pages']);
+		if(!isset($network['pages'])) 
+		{
+			$network = $LMS->GetNetworkRecord($netid, $page, 
+				$CONFIG['phpui']['networkhosts_pagelimit'],
+				isset($firstfree) ? true : false);
+		}
+		$SESSION->save('ntlp.pages.'.$netid, $network['pages']);
+		$SESSION->save('ntlp.page.'.$netid, $network['page']);
+	break;
+	default:
+		if(!isset($firstfree))
+			$SESSION->save('ntlp.page.'.$netid, $page);
+	break;
 }
 
-if($p == 'down' || $p == 'top')
-{
-	$SESSION->restore('ntlp.page.'.$netid, $network['page']);
-	$SESSION->restore('ntlp.pages.'.$netid, $network['pages']);
-	if (!isset($network['pages'])) 
-	{
-		$network = $LMS->GetNetworkRecord($netid, $page, $CONFIG['phpui']['networkhosts_pagelimit']);
-		$SESSION->save('ntlp.pages.'.$netid, $network['pages']);
-	}
-}
+$SESSION->save('netid', $netid);
 
 $SMARTY->assign('part',$p);
 $SMARTY->assign('js',$js);
