@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: choosemac.php,v 1.23.2.3 2007/10/02 06:54:46 alec Exp $
+ *  $Id: choosemac.php,v 1.29 2009/01/13 07:45:48 alec Exp $
  */
 
 $layout['pagetitle'] = trans('Select MAC address');
@@ -51,6 +51,9 @@ elseif($p == 'main')
 		}
 	}
 	
+	if(sizeof($maclist))
+		array_multisort($maclist['longip'],$maclist['mac'],$maclist['ip'],$maclist['nodename']);
+				
 	$SMARTY->assign('maclist',$maclist);
 }
 
