@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: configadd.php,v 1.19.2.1 2007/08/17 13:15:21 alec Exp $
+ *  $Id: configadd.php,v 1.23 2009/01/13 07:45:48 alec Exp $
  */
 
 $layout['pagetitle'] = trans('New Config Option');
@@ -80,6 +80,9 @@ if(sizeof($config))
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
+if(isset($_GET['section']))
+	$config['section'] = $_GET['section'];
+
 $SMARTY->assign('error', $error);
 $SMARTY->assign('config', $config);
 $SMARTY->display('configadd.html');
