@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: configlist.php,v 1.42.2.2 2007/09/27 09:11:27 alec Exp $
+ *  $Id: configlist.php,v 1.54 2009/01/13 07:45:48 alec Exp $
  */
 
-function GetConfigList($order='var,asc')
+function GetConfigList($order='var,asc', $section='')
 {
 	global $DB;
 
@@ -42,8 +42,15 @@ function GetConfigList($order='var,asc')
 		break;
 	}
 
-	if($config = $DB->GetAll('SELECT id, section, var, value, description as usercomment, disabled FROM uiconfig WHERE section != \'userpanel\''.$sqlord))
-	foreach ($config as $idx => $item) 
+	if($section)
+		$config = $DB->GetAll('SELECT id, section, var, value, description as usercomment, disabled 
+			FROM uiconfig WHERE section != \'userpanel\' AND section = ?'
+			.$sqlord, array($section));
+	else
+		$config = $DB->GetAll('SELECT id, section, var, value, description as usercomment, disabled 
+			FROM uiconfig WHERE section != \'userpanel\''.$sqlord);
+
+	if($config) foreach ($config as $idx => $item) 
 	{
 		switch($item['section'])
 		{
@@ -51,7 +58,7 @@ function GetConfigList($order='var,asc')
 				switch($item['var'])
 				{
 				case 'allow_from':
-					$config[$idx]['description'] = trans('List of networks and IP addresses, with access to LMS. If empty, every IP address has access to LMS. When you write list of addresses or address classes here, LMS will dismiss every unwanted user with HTTP 403 error.');
+					$config[$idx]['description'] = trans('List of networks and IP addresses, with access to LMS. If empty, every IP address has access to LMS. When you write list of addresses or address pools here, LMS will dismiss every unwanted user with HTTP 403 error.');
 				break;
 				
 				case 'lang':
@@ -110,6 +117,10 @@ function GetConfigList($order='var,asc')
 					$config[$idx]['description'] = trans('Limit of records displayed on one page in numbering plans list. Default: 100.');
 				break;
 
+				case 'divisionlist_pagelimit':
+					$config[$idx]['description'] = trans('Limit of records displayed on one page in divisions list. Default: 100.');
+				break;
+
 				case 'documentlist_pagelimit':
 					$config[$idx]['description'] = trans('Limit of records displayed on one page in documents list. Default: 100.');
 				break;
@@ -194,23 +205,23 @@ function GetConfigList($order='var,asc')
 
 				case 'nodepassword_length':
 					$config[$idx]['description'] = trans('Length of (auto-generated) node password. Max.32. Default: 16.');
-				break;					
+				break;
 				
 				case 'custom_accesstable':
 					$config[$idx]['description'] = trans('PHP file with user-defined access rules in "lib" directory. Default: empty.');
-				break;					
+				break;
 
 				case 'check_for_updates_period':
 					$config[$idx]['description'] = trans('How often to check for LMS updates (in seconds). Default: 86400.');
-				break;					
+				break;
 
 				case 'map_type':
 					$config[$idx]['description'] = trans('Network map type. Use "flash" if you have Ming library or "gd" if your PHP supports gdlib. By default LMS will try to generate flash map, with fallback to GD if it fails.');
-				break;					
+				break;
 
 				case 'homedir_prefix':
 					$config[$idx]['description'] = trans('Prefix for account home directory. Default: /home/');
-				break;					
+				break;
 
 				case 'smtp_port':
 				case 'smtp_host':
@@ -245,7 +256,7 @@ function GetConfigList($order='var,asc')
 				break;					
 
 				case 'helpdesk_customerinfo':
-					$config[$idx]['description'] = trans('Adds customer basic informations on ticket view and in notifications. Default: true');
+					$config[$idx]['description'] = trans('Adds customer basic information on ticket view and in notifications. Default: true');
 				break;					
 
 				case 'ticket_template_file':
@@ -254,15 +265,19 @@ function GetConfigList($order='var,asc')
 			
 				case 'ticketlist_status':
 					$config[$idx]['description'] = trans('Default status filter setting on tickets list. For allowed values see html source code. Default: not set');
-				break;					
+				break;
 
 				case 'use_invoices':
 					$config[$idx]['description'] = trans('Makes option "with invoice" checked by default. Default: false');
-				break;					
+				break;
 
 				case 'default_module':
 					$config[$idx]['description'] = trans('Start-up module (filename from /modules without .php). Default: welcome');
-				break;					
+				break;
+
+				case 'default_assignment_period':
+					$config[$idx]['description'] = trans('Default period value for assignment. Default: 0');
+				break;
 				
 				default:
 					$config[$idx]['description'] = trans('Unknown option. No description.');
@@ -319,7 +334,7 @@ function GetConfigList($order='var,asc')
 					break;
 					
 					case 'footer':
-						$config[$idx]['description'] = trans('Small font footer will appear at the bottom of page, e.g. Our Bank: SNETISP, 828823917293871928371\nPhone number 555 123 123');
+						$config[$idx]['description'] = trans('Small font text appearing in selected (in template) place of the invoice, e.g. Our Bank: SNETISP, 828823917293871928371\nPhone number 555 123 123');
 					break;
 					
 					case 'default_author':
@@ -357,6 +372,10 @@ function GetConfigList($order='var,asc')
 					case 'print_balance_history_limit':
 						$config[$idx]['description'] = trans('Number of Records on customer balance list on invoice. Specify last x records. Default: 10.');
 					break;
+
+					case 'default_printpage':
+						$config[$idx]['description'] = trans('Coma-separated list of default invoice printout pages. You can use "original", "copy", "duplicate". Default: "original,copy".');
+					break;
 					
 					default:
 						$config[$idx]['description'] = trans('Unknown option. No description.');
@@ -398,6 +417,7 @@ function GetConfigList($order='var,asc')
 	$config['total'] = sizeof($config);
 	$config['order'] = $order;
 	$config['direction'] = $direction;
+	$config['section'] = $section;
 
 	return $config;
 }
@@ -405,27 +425,37 @@ function GetConfigList($order='var,asc')
 $layout['pagetitle'] = trans('User Interface Configuration');
 
 if(!isset($_GET['o']))
-	$SESSION->restore('clo', $o);
+	$SESSION->restore('conlo', $o);
 else
 	$o = $_GET['o'];
-$SESSION->save('clo', $o);
+$SESSION->save('conlo', $o);
 
-if ($SESSION->is_set('clp') && !isset($_GET['page']))
-	$SESSION->restore('clp', $_GET['page']);
+if(!isset($_GET['s']))
+        $SESSION->restore('conls', $s);
+else
+	$s = $_GET['s'];
+$SESSION->save('conls', $s);
+		
+if ($SESSION->is_set('conlp') && !isset($_GET['page']))
+	$SESSION->restore('conlp', $_GET['page']);
+
+$configlist = GetConfigList($o, $s);
 
-$configlist = GetConfigList($o);
 $listdata['total'] = $configlist['total'];
 $listdata['order'] = $configlist['order'];
 $listdata['direction'] = $configlist['direction'];
+$listdata['section'] = $configlist['section'];
+
 unset($configlist['total']);
 unset($configlist['order']);
 unset($configlist['direction']);
+unset($configlist['section']);
 	    
 $page = (!isset($_GET['page']) ? 1 : $_GET['page']); 
 $pagelimit = (! $LMS->CONFIG['phpui']['configlist_pagelimit'] ? $listdata['total'] : $LMS->CONFIG['phpui']['configlist_pagelimit']);
 $start = ($page - 1) * $pagelimit;
 
-$SESSION->save('clp', $page);
+$SESSION->save('conlp', $page);
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
