@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: copyrights.php,v 1.37.2.1 2007/08/17 13:15:21 alec Exp $
+ *  $Id: copyrights.php,v 1.42 2009/01/13 07:45:48 alec Exp $
  */
 
 $layout['pagetitle'] = trans('Copyrights');
@@ -37,22 +37,28 @@ $authors = array(
 		'Baseciq' => array(
 			'realname' => 'Łukasz Jarosław Mozer',
 			'www' => 'www.baseciq.org',
-			'info' => 'inventor & maintainer, PHP, Perl, design, HTML, JavaScript, CSS, images, doc, project\'s WWW'
+			'info' => 'inventor & maintainer, PHP, Perl, design, HTML, JavaScript, CSS, images, doc, website'
 			),
 
-		'chilek' => array(
-			'realname' => 'Tomasz Chiliński',
+		'Ceho' => array(
+			'realname' => 'Grzegorz Chwesewicz',
 			'info' => 'PHP, Perl, HTML, JavaScript',
 			'www' => 'www.chilan.com'
 			),
 
+		'Chilek' => array(
+			'realname' => 'Tomasz Chiliński',
+			'info' => 'PHP, Perl, HTML, JavaScript, C',
+			'www' => 'www.chilan.com'
+			),
+
 		'hunter' => array(
 			'info' => 'PHP, Perl',
 			'realname' => 'Krzysztof Drewicz',
 			),
 
 		'Lexx' => array(
-			'info' => 'PHP, C, doc, project\'s  WWW',
+			'info' => 'PHP, C, doc, website',
 			'www' => 'www.lexx.w.pl',
 			'realname' => 'Marcin Król',
 		     ),
@@ -112,7 +118,7 @@ $others = array(
 			),
 
 		'Pierzak' => array(
-			'realname' => 'Piotr M.',
+			'realname' => 'Piotr Mierzeński',
 			'info' => 'Logo project',
 			),
 		);
