@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,35 +21,31 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customeradd.php,v 1.18.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customeradd.php,v 1.30 2009/01/13 07:45:48 alec Exp $
  */
 
 if(isset($_GET['ajax'])) 
 {
 	header('Content-type: text/plain');
-	function escape_js($string)
-	{
-        	// escape quotes and backslashes, newlines, etc.
-        	return strtr($string, array('\\'=>'\\\\',"'"=>"\\'",'"'=>'\\"',"\r"=>'\\r',"\n"=>'\\n','</'=>'<\/'));
-	}
-	
 	$search = urldecode(trim($_GET['what']));
+
 	switch($_GET['mode'])
 	{
-		        case 'address':
-				$mode='address';
-				if ($CONFIG['database']['type'] == 'mysql' || $CONFIG['database']['type'] == 'mysqli') 
-					$mode = 'substring(address from 1 for length(address)-locate(\' \',reverse(address))+1)';
-				elseif($CONFIG['database']['type'] == 'postgres') 
-					$mode = 'substring(address from \'^.* \')';
-				break;
-		        case 'zip':
-				$mode='zip';
-				break;
-		        case 'city':
-				$mode='city';
-				break;
+	        case 'address':
+			$mode='address';
+			if ($CONFIG['database']['type'] == 'mysql' || $CONFIG['database']['type'] == 'mysqli') 
+				$mode = 'substring(address from 1 for length(address)-locate(\' \',reverse(address))+1)';
+			elseif($CONFIG['database']['type'] == 'postgres') 
+				$mode = 'substring(address from \'^.* \')';
+		break;
+	        case 'zip':
+			$mode='zip';
+		break;
+	        case 'city':
+			$mode='city';
+		break;
 	}
+
 	if (!isset($mode)) { print 'false;'; exit; }
 	$candidates = $DB->GetAll('SELECT '.$mode.' as item, count(id) as entries FROM customers WHERE '.$mode.' != \'\' AND lower('.$mode.') ?LIKE? lower(\'%'.$search.'%\') GROUP BY item ORDER BY entries desc, item asc');
 	$eglible=array(); $descriptions=array();
@@ -95,11 +91,17 @@ elseif(isset($_POST['customeradd']))
 	if($customeradd['address'] == '')
 		$error['address'] = trans('Address required!');
 	
-	if($customeradd['ten'] !='' && !check_ten($customeradd['ten']))
-		$error['ten'] = trans('Incorrect Tax Exempt Number!');
+	if($customeradd['ten'] !='' && !check_ten($customeradd['ten']) && !isset($customeradd['tenwarning']))
+	{
+		$error['ten'] = trans('Incorrect Tax Exempt Number! If you are sure you want to accept it, then click "Submit" again.');
+		$customeradd['tenwarning'] = 1;
+	}
 
-	if($customeradd['ssn'] != '' && !check_ssn($customeradd['ssn']))
-		$error['ssn'] = trans('Incorrect Social Security Number!');
+	if($customeradd['ssn'] != '' && !check_ssn($customeradd['ssn']) && !isset($customeradd['ssnwarning']))
+	{
+		$error['ssn'] = trans('Incorrect Social Security Number! If you are sure you want to accept it, then click "Submit" again.');
+		$customeradd['ssnwarning'] = 1;
+	}
 
 	if($customeradd['icn'] != '' && !check_icn($customeradd['icn']))
 		$error['icn'] = trans('Incorrect Identity Card Number!');
@@ -107,8 +109,11 @@ elseif(isset($_POST['customeradd']))
 	if($customeradd['regon'] != '' && !check_regon($customeradd['regon']))
 		$error['regon'] = trans('Incorrect Business Registration Number!');
 		
-	if($customeradd['zip'] !='' && !check_zip($customeradd['zip']))
-		$error['zip'] = trans('Incorrect ZIP code!');
+	if($customeradd['zip'] !='' && !check_zip($customeradd['zip']) && !isset($customeradd['zipwarning']))
+	{
+		$error['zip'] = trans('Incorrect ZIP code! If you are sure you want to accept it, then click "Submit" again.');
+		$customeradd['zipwarning'] = 1;
+	}
 
 	if($customeradd['pin'] == '')
 		$error['pin'] = trans('PIN code is required!');
@@ -153,6 +158,14 @@ elseif(isset($_POST['customeradd']))
 
 	if(!$error)
 	{
+		if($customeradd['cutoffstop'])
+			$customeradd['cutoffstop'] = mktime(23,59,59,date('m'), date('d') + $customeradd['cutoffstop']);
+
+		if(!isset($customeradd['consentdate']))
+			$customeradd['consentdate'] = 0;
+		if(!isset($customeradd['divisionid']))
+			$customeradd['divisionid'] = 0;
+		
 		$id = $LMS->CustomerAdd($customeradd);
 
 		if(isset($im) && $id)
@@ -165,6 +178,18 @@ elseif(isset($_POST['customeradd']))
 				$DB->Execute('INSERT INTO customercontacts (customerid, phone, name)
 					VALUES(?, ?, ?)', array($id, $contact['phone'], $contact['name']));
 
+		if($customeradd['zip'] && $customeradd['stateid'])
+                {
+		        $cstate = $DB->GetOne('SELECT stateid FROM zipcodes WHERE zip = ?', array($customeradd['zip']));
+		
+		        if($cstate === NULL)
+		        	$DB->Execute('INSERT INTO zipcodes (stateid, zip) VALUES (?, ?)',
+			                array($customeradd['stateid'], $customeradd['zip']));
+			elseif($cstate != $customeradd['stateid'])
+			        $DB->Execute('UPDATE zipcodes SET stateid = ? WHERE zip = ?',
+			                array($customeradd['stateid'], $customeradd['zip']));
+                }
+
 		if(!isset($customeradd['reuse']))
 		{
 			$SESSION->redirect('?m=customerinfo&id='.$id);
@@ -191,8 +216,11 @@ if(!isset($customeradd['address']) && isset($CONFIG['phpui']['default_address'])
 
 $layout['pagetitle'] = trans('New Customer');
 
-$SMARTY->assign('customeradd',$customeradd);
-$SMARTY->assign('error',$error);
+$SMARTY->assign('cstateslist', $LMS->GetCountryStates());
+$SMARTY->assign('countrieslist', $LMS->GetCountries());
+$SMARTY->assign('divisions', $DB->GetAll('SELECT id, shortname, status FROM divisions ORDER BY shortname'));
+$SMARTY->assign('customeradd', $customeradd);
+$SMARTY->assign('error', $error);
 $SMARTY->display('customeradd.html');
 
 ?>
