@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customerassignments.php,v 1.22.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customerassignments.php,v 1.27 2009/01/13 07:45:48 alec Exp $
  */
 
 if($LMS->CustomerExists($_GET['id']) !== TRUE)
@@ -41,21 +41,135 @@ if($_GET['action'] == 'suspend')
 	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
-$a = $_POST['assignment'];
-
-if($_GET['action'] == 'add' && isset($a))
+if($_GET['action'] == 'add' && isset($_POST['assignment']))
 {
+	$a = $_POST['assignment'];
+
 	foreach($a as $key => $val)
 		$a[$key] = trim($val);
 	
 	$period = sprintf('%d',$a['period']);
 
-	if($period < DISPOSABLE || $period > YEARLY)
-		$period = DISPOSABLE;
-
 	switch($period)
 	{
-		case DISPOSABLE:
+		case DAILY:
+			$at = 0;
+		break;
+		
+		case WEEKLY:
+			$at = sprintf('%d',$a['at']);
+			
+			if(chkconfig($CONFIG['phpui']['use_current_payday']) && $at==0)
+			{
+				$at = strftime('%u', time());
+			}
+			
+			if($at < 1 || $at > 7)
+				$error['at'] = trans('Incorrect day of week (1-7)!');
+		break;
+
+		case MONTHLY:
+			$at = sprintf('%d',$a['at']);
+			
+			if(chkconfig($CONFIG['phpui']['use_current_payday']) && $at==0)
+				$at = date('j', time());
+
+			if(!chkconfig($CONFIG['phpui']['use_current_payday']) 
+				&& $CONFIG['phpui']['default_monthly_payday']>0 && $at==0)
+			{
+				$at = $CONFIG['phpui']['default_monthly_payday'];
+			}
+			
+			$a['at'] = $at;
+			
+			if($at > 28 || $at < 1)
+				$error['at'] = trans('Incorrect day of month (1-28)!');
+		break;
+
+		case QUARTERLY:
+			if(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
+			{
+				$d = date('j', time());
+				$m = date('n', time());
+				$a['at'] = $d.'/'.$m;
+			}
+			elseif(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']))
+			{
+				$error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
+			}
+			else
+			{
+				list($d,$m) = split('/',$a['at']);
+			}
+			
+			if(!$error)
+			{
+				if($d>30 || $d<1 || ($d>28 && $m==2))
+					$error['at'] = trans('This month doesn\'t contain specified number of days');
+				if($m>3 || $m<1)
+					$error['at'] = trans('Incorrect month number (max.3)!');
+
+				$at = ($m-1) * 100 + $d;
+			}
+		break;
+
+		case HALFYEARLY:
+			if(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']) && $a['at'])
+			{
+				$error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
+			}
+			elseif(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
+			{
+				$d = date('j', time());
+				$m = date('n', time());
+				$a['at'] = $d.'/'.$m;
+			}
+			else
+			{
+				list($d,$m) = split('/',$a['at']);
+			}
+			
+			if(!$error)
+			{
+				if($d>30 || $d<1 || ($d>28 && $m==2))
+					$error['at'] = trans('This month doesn\'t contain specified number of days');
+				if($m>6 || $m<1)
+					$error['at'] = trans('Incorrect month number (max.6)!');
+
+				$at = ($m-1) * 100 + $d;
+			}
+		break;
+
+		case YEARLY:
+			if(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
+			{
+				$d = date('j', time());
+				$m = date('n', time());
+				$a['at'] = $d.'/'.$m;
+			}
+			elseif(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']))
+			{
+				$error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
+			}
+			else
+			{
+				list($d,$m) = split('/',$a['at']);
+			}
+			
+			if(!$error)
+			{
+				if($d>30 || $d<1 || ($d>28 && $m==2))
+					$error['at'] = trans('This month doesn\'t contain specified number of days');
+				if($m>12 || $m<1)
+					$error['at'] = trans('Incorrect month number');
+			
+				$ttime = mktime(12, 0, 0, $m, $d, 1990);
+				$at = date('z',$ttime) + 1;
+			}
+		break;
+
+		default: // DISPOSABLE
+			$period = DISPOSABLE;
 			
 			if($a['tariffid']!='0')
 			{
@@ -79,95 +193,6 @@ if($_GET['action'] == 'add' && isset($a))
 			else
 				$error['at'] = trans('Incorrect date format! Enter date in YYYY/MM/DD format!');
 		break;
-		
-		case DAILY:
-			$at = 0;
-		break;
-		
-		case WEEKLY:
-			$at = sprintf('%d',$a['at']);
-			
-			if(chkconfig($CONFIG['phpui']['use_current_payday']) && $at==0)
-			{
-				$at = strftime('%u', time());
-			}
-			
-			if($at < 1 || $at > 7)
-				$error['at'] = trans('Incorrect day of week (1-7)!');
-		break;
-
-		case MONTHLY:
-			$at = sprintf('%d',$a['at']);
-			
-			if(isset($CONFIG['phpui']['use_current_payday']) && chkconfig($CONFIG['phpui']['use_current_payday']) && $at==0)
-				$at = date('j', time());
-
-			if((!isset($CONFIG['phpui']['use_current_payday']) || !chkconfig($CONFIG['phpui']['use_current_payday'])) 
-				&& isset($CONFIG['phpui']['default_monthly_payday']) && $CONFIG['phpui']['default_monthly_payday']>0 && $at==0)
-			{
-				$at = $CONFIG['phpui']['default_monthly_payday'];
-			}
-			
-			$a['at'] = $at;
-			
-			if($at > 28 || $at < 1)
-				$error['at'] = trans('Incorrect day of month (1-28)!');
-		break;
-
-		case QUARTERLY:
-			if(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']) && $a['at'])
-			{
-				$error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
-			}
-			elseif(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
-			{
-				$d = date('j', time());
-				$m = date('n', time());
-				$a['at'] = $d.'/'.$m;
-			}
-			else
-			{
-				list($d,$m) = split('/',$a['at']);
-			}
-			
-			if(!$error)
-			{
-				if($d>30 || $d<1 || ($d>28 && $m==2))
-					$error['at'] = trans('This month doesn\'t contain specified number of days');
-				if($m>3 || $m<1)
-					$error['at'] = trans('Incorrect month number (max.3)!');
-
-				$at = ($m-1) * 100 + $d;
-			}
-		break;
-
-		case YEARLY:
-			if(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']) && $a['at'])
-			{
-				$error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
-			}
-			elseif(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
-			{
-				$d = date('j', time());
-				$m = date('n', time());
-				$a['at'] = $d.'/'.$m;
-			}
-			else
-			{
-				list($d,$m) = split('/',$a['at']);
-			}
-			
-			if(!$error)
-			{
-				if($d>30 || $d<1 || ($d>28 && $m==2))
-					$error['at'] = trans('This month doesn\'t contain specified number of days');
-				if($m>12 || $m<1)
-					$error['at'] = trans('Incorrect month number');
-			
-				$ttime = mktime(12, 0, 0, $m, $d, 1990);
-				$at = date('z',$ttime) + 1;
-			}
-		break;
 	}
 
 	if($a['datefrom'] == '')
@@ -247,6 +272,8 @@ if($_GET['action'] == 'add' && isset($a))
 					    ));
 		$SESSION->redirect('?'.$SESSION->get('backto'));
 	}
+
+	$SMARTY->assign('assignment', $a);
 }
 
 $customerinfo = $LMS->GetCustomer($_GET['id']);
@@ -263,7 +290,6 @@ $SMARTY->assign('othercustomergroups',$LMS->GetGroupNamesWithoutCustomer($_GET['
 $SMARTY->assign('customerinfo',$customerinfo);
 $SMARTY->assign('recover',($_GET['action'] == 'recover' ? 1 : 0));
 $SMARTY->assign('error', $error);
-$SMARTY->assign('assignment', $a);
 $SMARTY->display('customerinfo.html');
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
