@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customerassignmentsedit.php,v 1.21.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customerassignmentsedit.php,v 1.27 2009/01/13 07:45:48 alec Exp $
  */
 
 $customerid = $DB->GetOne('SELECT customerid FROM assignments WHERE id=?', array($_GET['id']));
@@ -45,12 +45,127 @@ if(isset($_POST['assignmentedit']))
 
 	$period = sprintf('%d',$a['period']);
 
-	if($period < DISPOSABLE || $period > YEARLY)
-		$period = DISPOSABLE;
-
 	switch($period)
 	{
-		case DISPOSABLE:
+		case DAILY:
+			$at = 0;
+		break;
+		
+		case WEEKLY:
+			$at = sprintf('%d',$a['at']);
+			
+			if(chkconfig($CONFIG['phpui']['use_current_payday']) && $at==0)
+			{
+				$at = strftime('%u', time());
+			}
+			
+			if($at < 1 || $at > 7)
+				$error['editat'] = trans('Incorrect day of week (1-7)!');
+		break;
+
+		case MONTHLY:
+			$at = sprintf('%d',$a['at']);
+			
+			if(isset($CONFIG['phpui']['use_current_payday']) && chkconfig($CONFIG['phpui']['use_current_payday']) && $at==0)
+			{
+				$at = date('j', time());
+			}
+			elseif(!chkconfig($CONFIG['phpui']['use_current_payday'])
+				 && $CONFIG['phpui']['default_monthly_payday']>0 && $at==0)
+			{
+				$at = $CONFIG['phpui']['default_monthly_payday'];
+			}
+			
+			$a['at'] = $at;
+			
+			if($at > 28 || $at < 1)
+				$error['editat'] = trans('Incorrect day of month (1-28)!');
+		break;
+
+		case QUARTERLY:
+			if(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
+			{
+				$d = date('j', time());
+				$m = date('n', time());
+				$a['at'] = $d.'/'.$m;
+			}
+			elseif(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']))
+			{
+				$error['editat'] = trans('Incorrect date format! Enter date in DD/MM format!');
+			}
+			else
+			{
+				list($d,$m) = split('/',$a['at']);
+			}
+			
+			if(!$error)
+			{
+				if($d>30 || $d<1 || ($d>28 && $m==2))
+					$error['editat'] = trans('This month doesn\'t contain specified number of days');
+				if($m>3 || $m<1)
+					$error['editat'] = trans('Incorrect month number (max.3)!');
+
+				$at = ($m-1) * 100 + $d;
+			}
+		break;
+
+		case HALFYEARLY:
+			if(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']) && $a['at'])
+			{
+				$error['editat'] = trans('Incorrect date format! Enter date in DD/MM format!');
+			}
+			elseif(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
+			{
+				$d = date('j', time());
+				$m = date('n', time());
+				$a['at'] = $d.'/'.$m;
+			}
+			else
+			{
+				list($d,$m) = split('/',$a['at']);
+			}
+			
+			if(!$error)
+			{
+				if($d>30 || $d<1 || ($d>28 && $m==2))
+					$error['editat'] = trans('This month doesn\'t contain specified number of days');
+				if($m>6 || $m<1)
+					$error['editat'] = trans('Incorrect month number (max.6)!');
+
+				$at = ($m-1) * 100 + $d;
+			}
+		break;
+
+		case YEARLY:
+			if(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
+			{
+				$d = date('j', time());
+				$m = date('n', time());
+				$a['at'] = $d.'/'.$m;
+			}
+			elseif(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']))
+			{
+				$error['editat'] = trans('Incorrect date format! Enter date in DD/MM format!');
+			}
+			else
+			{
+				list($d,$m) = split('/',$a['at']);
+			}
+			
+			if(!$error)
+			{
+				if($d>30 || $d<1 || ($d>28 && $m==2))
+					$error['editat'] = trans('This month doesn\'t contain specified number of days');
+				if($m>12 || $m<1)
+					$error['editat'] = trans('Incorrect month number');
+			
+				$ttime = mktime(12, 0, 0, $m, $d, 1990);
+				$at = date('z',$ttime) + 1;
+			}
+		break;
+
+		default: // DISPOSABLE
+                        $period = DISPOSABLE;
 			
 			if(isset($a['tariffid']) && $a['tariffid'] != '0')
 			{
@@ -73,95 +188,6 @@ if(isset($_POST['assignmentedit']))
 			else
 				$error['editat'] = trans('Incorrect date format! Enter date in YYYY/MM/DD format!');
 		break;
-
-		case DAILY:
-			$at = 0;
-		break;
-		
-		case WEEKLY:
-			$at = sprintf('%d',$a['at']);
-			
-			if(chkconfig($CONFIG['phpui']['use_current_payday']) && $at==0)
-			{
-				$at = strftime('%u', time());
-			}
-			
-			if($at < 1 || $at > 7)
-				$error['editat'] = trans('Incorrect day of week (1-7)!');
-		break;
-
-		case MONTHLY:
-			$at = sprintf('%d',$a['at']);
-			
-			if(isset($CONFIG['phpui']['use_current_payday']) && chkconfig($CONFIG['phpui']['use_current_payday']) && $at==0)
-				$at = date('j', time());
-
-			if((!isset($CONFIG['phpui']['use_current_payday']) || !chkconfig($CONFIG['phpui']['use_current_payday']))
-				 && isset($CONFIG['phpui']['default_monthly_payday']) && $CONFIG['phpui']['default_monthly_payday']>0 && $at==0)
-			{
-				$at = $CONFIG['phpui']['default_monthly_payday'];
-			}
-			
-			$a['at'] = $at;
-			
-			if($at > 28 || $at < 1)
-				$error['editat'] = trans('Incorrect day of month (1-28)!');
-		break;
-
-		case QUARTERLY:
-			if(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']) && $a['at'])
-			{
-				$error['editat'] = trans('Incorrect date format! Enter date in DD/MM format!');
-			}
-			elseif(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
-			{
-				$d = date('j', time());
-				$m = date('n', time());
-				$a['at'] = $d.'/'.$m;
-			}
-			else
-			{
-				list($d,$m) = split('/',$a['at']);
-			}
-			
-			if(!$error)
-			{
-				if($d>30 || $d<1 || ($d>28 && $m==2))
-					$error['editat'] = trans('This month doesn\'t contain specified number of days');
-				if($m>3 || $m<1)
-					$error['editat'] = trans('Incorrect month number (max.3)!');
-
-				$at = ($m-1) * 100 + $d;
-			}
-		break;
-
-		case YEARLY:
-			if(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']) && $a['at'])
-			{
-				$error['editat'] = trans('Incorrect date format! Enter date in DD/MM format!');
-			}
-			elseif(chkconfig($CONFIG['phpui']['use_current_payday']) && !$a['at'])
-			{
-				$d = date('j', time());
-				$m = date('n', time());
-				$a['at'] = $d.'/'.$m;
-			}
-			else
-			{
-				list($d,$m) = split('/',$a['at']);
-			}
-			
-			if(!$error)
-			{
-				if($d>30 || $d<1 || ($d>28 && $m==2))
-					$error['editat'] = trans('This month doesn\'t contain specified number of days');
-				if($m>12 || $m<1)
-					$error['editat'] = trans('Incorrect month number');
-			
-				$ttime = mktime(12, 0, 0, $m, $d, 1990);
-				$at = date('z',$ttime) + 1;
-			}
-		break;
 	}
 
 	if($a['datefrom'] == '')
@@ -276,6 +302,9 @@ else
 		case QUARTERLY:
 			$a['at'] = sprintf('%02d/%02d',$a['at']%100,$a['at']/100+1);
 			break;
+		case HALFYEARLY:
+			$a['at'] = sprintf('%02d/%02d',$a['at']%100,$a['at']/100+1);
+			break;
 		case YEARLY:
 			$a['at'] = date('d/m',($a['at']-1)*86400);
 			break;
@@ -291,7 +320,7 @@ else
 
 $expired = isset($_GET['expired']) ? $_GET['expired'] : false;
 
-$layout['pagetitle'] = trans('Customer Charging Edit: $0',$LMS->GetCustomerName($customerid));
+$layout['pagetitle'] = trans('Customer Charging Edit: $0', '<A href="?m=customerinfo&id='.$customerid.'">'.$LMS->GetCustomerName($customerid).'</A>');
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
