@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customerbalanceok.php,v 1.11.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customerbalanceok.php,v 1.15 2009/01/13 07:45:48 alec Exp $
  */
 
 $customerid = $_GET['id'];
@@ -32,12 +32,20 @@ if($LMS->CustomerExists($customerid))
 
 	if($balance<0)
 	{
+		$DB->BeginTrans();
+
 		$DB->Execute('INSERT INTO cash (time, type, userid, value, customerid, comment)
 			VALUES (?NOW?, 1, ?, ?, ?, ?)', 
 			array($AUTH->id, 
 				str_replace(',','.', $balance*-1),
 				$customerid,
 				trans('Accounted')));
+	
+		$DB->Execute('UPDATE documents SET closed = 1 
+			WHERE customerid = ? AND type IN (?, ?) AND closed = 0',
+			array($customerid, DOC_INVOICE, DOC_CNOTE));
+
+		$DB->CommitTrans();
 	}
 }
 
