@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,30 +21,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customeredit.php,v 1.18.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customeredit.php,v 1.35 2009/01/13 07:45:48 alec Exp $
  */
 
 $action = isset($_GET['action']) ? $_GET['action'] : '';
+$exists = $LMS->CustomerExists($_GET['id']);
 
-if($LMS->CustomerExists($_GET['id']) < 0 && $action != 'recover')
+if($exists < 0 && $action != 'recover')
 {
 	$SESSION->redirect('?m=customerinfo&id='.$_GET['id']);
 }
-elseif(! $LMS->CustomerExists($_GET['id']))
+elseif(!$exists)
 {
 	$SESSION->redirect('?m=customerlist');
 }
-elseif($action == 'customergroupdelete')
-{
-	$LMS->CustomerAssignmentDelete(array('customerid' => $_GET['id'], 'customergroupid' => $_GET['customergroupid']));
-	$SESSION->redirect('?m=customerinfo&id='.$_GET['id']);
-}
-elseif($action == 'customergroupadd')
-{
-	if ($LMS->CustomerGroupExists($_POST['customergroupid']))
-		$LMS->CustomerAssignmentAdd(array('customerid' => $_GET['id'], 'customergroupid' => $_POST['customergroupid']));
-	$SESSION->redirect('?m=customerinfo&id='.$_GET['id']);
-}
 elseif(isset($_POST['customerdata']) && !isset($_GET['newcontact']))
 {
 	$customerdata = $_POST['customerdata'];
@@ -58,11 +48,17 @@ elseif(isset($_POST['customerdata']) && !isset($_GET['newcontact']))
 	if($customerdata['address']=='')
 		$error['address'] = trans('Address required!');
 
-	if($customerdata['ten'] !='' && !check_ten($customerdata['ten']))
-		$error['ten'] = trans('Incorrect Tax Exempt Number!');
+	if($customerdata['ten'] !='' && !check_ten($customerdata['ten']) && !isset($customerdata['tenwarning']))
+	{
+		$error['ten'] = trans('Incorrect Tax Exempt Number! If you are sure you want to accept it, then click "Submit" again.');
+		$tenwarning = 1;
+	}
 
-	if($customerdata['ssn'] != '' && !check_ssn($customerdata['ssn']))
-		$error['ssn'] = trans('Incorrect Social Security Number!');
+	if($customerdata['ssn'] != '' && !check_ssn($customerdata['ssn']) && !isset($customerdata['ssnwarning']))
+	{
+		$error['ssn'] = trans('Incorrect Social Security Number! If you are sure you want to accept it, then click "Submit" again.');
+		$ssnwarning = 1;
+	}
 
 	if($customerdata['regon'] != '' && !check_regon($customerdata['regon']))
 		$error['regon'] = trans('Incorrect Business Registration Number!');
@@ -70,8 +66,11 @@ elseif(isset($_POST['customerdata']) && !isset($_GET['newcontact']))
 	if($customerdata['icn'] != '' && !check_icn($customerdata['icn']))
 		$error['icn'] = trans('Incorrect Identity Card Number!');
 
-	if($customerdata['zip'] !='' && !check_zip($customerdata['zip']))
-		$error['zip'] = trans('Incorrect ZIP code!');
+	if($customerdata['zip'] !='' && !check_zip($customerdata['zip']) && !isset($customerdata['zipwarning']))
+	{
+		$error['zip'] = trans('Incorrect ZIP code! If you are sure you want to accept it, then click "Submit" again.');
+		$zipwarning = 1;
+	}
 
 	if($customerdata['email']!='' && !check_email($customerdata['email']))
 		$error['email'] = trans('Incorrect email!');
@@ -119,6 +118,19 @@ elseif(isset($_POST['customerdata']) && !isset($_GET['newcontact']))
 
 	if(!$error)
 	{
+		if($customerdata['cutoffstop'])
+			$customerdata['cutoffstop'] = mktime(23,59,59,date('m'), date('d') + $customerdata['cutoffstop']);
+		
+		$consent = $DB->GetOne('SELECT consentdate FROM customers WHERE id = ?', array($customerdata['id']));
+		
+		if(!isset($customerdata['consentdate']))
+			$customerdata['consentdate'] = 0;
+		elseif($consent)
+			$customerdata['consentdate'] = $consent;
+
+		if(!isset($customerdata['divisionid']))
+			$customerdata['divisionid'] = 0;
+		
 		$LMS->CustomerUpdate($customerdata);
 		
 		$DB->Execute('DELETE FROM imessengers WHERE customerid = ?', array($customerdata['id']));
@@ -133,6 +145,18 @@ elseif(isset($_POST['customerdata']) && !isset($_GET['newcontact']))
 				$DB->Execute('INSERT INTO customercontacts (customerid, phone, name)
 					VALUES(?, ?, ?)', array($customerdata['id'], $contact['phone'], $contact['name']));
 		
+		if($customerdata['zip'] && $customerdata['stateid'])
+		{
+			$cstate = $DB->GetOne('SELECT stateid FROM zipcodes WHERE zip = ?', array($customerdata['zip']));
+			
+			if($cstate === NULL)
+				$DB->Execute('INSERT INTO zipcodes (stateid, zip) VALUES (?, ?)',
+					array($customerdata['stateid'], $customerdata['zip']));
+			elseif($cstate != $customerdata['stateid'])
+				$DB->Execute('UPDATE zipcodes SET stateid = ? WHERE zip = ?',
+					array($customerdata['stateid'], $customerdata['zip']));
+		}
+
 		$SESSION->redirect('?m=customerinfo&id='.$customerdata['id']);
 	}
 	else
@@ -146,22 +170,31 @@ elseif(isset($_POST['customerdata']) && !isset($_GET['newcontact']))
 		$customerinfo['moddateh'] = $olddata['moddateh'];
 		$customerinfo['customername'] = $olddata['customername'];
 		$customerinfo['balance'] = $olddata['balance'];
-		
+		$customerinfo['stateid'] = isset($olddata['stateid']) ? $olddata['stateid'] : 0;
+		$customerinfo['zipwarning'] = empty($zipwarning) ? 0 : 1;
+		$customerinfo['tenwarning'] = empty($tenwarning) ? 0 : 1;
+		$customerinfo['ssnwarning'] = empty($ssnwarning) ? 0 : 1;
+
 		$SMARTY->assign('error',$error);
 	}
 }
 else
 {
-	
 	$customerinfo = $LMS->GetCustomer($_GET['id']);
 
+	if($customerinfo['cutoffstop'] > mktime(0,0,0))
+		$customerinfo['cutoffstop'] = floor(($customerinfo['cutoffstop'] - mktime(23,59,59))/86400);
+	else
+		$customerinfo['cutoffstop'] = 0;
+
 	if($customerinfo['messengers'])
 		foreach($customerinfo['messengers'] as $idx => $val)
 			$customerinfo['uid'][$idx] = $val['uid'];
 
 	if(!$customerinfo['contacts'])
+	{
 		$customerinfo['contacts'][] = array();
-
+	}
 	elseif(isset($_POST['customerdata']) && isset($_GET['newcontact']))
 	{
     		$customerdata = $_POST['customerdata'];
@@ -174,8 +207,10 @@ $layout['pagetitle'] = trans('Customer Edit: $0',$customerinfo['customername']);
 
 if(isset($CONFIG['phpui']['ewx_support']) && chkconfig($CONFIG['phpui']['ewx_support']))
 {
-        $SMARTY->assign('ewx_channelid', $DB->GetOne('SELECT MAX(channelid) FROM ewx_stm_nodes, nodes
-                                        WHERE nodeid = nodes.id AND ownerid = ?', array($customerinfo['id'])));
+        $SMARTY->assign('ewx_channelid',
+		$DB->GetOne('SELECT MAX(channelid) FROM ewx_stm_nodes, nodes
+                        WHERE nodeid = nodes.id AND ownerid = ?',
+			array($customerinfo['id'])));
 }
 
 $SMARTY->assign('customernodes',$LMS->GetCustomerNodes($customerinfo['id']));
@@ -184,9 +219,13 @@ $SMARTY->assign('tariffs',$LMS->GetTariffs());
 $SMARTY->assign('assignments',$LMS->GetCustomerAssignments($_GET['id']));
 $SMARTY->assign('customergroups',$LMS->CustomergroupGetForCustomer($_GET['id']));
 $SMARTY->assign('othercustomergroups',$LMS->GetGroupNamesWithoutCustomer($_GET['id']));
+$SMARTY->assign('allnodegroups', $LMS->GetNodeGroupNames());
 $SMARTY->assign('documents',$LMS->GetDocuments($_GET['id'], 10));
 $SMARTY->assign('customerinfo',$customerinfo);
 $SMARTY->assign('taxeslist',$LMS->GetTaxes());
+$SMARTY->assign('cstateslist',$LMS->GetCountryStates());
+$SMARTY->assign('countrieslist',$LMS->GetCountries());
+$SMARTY->assign('divisions', $DB->GetAll('SELECT id, shortname, status FROM divisions ORDER BY shortname'));
 $SMARTY->assign('recover',($action == 'recover' ? 1 : 0));
 $SMARTY->display('customeredit.html');
 
