@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customergroupedit.php,v 1.6.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customergroupedit.php,v 1.11 2009/01/13 07:45:49 alec Exp $
  */
 
 if(!$LMS->CustomergroupExists($_GET['id']))
@@ -33,35 +33,10 @@ if(isset($_POST['customerassignments']))
 {
 	$oper = $_POST['oper'];
 	$customerassignments = $_POST['customerassignments'];
-	
-	if(isset($customerassignments['gmcustomerid']) && $oper=='0')
-	{
-		$assignment['customergroupid'] = $_GET['id'];
-		foreach($customerassignments['gmcustomerid'] as $value)
-		{
-			$assignment['customerid'] = $value;
-			$LMS->CustomerassignmentDelete($assignment);
-		}
-		$SESSION->redirect('?'.$SESSION->get('backto'));
-	}
-
-	if (isset($customerassignments['mcustomerid']) && $oper=='1')
-	{
-		$assignment['customergroupid'] = $_GET['id'];
-		foreach($customerassignments['mcustomerid'] as $value)
-		{
-			$assignment['customerid'] = $value;
-			if(! $LMS->CustomerassignmentExist($assignment['customergroupid'],$value))
-				$LMS->CustomerassignmentAdd($assignment);
-		}
-		$SESSION->redirect('?'.$SESSION->get('backto'));
-	}
-
 	if (isset($customerassignments['membersnetid']) && $oper=='2')
 	{
 		$SESSION->redirect('?'.ereg_replace('&membersnetid=[0-9]+', '', $SESSION->get('backto')).'&membersnetid='.$customerassignments['membersnetid']);
 	}
-
 	if (isset($customerassignments['othersnetid']) && $oper=='3')
 	{
 		$SESSION->redirect('?'.ereg_replace('&othersnetid=[0-9]+', '', $SESSION->get('backto')).'&othersnetid='.$customerassignments['othersnetid']);
@@ -112,6 +87,7 @@ $SMARTY->assign('error', $error);
 $SMARTY->assign('customers', $customers);
 $SMARTY->assign('customerscount', sizeof($customers));
 $SMARTY->assign('networks', $LMS->GetNetworks());
+$SMARTY->assign('customergroups',$LMS->CustomergroupGetAll());
 $SMARTY->assign('membersnetid', isset($membersnetid) ? $membersnetid : 0);
 $SMARTY->assign('othersnetid', isset($othersnetid) ? $othersnetid : 0);
 $SMARTY->display('customergroupedit.html');
