@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customergrouplist.php,v 1.5.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customergrouplist.php,v 1.9 2009/01/13 07:45:49 alec Exp $
  */
 
-$layout['pagetitle'] = trans('Group List');
+$layout['pagetitle'] = trans('Customer Groups List');
 
 $customergrouplist = $LMS->CustomergroupGetList();
 
