@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,14 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customerinfoshort.php,v 1.4.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customerinfoshort.php,v 1.9 2009/01/13 07:45:49 alec Exp $
  */
 
+$id = intval($_GET['id']);
+
+$customerinfo = $LMS->GetCustomer($id, true);
+$customergroups = $LMS->CustomergroupGetForCustomer($id);
+
+$SMARTY->assign('customergroups', $customergroups);
+$SMARTY->assign('customerinfo', $customerinfo);
 
-$customerinfo = $LMS->GetCustomer($_GET['id']);
-$customergroups = $LMS->CustomergroupGetForCustomer($_GET['id']);
-$SMARTY->assign('customergroups',$customergroups);
-$SMARTY->assign('customerinfo',$customerinfo);
 $SMARTY->display('customerinfoshort.html');
 
 ?>
