@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customerprint.php,v 1.9.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customerprint.php,v 1.17 2009/01/13 07:45:49 alec Exp $
  */
 
 $type = isset($_GET['type']) ? $_GET['type'] : '';
@@ -31,42 +31,69 @@ switch($type)
 	case 'customerlist':
 
 		$date = 0;
+		$search['type'] = $_POST['type'];
+		$search['linktype'] = $_POST['linktype'];
 		
 		if($_POST['day'])
 		{
 			list($year, $month, $day) = split('/',$_POST['day']);
 			$date = mktime(0,0,0,$month,$day+1,$year);
 		}
+
+		if($_POST['docfrom'])
+		{
+			list($year, $month, $day) = split('/', $_POST['docfrom']);
+			$docfrom = mktime(0,0,0,$month,$day,$year);
+		}
+		else
+			$docfrom = 0;
+
+		if($_POST['docto'])
+		{
+			list($year, $month, $day) = split('/', $_POST['docto']);
+			$docto = mktime(23,59,59,$month,$day,$year);
+		}
+		else
+			$docto = 0;
 		
+		if(!empty($_POST['doctype']) || !empty($docfrom) || !empty($docto))
+		{
+			$search['doctype'] = intval($_POST['doctype']).':'.$docfrom.':'.$docto;
+		}
+		if(!empty($_POST['stateid']))
+		{
+			$search['stateid'] = intval($_POST['stateid']);
+		}
+
 		switch($_POST['filter'])
 		{
 			case 0:
 				$layout['pagetitle'] = trans('Customers List $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : ''));
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], NULL, $date));
+				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], $search, $date, 'AND', $_POST['nodegroup']));
 			break;
 			case 1:
 				$layout['pagetitle'] = trans('Interested Customers List');
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], NULL, NULL, NULL, $date));
+				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], NULL, NULL, $search, $date));
 			break;
 			case 2:
 				$layout['pagetitle'] = trans('List of awaiting customers');
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], NULL, NULL, NULL, $date));
+				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], NULL, NULL, $search, $date));
 			break;
 			case 3:
 				$layout['pagetitle'] = trans('List of Connected Customers $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : '')); 
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], NULL, $date));
+				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], $search, $date, 'AND', $_POST['nodegroup']));
 			break;
 			case 5:
 				$layout['pagetitle'] = trans('List of Disconnected Customers $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : ''));
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], NULL, $date));
+				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], $search, $date, 'AND', $_POST['nodegroup']));
 			break;
 			case 6:
 				$layout['pagetitle'] = trans('Indebted Customers List $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : ''));
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], NULL, $date));
+				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], $search, $date, 'AND', $_POST['nodegroup']));
 			break;
 			case -1:
 				$layout['pagetitle'] = trans('Customers Without Nodes List $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : ''));
-				if($customerlist = $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], NULL, NULL, $_POST['customergroup'], NULL, $date))
+				if($customerlist = $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], NULL, NULL, $_POST['customergroup'], $search, $date))
 				{
 					unset($customerlist['total']);
 					unset($customerlist['state']);
@@ -174,6 +201,8 @@ switch($type)
 		$SMARTY->assign('months', $months);
 		$SMARTY->assign('networks', $LMS->GetNetworks());
 		$SMARTY->assign('customergroups', $LMS->CustomergroupGetAll());
+		$SMARTY->assign('nodegroups', $LMS->GetNodeGroupNames());
+		$SMARTY->assign('cstateslist', $LMS->GetCountryStates());
 		$SMARTY->assign('printmenu', 'customer');
 		$SMARTY->display('printindex.html');
 	break;
