@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customerwarn.php,v 1.8.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: customerwarn.php,v 1.14 2009/01/13 07:45:49 alec Exp $
  */
 
 $setwarnings = isset($_POST['setwarnings']) ? $_POST['setwarnings'] : array();
@@ -30,8 +30,8 @@ if(isset($setwarnings['mcustomerid']))
 {
 	$warnon = isset($setwarnings['warnon']) ? $setwarnings['warnon'] : FALSE;
 	$warnoff = isset($setwarnings['warnoff']) ? $setwarnings['warnoff'] : FALSE;
-	$message = isset($setwarnings['message']) ? $setwarnings['message'] : '';
-	
+	$message = isset($setwarnings['message']) ? $setwarnings['message'] : NULL;
+
 	foreach($setwarnings['mcustomerid'] as $uid)
 	{
 		if($warnon)
@@ -40,25 +40,25 @@ if(isset($setwarnings['mcustomerid']))
 		if($warnoff) 
 			$LMS->NodeSetWarnU($uid, FALSE);
 
-		if($message)
+		if(isset($message))
 			$DB->Execute('UPDATE customers SET message=? WHERE id=?', array($message, $uid));
 	}
 
 	$SESSION->save('warnmessage', $message);
 	$SESSION->save('warnon', $warnon);
 	$SESSION->save('warnoff', $warnoff);
-	
+
 	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
 if(isset($_GET['search']))
 {
 	$SESSION->restore('customersearch', $customersearch);
-	$SESSION->restore('uslo', $o);
-	$SESSION->restore('usls', $s);
-	$SESSION->restore('usln', $n);
-	$SESSION->restore('uslg', $g);
-	$SESSION->restore('uslk', $k);
+	$SESSION->restore('cslo', $o);
+	$SESSION->restore('csls', $s);
+	$SESSION->restore('csln', $n);
+	$SESSION->restore('cslg', $g);
+	$SESSION->restore('cslk', $k);
 
 	$customerlist = $LMS->GetCustomerList($o, $s, $n, $g, $customersearch, NULL, $k);
 	
@@ -79,7 +79,7 @@ if(isset($_GET['search']))
 	$SMARTY->assign('selected', $selected);
 }
 
-$layout['pagetitle'] = trans('Warnings');
+$layout['pagetitle'] = trans('Messages');
 
 $customerlist = $DB->GetAllByKey('SELECT c.id AS id, MAX(warning) AS warning, '.
 		    $DB->Concat('UPPER(lastname)',"' '",'c.name').' AS customername 
