@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: daemoninstanceadd.php,v 1.12.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: daemoninstanceadd.php,v 1.17 2009/01/13 07:45:49 alec Exp $
  */
 
 $instance = isset($_POST['instance']) ? $_POST['instance'] : NULL;
@@ -65,11 +65,20 @@ if($instance)
 					    $instance['crontab'],
 					    $instance['priority']));
 		
+		if($instance['id'])
+		{
+			$id = $DB->GetLastInsertId('daemoninstances');
+			$DB->Execute('INSERT INTO daemonconfig (var, description, value, instanceid)
+					SELECT var, description, value, ? FROM daemonconfig
+					WHERE instanceid = ?', array($id, $instance['id']));
+		}
+		
 		if(!isset($instance['reuse']))
 		{
 			$SESSION->redirect('?m=daemoninstancelist&id='.$instance['hostid']);
 		}
 		
+		unset($instance['id']);
 		unset($instance['name']);
 		unset($instance['module']);
 		unset($instance['crontab']);
@@ -77,16 +86,22 @@ if($instance)
 		unset($instance['description']);
 	}
 }	
+elseif(isset($_GET['id']))
+{
+	$instance = $DB->GetRow('SELECT * FROM daemoninstances
+			WHERE id = ?', array(intval($_GET['id'])));
+}
+
+$instance['hostid'] = isset($instance['hostid']) ? $instance['hostid'] : $_GET['hostid'];
 
 $layout['pagetitle'] = trans('New Instance');
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$instance['hostid'] = isset($instance['hostid']) ? $instance['hostid'] : $_GET['hostid'];
-
 $SMARTY->assign('error', $error);
 $SMARTY->assign('instance', $instance);
 $SMARTY->assign('hosts', $DB->GetAll('SELECT id, name FROM hosts ORDER BY name'));
+
 $SMARTY->display('daemoninstanceadd.html');
 
 ?>
