@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: daemoninstanceedit.php,v 1.13.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: daemoninstanceedit.php,v 1.17 2009/01/13 07:45:49 alec Exp $
  */
 
 $instance = $DB->GetRow('SELECT id, name, hostid, description, module, crontab, priority, disabled FROM daemoninstances WHERE id=?', array($_GET['id']));
@@ -70,7 +70,7 @@ if(isset($_POST['instance']))
 					    $instedit['disabled'],
 					    $instedit['id']));
 		
-		$SESSION->redirect('?m=daemoninstancelist&id='.$instedit['hostid']);
+		$SESSION->redirect('?m=daemoninstancelist');
 	}
 }	
 elseif(isset($_GET['statuschange']))
@@ -79,7 +79,7 @@ elseif(isset($_GET['statuschange']))
 		$DB->Execute('UPDATE daemoninstances SET disabled=0 WHERE id=?', array($_GET['id']));
 	else
 		$DB->Execute('UPDATE daemoninstances SET disabled=1 WHERE id=?', array($_GET['id']));
-	$SESSION->redirect('?m=daemoninstancelist&id='.$instance['hostid']);
+	$SESSION->redirect('?m=daemoninstancelist');
 }
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
