@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: daemoninstancelist.php,v 1.9.2.1 2007/08/17 13:15:22 alec Exp $
+ *  $Id: daemoninstancelist.php,v 1.13 2009/01/13 07:45:49 alec Exp $
  */
 
 function GetInstanceList($hostid)
@@ -39,8 +39,12 @@ function GetInstanceList($hostid)
 
 $layout['pagetitle'] = trans('Instances List');
 
-$hostid = isset($_GET['id']) ? $_GET['id'] : 0;
-
+if(!isset($_GET['id']))
+        $SESSION->restore('dilh', $hostid);
+else
+        $hostid = $_GET['id'];
+$SESSION->save('dilh', $hostid);
+		
 $instancelist = GetInstanceList($hostid);
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
