@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: documentadd.php,v 1.26.2.1 2007/08/17 13:15:23 alec Exp $
+ *  $Id: documentadd.php,v 1.36 2009/01/24 09:38:55 alec Exp $
  */
 
 $_DOC_DIR = DOC_DIR;
@@ -35,7 +35,7 @@ function plugin($template, $customer)
 
 	$result = '';
 	
-	// read template informations
+	// read template information
 	@include(DOC_DIR.'/templates/'.$template.'/info.php');
 	// call plugin
 	@include(DOC_DIR.'/templates/'.$engine['name'].'/'.$engine['plugin'].'.php');
@@ -67,7 +67,7 @@ if(isset($_POST['document']))
 		$SESSION->redirect('?'.$SESSION->get('backto'));
 	}
 	
-	$document['customerid'] = $_POST['customerid'] ? $_POST['customerid'] : $_POST['customer'];
+	$document['customerid'] = isset($_POST['customerid']) ? intval($_POST['customerid']) : intval($_POST['customer']);
 	
 	if(!$LMS->CustomerExists(intval($document['customerid'])))
 		$error['customer'] = trans('Customer not selected!');
@@ -78,10 +78,21 @@ if(isset($_POST['document']))
 	if(!$document['title'])
 		$error['title'] = trans('Document title is required!');
 
-	if($document['number'] == '')
+
+	// check if selected customer can use selected numberplan
+        if($document['numberplanid'] && $document['customerid']
+	        && !$DB->GetOne('SELECT 1 FROM numberplanassignments
+	                WHERE planid = ? AND divisionid IN (SELECT divisionid
+				FROM customers WHERE id = ?)', array($document['numberplanid'], $document['customerid'])))
+	{
+	        $error['number'] = trans('Selected numbering plan doesn\'t match customer\'s division!');
+	}
+	// check number
+	elseif($document['number'] == '')
 	{
 		$tmp = $LMS->GetNewDocumentNumber($document['type'], $document['numberplanid']);
 		$document['number'] = $tmp ? $tmp : 0;
+		$autonumber = true;
 	}
 	elseif(!eregi('^[0-9]+$', $document['number']))
     		$error['number'] = trans('Document number must be an integer!');
@@ -135,7 +146,7 @@ if(isset($_POST['document']))
 	elseif($document['templ'])
 	{
 		$result = '';
-		// read template informations
+		// read template information
 		include(DOC_DIR.'/templates/'.$document['templ'].'/info.php');
 		// set some variables (needed in e.g. plugin)
 		$SMARTY->assign_by_ref('document', $document);
@@ -189,36 +200,38 @@ if(isset($_POST['document']))
 		
 		$DB->BeginTrans();
 		
-		$DB->Execute('INSERT INTO documents (type, number, numberplanid, cdate, customerid, userid, name, address, zip, city, ten, ssn, closed)
-				VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)',
-				array(	$document['type'],
-					$document['number'],
-					$document['numberplanid'],
-					$time,
-					$document['customerid'],
-					$AUTH->id,
-					trim($customer['lastname'].' '.$customer['name']),
-					$customer['address'] ? $customer['address'] : '',
-					$customer['zip'] ? $customer['zip'] : '',
-					$customer['city'] ? $customer['city'] : '',
-					$customer['ten'] ? $customer['ten'] : '',
-					$customer['ssn'] ? $customer['ssn'] : '',
-					isset($document['closed']) ? 1 : 0
-					));
+		$DB->Execute('INSERT INTO documents (type, number, numberplanid, cdate, 
+			customerid, userid, name, address, zip, city, ten, ssn, divisionid, closed)
+			VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)',
+			array(	$document['type'],
+				$document['number'],
+				$document['numberplanid'],
+				$time,
+				$document['customerid'],
+				$AUTH->id,
+				trim($customer['lastname'].' '.$customer['name']),
+				$customer['address'] ? $customer['address'] : '',
+				$customer['zip'] ? $customer['zip'] : '',
+				$customer['city'] ? $customer['city'] : '',
+				$customer['ten'] ? $customer['ten'] : '',
+				$customer['ssn'] ? $customer['ssn'] : '',
+				$customer['divisionid'],
+				isset($document['closed']) ? 1 : 0
+			));
 		
 		$docid = $DB->GetLastInsertID('documents');
 
 		$DB->Execute('INSERT INTO documentcontents (docid, title, fromdate, todate, filename, contenttype, md5sum, description)
-				VALUES (?, ?, ?, ?, ?, ?, ?, ?)',
-				array(	$docid,
-					$document['title'],
-					$document['fromdate'],
-					$document['todate'],
-					$document['filename'],
-					$document['contenttype'],
-					$document['md5sum'],
-					$document['description']
-					));
+			VALUES (?, ?, ?, ?, ?, ?, ?, ?)',
+			array(	$docid,
+				$document['title'],
+				$document['fromdate'],
+				$document['todate'],
+				$document['filename'],
+				$document['contenttype'],
+				$document['md5sum'],
+				$document['description']
+			));
 
 		// template post-action
 		if(isset($engine['post-action']) && file_exists(DOC_DIR.'/templates/'.$engine['name'].'/'.$engine['post-action'].'.php'))
@@ -228,19 +241,24 @@ if(isset($_POST['document']))
 		
 		if(!isset($document['reuse']))
 		{
-			$SESSION->redirect('?m=documentlist&c='.$document['customerid'].(isset($_GET['print']) ? '&docid='.$docid : ''));
+			if(isset($_GET['print']))
+				$SESSION->save('documentprint', $docid);
+			
+			$SESSION->redirect('?m=documentlist&c='.$document['customerid']);
 		}
 		
 		unset($document['title']);
 		unset($document['number']);
 		unset($document['description']);
-		unset($document['datefrom']);
-		unset($document['dateto']);
+		unset($document['fromdate']);
+		unset($document['todate']);
 	}
 	else
 	{
 		$document['fromdate'] = $oldfromdate;
 		$document['todate'] = $oldtodate;
+		if(isset($autonumber))
+			$document['number'] = '';
 	}
 }
 else
