@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: documentlist.php,v 1.13.2.1 2007/08/17 13:15:23 alec Exp $
+ *  $Id: documentlist.php,v 1.18 2009/01/13 07:45:50 alec Exp $
  */
 
 function GetDocumentList($order='cdate,asc', $type=NULL, $customer=NULL)
@@ -37,27 +37,32 @@ function GetDocumentList($order='cdate,asc', $type=NULL, $customer=NULL)
 	switch($order)
 	{
 		case 'type':
-			$sqlord = ' ORDER BY type '.$direction.', documents.name';
+			$sqlord = ' ORDER BY d.type '.$direction.', d.name';
 		break;
 		case 'title':
-			$sqlord = ' ORDER BY title '.$direction.', documents.name';
+			$sqlord = ' ORDER BY title '.$direction.', d.name';
 		break;
 		case 'customer':
-			$sqlord = ' ORDER BY documents.name '.$direction.', title';
+			$sqlord = ' ORDER BY d.name '.$direction.', title';
 		break;
 		default:
-			$sqlord = ' ORDER BY cdate '.$direction.', documents.name';
+			$sqlord = ' ORDER BY d.cdate '.$direction.', d.name';
 		break;
 	}
 
-	$list = $DB->GetAll('SELECT docid, number, type, title, cdate, fromdate, todate, description, 
-				filename, md5sum, contenttype, template, closed, documents.name, customerid
-                	FROM documentcontents, documents
-		        LEFT JOIN numberplans ON (numberplanid = numberplans.id)
-			LEFT JOIN customersview c ON (customerid = c.id)
-			WHERE documents.id = documentcontents.docid '
-			.($customer ? 'AND customerid = '.$customer : '')
-			.($type ? ' AND type = '.$type : '')
+	$list = $DB->GetAll('SELECT docid, d.number, d.type, title, d.cdate, fromdate, todate, description, 
+				filename, md5sum, contenttype, template, d.closed, d.name, d.customerid
+                	FROM documentcontents
+			JOIN documents d ON (d.id = documentcontents.docid)
+		        LEFT JOIN numberplans ON (d.numberplanid = numberplans.id)
+			LEFT JOIN (
+			        SELECT DISTINCT a.customerid FROM customerassignments a
+				JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
+				WHERE e.userid = lms_current_user()
+			) e ON (e.customerid = d.customerid)
+			WHERE e.customerid IS NULL '
+			.($customer ? 'AND d.customerid = '.$customer : '')
+			.($type ? ' AND d.type = '.$type : '')
 			.$sqlord);
 
 	$list['total'] = sizeof($list);
@@ -104,13 +109,18 @@ $start = ($page - 1) * $pagelimit;
 $layout['pagetitle'] = trans('Documents List');
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
+if($docid = $SESSION->get('documentprint'))
+{
+	$SMARTY->assign('docid', $docid);
+	$SESSION->remove('documentprint');
+}
+
 $SMARTY->assign('customerlist', $LMS->GetCustomerNames());
 $SMARTY->assign('documentlist', $documentlist);
 $SMARTY->assign('pagelimit', $pagelimit);
 $SMARTY->assign('page', $page);
 $SMARTY->assign('start', $start);
 $SMARTY->assign('listdata', $listdata);
-$SMARTY->assign('docid', isset($_GET['docid']) ? $_GET['docid'] : 0);
 $SMARTY->display('documentlist.html');
 
 ?>
