@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: domainadd.php,v 1.13.2.1 2007/08/17 13:15:23 alec Exp $
+ *  $Id: domainadd.php,v 1.18 2009/01/13 07:45:50 alec Exp $
  */
 
 function GetDomainIdByName($name)
@@ -46,8 +46,25 @@ if(isset($_POST['domainadd']))
 	
 	if($domainadd['name'] == '')
 		$error['name'] = trans('Domain name is required!');
+	elseif(!ereg("^[a-z0-9._-]+$", $domainadd['name']))
+                $error['name'] = trans('Domain name contains forbidden characters!');	
 	elseif(GetDomainIdByName($domainadd['name']))
 		$error['name'] = trans('Domain with specified name exists!');
+
+	if($domainadd['ownerid'])
+	{
+		$limits = $LMS->GetHostingLimits($domainadd['ownerid']);
+		
+		if($limits['domain_limit'] !== NULL) 
+		{
+			if($limits['domain_limit'] > 0)
+				$cnt = $DB->GetOne('SELECT COUNT(*) FROM domains WHERE ownerid = ?', 
+					array($domainadd['ownerid']));
+
+			if($limits['domain_limit'] == 0 || $limits['domain_limit'] <= $cnt)
+				$error['ownerid'] = trans('Exceeded domains limit of selected customer ($0)!', $limits['domain_limit']);
+		}
+	}
 	
 	if(!$error)
 	{
