@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,23 +21,29 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: domaindel.php,v 1.10.2.1 2007/08/17 13:15:23 alec Exp $
+ *  $Id: domaindel.php,v 1.14 2009/01/13 07:45:50 alec Exp $
  */
 
 $id = $_GET['id'];
 
 if($id && $_GET['is_sure']=='1')
 {
+	$DB->BeginTrans();
+
 	if($DB->Execute('DELETE FROM domains WHERE id = ?', array($id)))
 	{
-		if($accounts = $DB->GetCol('SELECT id FROM passwd WHERE domainid = ?', array($id)))
-		{
-			foreach($accounts as $aid)
-				$DB->Execute('DELETE FROM aliases WHERE accountid = ?', array($aid));
-		
-			$DB->Execute('DELETE FROM passwd WHERE domainid = ?', array($id));
-		}
+		$DB->Execute('DELETE FROM aliasassignments WHERE aliasid IN (
+			SELECT id FROM aliases WHERE domainid = ?)', array($id));
+		$DB->Execute('DELETE FROM aliasassignments WHERE accountid IN (
+			SELECT id FROM passwd WHERE domainid = ?)', array($id));
+		$DB->Execute('DELETE FROM passwd WHERE domainid = ?', array($id));
+		// ...aliases and orphaned aliases
+	        $DB->Execute('DELETE FROM aliases WHERE domainid = ? 
+			OR NOT EXISTS (SELECT 1 FROM aliasassignments
+			        WHERE aliasid = aliases.id)', array($id));
 	}
+
+	$DB->CommitTrans();
 }
 
 header('Location: ?m=domainlist');
