@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: domainlist.php,v 1.18.2.1 2007/08/17 13:15:23 alec Exp $
+ *  $Id: domainlist.php,v 1.23 2009/01/13 07:45:50 alec Exp $
  */
 
 function GetDomainList($order='name,asc', $customer='')
@@ -35,25 +35,26 @@ function GetDomainList($order='name,asc', $customer='')
 	switch($order)
 	{
 		case 'id':
-			$sqlord = " ORDER BY domains.id $direction";
+			$sqlord = " ORDER BY d.id $direction";
 		break;
 		case 'description':
-			$sqlord = " ORDER BY description $direction";
+			$sqlord = " ORDER BY d.description $direction";
 		break;
 		case 'customer':
 			$sqlord = " ORDER BY customername $direction";
 		break;
 		default:
-			$sqlord = " ORDER BY name $direction";
+			$sqlord = " ORDER BY d.name $direction";
 		break;
 	}
 
-	$list = $DB->GetAll('SELECT domains.id AS id, domains.name AS name, description, ownerid, '
-				.$DB->Concat('lastname', "' '",'customers.name').' AS customername 
-				FROM domains 
-				LEFT JOIN customers ON (ownerid = customers.id) '
-				.($customer != '' ? ' WHERE ownerid = '.$customer : '')
-				.($sqlord != '' ? $sqlord : ''));
+	$list = $DB->GetAll('SELECT d.id AS id, d.name AS name, d.description, 
+		d.ownerid, (SELECT COUNT(*) FROM passwd WHERE domainid = d.id) AS cnt, '
+		.$DB->Concat('lastname', "' '",'c.name').' AS customername 
+		FROM domains d
+		LEFT JOIN customers c ON (d.ownerid = c.id) '
+		.($customer != '' ? ' WHERE d.ownerid = '.$customer : '')
+		.($sqlord != '' ? $sqlord : ''));
 	
 	$list['total'] = sizeof($list);
 	$list['order'] = $order;
@@ -77,25 +78,27 @@ $SESSION->save('dlc', $c);
 
 if ($SESSION->is_set('dlp') && !isset($_GET['page']))
 	$SESSION->restore('dlp', $_GET['page']);
-	    
-$page = (!isset($_GET['page']) ? 1 : $_GET['page']); 
-$pagelimit = (!isset($CONFIG['phpui']['domainlist_pagelimit']) ? $listdata['total'] : $CONFIG['phpui']['domainlist_pagelimit']);
-$start = ($page - 1) * $pagelimit;
-
-$SESSION->save('dlp', $page);
 
 $layout['pagetitle'] = trans('Domains List');
 
 $domainlist = GetDomainList($o, $c);
+
 $listdata['total'] = $domainlist['total'];
 $listdata['order'] = $domainlist['order'];
 $listdata['direction'] = $domainlist['direction'];
 $listdata['customer'] = $domainlist['customer'];
+
 unset($domainlist['total']);
 unset($domainlist['order']);
 unset($domainlist['direction']);
 unset($domainlist['customer']);
 
+$page = (empty($_GET['page']) ? 1 : $_GET['page']); 
+$pagelimit = (empty($CONFIG['phpui']['domainlist_pagelimit']) ? $listdata['total'] : $CONFIG['phpui']['domainlist_pagelimit']);
+$start = ($page - 1) * $pagelimit;
+
+$SESSION->save('dlp', $page);
+
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('pagelimit', $pagelimit);
