@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: eventadd.php,v 1.17.2.1 2007/08/17 13:15:23 alec Exp $
+ *  $Id: eventadd.php,v 1.22 2009/01/13 07:45:50 alec Exp $
  */
 
 if(isset($_POST['event']))
@@ -48,12 +48,21 @@ if(isset($_POST['event']))
 	if(!$error)
 	{
 		$date = mktime(0, 0, 0, $month, $day, $year);
-		$event['status'] = $event['status'] ? 1 : 0;
+		$event['status'] = isset($event['status']) ? 1 : 0;
 
-		$DB->Execute('INSERT INTO events (title, description, date, begintime, endtime, userid, private, customerid) VALUES (?, ?, ?, ?, ?, ?, ?, ?)',
-				array($event['title'], $event['description'], $date, $event['begintime'], $event['endtime'], $AUTH->id, $event['status'], $event['customerid']));
+		$DB->Execute('INSERT INTO events (title, description, date, begintime, endtime, userid, private, customerid) 
+				VALUES (?, ?, ?, ?, ?, ?, ?, ?)',
+				array($event['title'], 
+					$event['description'], 
+					$date, 
+					$event['begintime'], 
+					$event['endtime'], 
+					$AUTH->id, 
+					$event['status'], 
+					$event['customerid']
+					));
 		
-		if($event['userlist'])
+		if(!empty($event['userlist']))
 		{
 			$id = $DB->GetOne('SELECT id FROM events WHERE title=? AND date=? AND begintime=? AND endtime=? AND userid=?',
 				array($event['title'], $date, $event['begintime'], $event['endtime'], $AUTH->id));
@@ -63,7 +72,7 @@ if(isset($_POST['event']))
 					VALUES (?, ?)', array($id, $userid));
 		}
 		
-		if(!$event['reuse'])
+		if(!isset($event['reuse']))
 		{
 			$SESSION->redirect('?m=eventlist');
 		}
