@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,20 +21,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: eventedit.php,v 1.15.2.1 2007/08/17 13:15:23 alec Exp $
+ *  $Id: eventedit.php,v 1.19 2009/01/13 07:45:50 alec Exp $
  */
 
-if($_GET['action'] == 'open')
+if(isset($_GET['action']) && $_GET['action'] == 'open')
 {
 	$DB->Execute('UPDATE events SET closed = 0 WHERE id = ?',array($_GET['id']));
 	$SESSION->redirect('?m=eventlist');
 }
-elseif($_GET['action'] == 'close')
+elseif(isset($_GET['action']) && $_GET['action'] == 'close')
 {
 	$DB->Execute('UPDATE events SET closed = 1 WHERE id = ?',array($_GET['id']));
 	$SESSION->redirect('?m=eventlist');
 }
-elseif($_GET['action'] == 'dropuser')
+elseif(isset($_GET['action']) && $_GET['action'] == 'dropuser')
 {
 	$DB->Execute('DELETE FROM eventassignments WHERE eventid = ? AND userid = ?',array($_GET['eid'], $_GET['aid']));
 	$SESSION->redirect('?'.$SESSION->get('backto'));
@@ -73,7 +73,7 @@ if(isset($_POST['event']))
 	if(!$error)
 	{
 		$date = mktime(0, 0, 0, $month, $day, $year);
-		$event['private'] = $event['private'] ? 1 : 0;
+		$event['private'] = isset($event['private']) ? 1 : 0;
 
 		$DB->Execute('UPDATE events SET title=?, description=?, date=?, begintime=?, endtime=?, private=?, note=?, customerid=? WHERE id=?',
 				array($event['title'], $event['description'], $date, $event['begintime'], $event['endtime'], $event['private'], $event['note'], $event['customerid'], $event['id']));
