@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: eventprint.php,v 1.15.2.1 2007/08/17 13:15:23 alec Exp $
+ *  $Id: eventprint.php,v 1.19 2009/01/13 07:45:50 alec Exp $
  */
 
 function GetEvents($date=NULL, $userid=0, $customerid=0)
@@ -31,7 +31,7 @@ function GetEvents($date=NULL, $userid=0, $customerid=0)
 	$list = $DB->GetAll(
 	        'SELECT events.id AS id, title, description, begintime, endtime, closed, note, '
 		.$DB->Concat('UPPER(customers.lastname)',"' '",'customers.name'). ' AS customername, 
-		 customers.address AS customeraddr, 
+		 customers.address AS customeraddr, customers.city AS customercity,
 		 (SELECT phone FROM customercontacts WHERE customerid = customers.id ORDER BY id LIMIT 1) AS customerphone 
 		 FROM events LEFT JOIN customers ON (customerid = customers.id)
 		 WHERE date = ? AND (private = 0 OR (private = 1 AND userid = ?)) '
