@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice.php,v 1.66.2.2 2007/08/22 14:05:06 alec Exp $
+ *  $Id: invoice.php,v 1.79 2009/01/13 07:45:51 alec Exp $
  */
 
 if(strtolower($CONFIG['invoices']['type']) == 'pdf')
@@ -32,7 +32,7 @@ if(strtolower($CONFIG['invoices']['type']) == 'pdf')
 }
 
 header('Content-Type: '.$CONFIG['invoices']['content_type']);
-if(isset($CONFIG['invoices']['attachment_name']) && $CONFIG['invoices']['attachment_name'] != '')
+if(!empty($CONFIG['invoices']['attachment_name']))
 	header('Content-Disposition: attachment; filename='.$CONFIG['invoices']['attachment_name']);
 
 $SMARTY->assign('css', file('img/style_print.css')); 
@@ -42,14 +42,14 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached')
 	$SESSION->restore('ilm', $ilm);
 	$SESSION->remove('ilm');
 
-	if(sizeof($_POST['marks']))
+	if(!empty($_POST['marks']))
 		foreach($_POST['marks'] as $id => $mark)
 			$ilm[$id] = $mark;
 	if(sizeof($ilm))
 		foreach($ilm as $mark)
 			$ids[] = $mark;
 
-	if(!$ids)
+	if(empty($ids))
 	{
 		$SESSION->close();
 		die;
@@ -58,7 +58,7 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached')
 	$layout['pagetitle'] = trans('Invoices');
 	$SMARTY->display('invoiceheader.html');
 	
-	if($_GET['cash'])
+	if(isset($_GET['cash']))
 	{
 		foreach($ids as $cashid)
 		{
@@ -83,6 +83,7 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached')
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
 		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
+		
 		foreach($which as $type)
 		{
 			$i++;
@@ -102,15 +103,22 @@ elseif(isset($_GET['fetchallinvoices']))
 {
 	$layout['pagetitle'] = trans('Invoices');
 
-	$ids = $DB->GetCol('SELECT id FROM documents d
-				WHERE cdate >= ? AND cdate <= ? AND (type = ? OR type = ?)'
-				.($_GET['customerid'] ? ' AND customerid = '.$_GET['customerid'] : '')
-				.' AND NOT EXISTS (
-					SELECT 1 FROM customerassignments a
-				        JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
-					WHERE e.userid = lms_current_user() AND a.customerid = d.customerid)' 
-				.' ORDER BY CEIL(cdate/86400), id',
-				array($_GET['from'], $_GET['to'], DOC_INVOICE, DOC_CNOTE));
+	$ids = $DB->GetCol('SELECT d.id FROM documents d
+		WHERE d.cdate >= ? AND d.cdate <= ? AND (d.type = ? OR d.type = ?)'
+		.(!empty($_GET['customerid']) ? ' AND d.customerid = '.intval($_GET['customerid']) : '')
+		.(!empty($_GET['numberplanid']) ? ' AND d.numberplanid = '.intval($_GET['numberplanid']) : '')
+		.(!empty($_GET['groupid']) ? 
+		' AND '.(!empty($_GET['groupexclude']) ? 'NOT' : '').'
+		        EXISTS (SELECT 1 FROM customerassignments a
+			        WHERE a.customergroupid = '.intval($_GET['groupid']).'
+				AND a.customerid = d.customerid)' : '')
+		.' AND NOT EXISTS (
+			SELECT 1 FROM customerassignments a
+		        JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
+			WHERE e.userid = lms_current_user() AND a.customerid = d.customerid)' 
+		.' ORDER BY CEIL(d.cdate/86400), d.id',
+		array($_GET['from'], $_GET['to'], DOC_INVOICE, DOC_CNOTE));
+
 	if(!$ids)
 	{
 		$SESSION->close();
@@ -132,12 +140,10 @@ elseif(isset($_GET['fetchallinvoices']))
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
 		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
+
 		foreach($which as $type)
 		{
-			$i++;
-			if($i == $count) $invoice['last'] = TRUE;
 			$SMARTY->assign('type',$type);
-			$SMARTY->assign('duplicate',$type==trans('DUPLICATE') ? TRUE : FALSE);
 			$SMARTY->assign('invoice',$invoice);
 			if(isset($invoice['invoice']))
 				$SMARTY->display($CONFIG['invoices']['cnote_template_file']);
@@ -147,25 +153,6 @@ elseif(isset($_GET['fetchallinvoices']))
 	}
 	$SMARTY->display('clearfooter.html');
 }
-elseif(isset($_GET['fetchsingle']))
-{
-	$invoice = $LMS->GetInvoiceContent($_GET['id']);
-	$number = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
-	if( !$invoice['invoice'])
-		$layout['pagetitle'] = trans('Invoice No. $0', $number);
-	else
-		$layout['pagetitle'] = trans('Credit Note No. $0', $number);
-	$invoice['last'] = TRUE;
-	$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
-	$SMARTY->assign('invoice',$invoice);
-	$SMARTY->display('invoiceheader.html');
-	$SMARTY->assign('type',trans('ORIGINAL'));
-	if(isset($invoice['invoice']))
-		$SMARTY->display($CONFIG['invoices']['cnote_template_file']);
-	else
-		$SMARTY->display($CONFIG['invoices']['template_file']);
-	$SMARTY->display('clearfooter.html');
-}
 elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 {
 	$number = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
@@ -173,21 +160,43 @@ elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 		$layout['pagetitle'] = trans('Invoice No. $0', $number);
 	else
 		$layout['pagetitle'] = trans('Credit Note No. $0', $number);
+
 	$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
-	$SMARTY->assign('invoice',$invoice);
+
+	$which = array();
+
+	if(isset($_GET['original'])) $which[] = trans('ORIGINAL');
+	if(isset($_GET['copy'])) $which[] = trans('COPY');
+	if(isset($_GET['duplicate'])) $which[] = trans('DUPLICATE');
+
+	if(!sizeof($which))
+        {
+	        $tmp = explode(',', $CONFIG['invoices']['default_printpage']);
+	        foreach($tmp as $t)
+			if(trim($t) == 'original') $which[] = trans('ORIGINAL');
+			elseif(trim($t) == 'copy') $which[] = trans('COPY');
+			elseif(trim($t) == 'duplicate') $which[] = trans('DUPLICATE');
+		
+		if(!sizeof($which)) $which[] = trans('ORIGINAL');
+	}
+	
+	$count = sizeof($which);
+	$i = 0;
+	
 	$SMARTY->display('invoiceheader.html');
-	$SMARTY->assign('type',trans('ORIGINAL'));
-	if(isset($invoice['invoice']))
-		$SMARTY->display($CONFIG['invoices']['cnote_template_file']);
-	else
-		$SMARTY->display($CONFIG['invoices']['template_file']);
-	$SMARTY->assign('type',trans('COPY'));
-	$invoice['last'] = TRUE;
-	$SMARTY->assign('invoice',$invoice);
-	if(isset($invoice['invoice']))
-		$SMARTY->display($CONFIG['invoices']['cnote_template_file']);
-	else
-		$SMARTY->display($CONFIG['invoices']['template_file']);
+	foreach($which as $type)
+	{
+		$i++;
+		if($i == $count) $invoice['last'] = TRUE;
+		$SMARTY->assign('invoice',$invoice);
+		$SMARTY->assign('duplicate',$type==trans('DUPLICATE') ? TRUE : FALSE);
+		$SMARTY->assign('type',$type);
+
+		if(isset($invoice['invoice']))
+			$SMARTY->display($CONFIG['invoices']['cnote_template_file']);
+		else
+			$SMARTY->display($CONFIG['invoices']['template_file']);
+	}
 	$SMARTY->display('clearfooter.html');
 }
 else
