@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,15 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice_pdf.php,v 1.72.2.2 2007/08/30 09:23:17 alec Exp $
+ *  $Id: invoice_pdf.php,v 1.88 2009/01/13 07:45:51 alec Exp $
  */
 // Faktury w PDF, do uycia z formularzami FT-0100 (c) Polarnet
 // w razie pyta mailto:lexx@polarnet.org
 
 function invoice_simple_form_fill($x,$y,$scale)  
 {
-    global $pdf,$invoice,$CONFIG;
-    $finances = $CONFIG['finances'];
+    global $pdf,$invoice;
     $pdf->setlinestyle(1);
 
     $pdf->line(7*$scale+$x,724*$scale+$y,7*$scale+$x,694*$scale+$y);
@@ -41,10 +40,16 @@ function invoice_simple_form_fill($x,$y,$scale)
     $pdf->line(370*$scale+$x,197*$scale+$y,370*$scale+$x,227*$scale+$y);
     $pdf->line(370*$scale+$x,197*$scale+$y,340*$scale+$x,197*$scale+$y);
     
-    text_autosize(15*$scale+$x,568*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT",$finances['shortname']),350*$scale);
-    text_autosize(15*$scale+$x,534*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT",$finances['address']),350*$scale);
-    text_autosize(15*$scale+$x,500*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT",$finances['zip']." ".$finances['city']),350*$scale);
-    $tmp = bankaccount($invoice['customerid']);
+    $shortname = $invoice['division_shortname'];
+    $address = $invoice['division_address'];
+    $zip = $invoice['division_zip'];
+    $city = $invoice['division_city'];
+    $account = bankaccount($invoice['customerid']);
+    
+    text_autosize(15*$scale+$x,568*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT", $shortname),350*$scale);
+    text_autosize(15*$scale+$x,534*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT", $address),350*$scale);
+    text_autosize(15*$scale+$x,500*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT", $zip.' '.$city),350*$scale);
+
     //text_autosize(15*$scale+$x,683*$scale+$y,30*$scale, substr($tmp,0,17),350*$scale);
     //text_autosize(15*$scale+$x,626*$scale+$y,30*$scale, substr($tmp,18,200),350*$scale);
     text_autosize(15*$scale+$x,683*$scale+$y,30*$scale, $tmp,350*$scale);
@@ -52,16 +57,15 @@ function invoice_simple_form_fill($x,$y,$scale)
 
     text_autosize(15*$scale+$x,390*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['name']),350*$scale);
     text_autosize(15*$scale+$x,356*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['address']),350*$scale);
-    text_autosize(15*$scale+$x,322*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['zip']." ".$invoice['city']),350*$scale);
+    text_autosize(15*$scale+$x,322*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['zip'].' '.$invoice['city']),350*$scale);
 
     $tmp = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
-    text_autosize(15*$scale+$x,215*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Payment for invoice No. $0',$tmp)),350*$scale);
+    text_autosize(15*$scale+$x,215*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Payment for invoice No. $0', $account)),350*$scale);
 }
 
 function invoice_main_form_fill($x,$y,$scale)	
 {
-    global $pdf,$invoice,$CONFIG;
-    $finances = $CONFIG['finances'];
+    global $pdf,$invoice;
     $pdf->setlinestyle(1);
 
     $pdf->line(7*$scale+$x,724*$scale+$y,7*$scale+$x,694*$scale+$y);
@@ -71,9 +75,15 @@ function invoice_main_form_fill($x,$y,$scale)
     $pdf->line(7*$scale+$x,172*$scale+$y,7*$scale+$x,202*$scale+$y);
     $pdf->line(7*$scale+$x,172*$scale+$y,37*$scale+$x,172*$scale+$y);
 
-    text_autosize(15*$scale+$x,680*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2//TRANSLIT",$finances['name']),950*$scale);
-    text_autosize(15*$scale+$x,617*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2//TRANSLIT",$finances['address']." ".$finances['zip']." ".$finances['city']),950*$scale);
-    text_autosize(15*$scale+$x,555*$scale+$y,30*$scale,bankaccount($invoice['customerid']),950*$scale);
+    $name = $invoice['division_name'];
+    $address = $invoice['division_address'];
+    $zip = $invoice['division_zip'];
+    $city = $invoice['division_city'];
+    $account = bankaccount($invoice['customerid']);
+
+    text_autosize(15*$scale+$x,680*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2//TRANSLIT",$name),950*$scale);
+    text_autosize(15*$scale+$x,617*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2//TRANSLIT",$address." ".$zip." ".$city),950*$scale);
+    text_autosize(15*$scale+$x,555*$scale+$y,30*$scale,$account,950*$scale);
     $pdf->addtext(330*$scale+$x,495*$scale+$y,30*$scale,'X');
     text_autosize(550*$scale+$x,495*$scale+$y,30*$scale,"*".number_format($invoice['total'],2,',','')."*",400*$scale);
     text_autosize(15*$scale+$x,434*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('$0 dollars $1 cents',to_words(floor($invoice['total'])),to_words(round(($invoice['total']-floor($invoice['total']))*100)))),950*$scale);
@@ -106,22 +116,23 @@ function invoice_buyer($x,$y)
     $y=text_wrap($x,$y,350,$font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['name']),'left');
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['address']));
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['zip']." ".$invoice['city']));
+    if ($invoice['division_countryid'] && $invoice['countryid'] && $invoice['division_countryid'] != $invoice['countryid'])
+        $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans($invoice['country'])));
     if ($invoice['ten']) 
-	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('TEN:')).' '.$invoice['ten']);
+	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('TEN')).' '.$invoice['ten']);
     else if ($invoice['ssn']) 
-	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('SSN:')).' '.$invoice['ssn']);
+	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('SSN')).' '.$invoice['ssn']);
     $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Customer No.: $0',sprintf('%04d',$invoice['customerid']))).'</b>');
     return $y;
 }
 
 function invoice_seller($x,$y) 
 {
-    global $pdf,$CONFIG;
+    global $pdf, $invoice;
     $font_size=10;
     $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Seller:')).'</b>');
-    $tmp = iconv("UTF-8","ISO-8859-2//TRANSLIT", isset($CONFIG['invoices']['header']) ? $CONFIG['invoices']['header'] : '');
-    $tmp = str_replace('\n',"\n",$tmp);
-    $tmp = explode("\n",$tmp);
+    $tmp = iconv("UTF-8","ISO-8859-2//TRANSLIT", $invoice['division_header']);
+    $tmp = preg_split('/\r?\n/', $tmp);
     foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,$line);
 
     return $y;
@@ -129,7 +140,7 @@ function invoice_seller($x,$y)
 
 function invoice_title($x,$y) 
 {
-    global $invoice,$pdf,$CONFIG,$type;
+    global $invoice,$pdf,$type;
     $font_size = 16;
     $tmp = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
     if(isset($invoice['invoice']))
@@ -167,12 +178,12 @@ function invoice_address_box($x,$y)
     $invoice_name = $invoice['name'];
     if (strlen($invoice_name)>25) 
         $invoice_name = preg_replace('/(.{25})/',"$1<i>&gt;</i>\n",$invoice_name);
-    $tmp = explode("\n",iconv("UTF-8","ISO-8859-2",$invoice_name));
+    $tmp = preg_split('/\r?\n/', iconv("UTF-8","ISO-8859-2",$invoice_name));
     foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,"<b>".$line."</b>");
 */
     $y = text_wrap($x, $y, 160, $font_size, '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['name'].'</b>'), 'left');
     if ($invoice['serviceaddr']) {
-	$tmp = explode("\n",iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['serviceaddr']));
+	$tmp = preg_split('/\r?\n/', iconv("UTF-8","ISO-8859-2//TRANSLIT",$invoice['serviceaddr']));
 	foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,'<b>'.$line.'</b>');
     } else {
 	$y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv('UTF-8','ISO-8859-2//TRANSLIT',$invoice['address']).'</b>');
@@ -446,6 +457,292 @@ function invoice_data($x,$y,$width,$font_size,$margin)
     return $return;
 }
 
+function new_invoice_data($x,$y,$width,$font_size,$margin) 
+{
+    global $invoice, $pdf;
+
+    $pdf->setlinestyle(0.5);
+    $data = array();
+    $cols = array();
+    $params = array(
+	    'fontSize' => $font_size,
+	    'xPos' => $x,
+	    'xOrientation' => 'right', // I think it should be left here (bug?)
+	    'rowGap' => 2,
+	    'colGap' => 2,
+	    'showHeadings' => 0,
+	    'cols' => array(),
+	    );
+        
+    // tabelka glowna
+    $cols['no'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('No.')).'</b>';
+    $cols['name'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Name of Product, Commodity or Service:')).'</b>';
+    $cols['prodid'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Product ID:')).'</b>';
+    $cols['content'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Unit:')).'</b>';
+    $cols['count'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Amount:')).'</b>';
+    if($invoice['discount'])
+	    $cols['discount'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Discount:')).'</b>';
+    $cols['basevalue'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Unitary Net Value:')).'</b>';
+    $cols['totalbase'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Net Value:')).'</b>';
+    $cols['taxlabel'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Tax Rate:')).'</b>';
+    $cols['totaltax'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Tax Value:')).'</b>';
+    $cols['total'] = '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Gross Value:')).'</b>';
+
+    foreach($cols as $name => $text)
+    {
+	    $params['cols'][$name] = array(
+		    'justification' => 'center',
+		    'width' => getWrapTextWidth($font_size,$text)+2*$margin+2,
+	    );
+    }
+    
+    // tutaj jeszcze trzeba bdzie sprawdzi jak szeroko maj pola w tabelce pniej
+    if ($invoice['content']) foreach ($invoice['content'] as $item)
+    {
+	$tt_width['name'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['description']));
+	$tt_width['prodid'] = $pdf->getTextWidth($font_size,$item['prodid']);
+	$tt_width['content'] = $pdf->getTextWidth($font_size,$item['content']);
+	$tt_width['count'] = $pdf->getTextWidth($font_size,sprintf('%.2f',$item['count']));
+	if($invoice['discount'])
+	    $tt_width['discount'] = $pdf->getTextWidth($font_size,sprintf('%.2f%%',$item['discount']));
+	$tt_width['basevalue'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['basevalue'])))+6;
+	$tt_width['totalbase'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['totalbase'])))+6;
+	$tt_width['taxlabel'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['taxlabel']))+6;
+	$tt_width['totaltax'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['totaltax'])))+6;
+	$tt_width['total'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['total'])))+6;
+
+	foreach($tt_width as $name => $w) 
+		if(($w+2*$margin+2) > $params['cols'][$name]['width']) 
+			$params['cols'][$name]['width'] = $w+2*$margin+2;
+    }
+    
+    if(isset($invoice['invoice']['content'])) foreach ($invoice['invoice']['content'] as $item)
+    {
+	$tt_width['name'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['description']));
+	$tt_width['prodid'] = $pdf->getTextWidth($font_size,$item['prodid']);
+	$tt_width['content'] = $pdf->getTextWidth($font_size,$item['content']);
+	$tt_width['count'] = $pdf->getTextWidth($font_size,sprintf('%.2f',$item['count']));
+	if($invoice['discount'])
+	    $tt_width['discount'] = $pdf->getTextWidth($font_size,sprintf('%.2f%%',$item['discount']));
+	$tt_width['basevalue'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['basevalue'])))+6;
+	$tt_width['totalbase'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['totalbase'])))+6;
+	$tt_width['taxlabel'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['taxlabel']))+6;
+	$tt_width['totaltax'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['totaltax'])))+6;
+	$tt_width['total'] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['total'])))+6;
+
+	foreach($tt_width as $name => $w) 
+		if(($w+2*$margin+2) > $params['cols'][$name]['width']) 
+			$params['cols'][$name]['width'] = $w+2*$margin+2;
+    }
+
+    // Kolumna 'name' bedzie miala rozmiar ustalany dynamicznie
+    $sum = 0;
+    foreach($params['cols'] as $name => $col)
+	    if($name != 'name')
+		    $sum += $col['width'];
+    $params['cols']['name']['width'] = $width - $sum;
+
+    // table header
+    $pdf->ezSetY($y);
+    $data = array(0=>$cols);
+    $y = $pdf->ezTable($data, $cols,'', $params);
+    $data = array();
+
+    foreach($cols as $name => $text)
+    {
+	    switch($name)
+	    {
+		    case 'no': $params['cols'][$name]['justification'] = 'center'; break;
+		    case 'name': $params['cols'][$name]['justification'] = 'left'; break;
+		    default: $params['cols'][$name]['justification'] = 'right'; break;
+	    }
+    }
+
+    // size of taxes summary table
+    $xx = $x;
+    foreach($params['cols'] as $name => $value)
+	    if(in_array($name, array('no','name','prodid','content','count','discount','basevalue')))
+	    {
+		    $xx += $params['cols'][$name]['width'];
+	    }
+	    else
+	    	    $cols2[$name] = $params['cols'][$name];
+
+    $data2 = array();
+    $params2 = array(
+	    'fontSize' => $font_size,
+	    'xPos' => $xx,
+	    'xOrientation' => 'right',
+	    'rowGap' => 2,
+	    'colGap' => 2,
+	    'showHeadings' => 0,
+	    'cols' => $cols2,
+    );
+
+    if(isset($invoice['invoice']))
+    {
+	// we have credit note, so first print corrected invoice data
+
+	$y -= 20;	
+	check_page_length($y);
+        $y = $y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Was:')).'</b>');
+
+	$i = 0;
+	if ($invoice['invoice']['content']) 
+	    foreach ($invoice['invoice']['content'] as $item)
+	    {
+		$data[$i]['no'] = $i+1;
+		$data[$i]['name'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['description']);
+		$data[$i]['prodid'] = $item['prodid'];
+		$data[$i]['content'] = $item['content'];
+		$data[$i]['count'] = sprintf('%.2f',$item['count']);
+		if($invoice['discount'])
+			$data[$i]['discount'] = sprintf('%.2f%%',$item['discount']);
+		$data[$i]['basevalue'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['basevalue']));
+		$data[$i]['totalbase'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['totalbase']));
+		$data[$i]['taxlabel'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['taxlabel']);
+		$data[$i]['totaltax'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['totaltax']));
+		$data[$i]['total'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['total']));
+	
+		$i++;
+	    }
+
+	$pdf->ezSetY($y);
+	$y = $pdf->ezTable($data, $cols,'', $params);
+	$data = array();
+
+	$y -= 10;
+	check_page_length($y);
+    
+	$data2[0]['totalbase'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($invoice['invoice']['totalbase']));
+        $data2[0]['taxlabel'] = "<b>x</b>";
+	$data2[0]['totaltax'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($invoice['invoice']['totaltax']));
+        $data2[0]['total'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($invoice['invoice']['total']));
+
+	$pdf->ezSetY($y);
+	$y = $pdf->ezTable($data2, NULL,'', $params2);
+	$data2 = array();
+
+	$fy = $y + $pdf->GetFontHeight($font_size)/2;    
+	text_align_right($xx-5, $fy, $font_size, '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Total:')).'</b>');
+    
+	check_page_length($y);
+	$fy = $y - $margin - $pdf->GetFontHeight($font_size);    
+	text_align_right($xx-5,$fy,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('in it:')).'</b>');
+	
+	if ($invoice['invoice']['taxest']) 
+	{
+	    $i = 0;
+	    foreach ($invoice['invoice']['taxest'] as $item) 
+	    {
+		$data2[$i]['totalbase'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['base']));
+		$data2[$i]['taxlabel'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['taxlabel']);
+		$data2[$i]['totaltax'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['tax']));
+		$data2[$i]['total'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['total']));
+		$i++;
+	    }
+	    $pdf->ezSetY($y);
+	    $y = $pdf->ezTable($data2, NULL,'', $params2);
+	    $data2 = array();
+	}
+
+	$y -= 20;
+	if($invoice['reason'] != '')
+	{
+		check_page_length($y);
+		$y = text_wrap($x,$y,$width,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Reason:').' '.$invoice['reason']).'</b>','left');
+		$y -= 10;
+	}
+	check_page_length($y);
+	$y = $y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Corrected to:')).'</b>');
+    }
+        
+    // pozycje faktury
+    $i = 0;
+    if(isset($invoice['content'])) foreach ($invoice['content'] as $item)
+    {
+	$data[$i]['no'] = $i+1;
+	$data[$i]['name'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['description']);
+	$data[$i]['prodid'] = $item['prodid'];
+	$data[$i]['content'] = $item['content'];
+	$data[$i]['count'] = sprintf('%.2f',$item['count']);
+	if($invoice['discount'])
+		$data[$i]['discount'] = sprintf('%.2f%%',$item['discount']);
+	$data[$i]['basevalue'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['basevalue']));
+	$data[$i]['totalbase'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['totalbase']));
+	$data[$i]['taxlabel'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['taxlabel']);
+	$data[$i]['totaltax'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['totaltax']));
+	$data[$i]['total'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['total']));
+	
+	$i++;
+    }
+
+    $pdf->ezSetY($y);
+    $y = $pdf->ezTable($data, $cols,'', $params);
+
+    $y -= 10;
+    check_page_length($y);
+
+    // podsumowanie podatku    
+    $data2[0]['totalbase'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($invoice['totalbase']));
+    $data2[0]['taxlabel'] = "<b>x</b>";
+    $data2[0]['totaltax'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($invoice['totaltax']));
+    $data2[0]['total'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($invoice['total']));
+
+    $pdf->ezSetY($y);
+    $y = $pdf->ezTable($data2, NULL,'', $params2);
+    $data2 = array();
+
+    $fy = $y + $pdf->GetFontHeight($font_size)/2;    
+    text_align_right($xx-5, $fy, $font_size, '<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Total:')).'</b>');
+
+    $return[1] = $y;
+    
+    check_page_length($y);
+    $fy = $y - $margin - $pdf->GetFontHeight($font_size);    
+    text_align_right($xx-5,$fy,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('in it:')).'</b>');
+    
+    if(isset($invoice['taxest'])) 
+    {
+	$i = 0;
+	foreach ($invoice['taxest'] as $item) 
+	{
+	    $data2[$i]['totalbase'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['base']));
+	    $data2[$i]['taxlabel'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",$item['taxlabel']);
+	    $data2[$i]['totaltax'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['tax']));
+	    $data2[$i]['total'] = iconv("UTF-8","ISO-8859-2//TRANSLIT",moneyf($item['total']));
+	    $i++;
+	}
+	$pdf->ezSetY($y);
+	$y = $pdf->ezTable($data2, NULL,'', $params2);
+	$data2 = array();
+    }
+
+    if(isset($invoice['invoice']))
+    {
+	$total = $invoice['total'] - $invoice['invoice']['total'];
+	$totalbase = $invoice['totalbase'] - $invoice['invoice']['totalbase'];
+	$totaltax = $invoice['totaltax'] - $invoice['invoice']['totaltax'];
+	
+	$y -= 10;
+	$fy = $y - $margin - $pdf->GetFontHeight($font_size);
+	text_align_right($xx-5,$fy,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT", trans('Difference value:')).'</b>');
+    
+	$data2[0]['totalbase'] = ($totalbase>0 ? '+' : '') . iconv("UTF-8","ISO-8859-2//TRANSLIT", moneyf($totalbase));
+        $data2[0]['taxlabel'] = "<b>x</b>";
+	$data2[0]['totaltax'] = ($totaltax>0 ? '+' : '') . iconv("UTF-8","ISO-8859-2//TRANSLIT", moneyf($totaltax));
+        $data2[0]['total'] = ($total>0 ? '+' : '') . iconv("UTF-8","ISO-8859-2//TRANSLIT", moneyf($total));
+	
+	$pdf->ezSetY($y);
+	$y = $pdf->ezTable($data2, NULL,'', $params2);
+	$data2 = array();
+    }
+    
+    $return[2] = $y;
+
+    return $return;
+}
+
 function invoice_to_pay($x,$y) 
 {
     global $pdf, $invoice;
@@ -459,9 +756,9 @@ function invoice_to_pay($x,$y)
 
 function invoice_expositor ($x,$y) 
 {
-    global $pdf, $invoice, $CONFIG;
+    global $pdf, $invoice;
     
-    $expositor = isset($invoice['user']) ? $invoice['user'] : (isset($CONFIG['invoices']['default_author']) ? $CONFIG['invoices']['default_author'] : '');
+    $expositor = isset($invoice['user']) ? $invoice['user'] : $invoice['division_author'];
 	    
     $y = $y - text_align_left($x,$y,10,iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Expositor:')).' '.iconv("UTF-8","ISO-8859-2//TRANSLIT",$expositor));
     return $y;
@@ -469,21 +766,21 @@ function invoice_expositor ($x,$y)
 
 function invoice_footnote($x, $y, $width, $font_size) 
 {
-    global $pdf, $CONFIG;
-    if(isset($CONFIG['invoices']['footer']) && $CONFIG['invoices']['footer'])
+    global $pdf, $invoice;
+
+    if(!empty($invoice['division_footer']))
     {
 	$y = $y - $pdf->getFontHeight($font_size);
 	$y = $y - text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2//TRANSLIT",trans('Notes:')).'</b>');
-	$tmp = iconv("UTF-8","ISO-8859-2//TRANSLIT",$CONFIG['invoices']['footer']);
-	$tmp = str_replace('\n',"\n",$tmp);
-        $tmp = explode("\n",$tmp);
+	$tmp = iconv("UTF-8","ISO-8859-2//TRANSLIT", $invoice['division_footer']);
+        $tmp = preg_split('/\r?\n/', $tmp);
 	foreach ($tmp as $line) $y = text_wrap($x,$y,$width,$font_size,$line,"full");
     }
 }
 
 function invoice_body() 
 {
-    global $invoice,$pdf,$id,$CONFIG;
+    global $invoice,$pdf,$CONFIG;
     
     if(isset($invoice['invoice']))
 	    $template = $CONFIG['invoices']['cnote_template_file'];
@@ -493,6 +790,7 @@ function invoice_body()
     switch ($template)
     {
 	case "standard":
+	    $page = $pdf->ezStartPageNumbers($pdf->ez['pageWidth']-50,20,8,'right',trans('Page $0 of $1', '{PAGENUM}','{TOTALPAGENUM}'),1);
 	    $top=800;
 	    invoice_dates(500,800);    
     	    invoice_address_box(400,700);
@@ -502,16 +800,18 @@ function invoice_body()
 	    $top=$top-20;
     	    $top=invoice_buyer(30,$top);
 	    $top=$top-20;
-    	    $return=invoice_data(30,$top,530,7,2);
+    	    $return=new_invoice_data(30,$top,530,7,2);
 	    invoice_expositor(30,$return[1]-20);
     	    $top=$return[2]-20;
 	    $top=invoice_to_pay(30,$top);
 	    $top=$top-20;
 	    invoice_footnote(30,$top,530,10);
+	    $page = $pdf->ezStopPageNumbers(1,1,$page);
 	    break;
 	case "FT-0100":
-	    $top=800;
-	    invoice_dates(500,800);    
+	    $page = $pdf->ezStartPageNumbers($pdf->ez['pageWidth']/2+10,$pdf->ez['pageHeight']-30,8,'',trans('Page $0 of $1', '{PAGENUM}','{TOTALPAGENUM}'),1);
+	    $top=$pdf->ez['pageHeight']-50;
+	    invoice_dates(500,$top);    
     	    invoice_address_box(400,700);
 	    $top=invoice_title(30,$top);
 	    $top=$top-10;
@@ -519,32 +819,33 @@ function invoice_body()
 	    $top=$top-10;
     	    $top=invoice_buyer(30,$top);
 	    $top=$top-10;
-    	    $return=invoice_data(30,$top,430,6,1);
 	    invoice_footnote(470,$top,90,8);
-	    invoice_expositor(30,$return[1]-20);
+    	    $return=new_invoice_data(30,$top,430,6,1);
     	    $top=$return[2]-10;
+	    invoice_expositor(30,$return[1]);
 	    invoice_to_pay(30,$top);
+	    check_page_length($top, 200);
 	    invoice_main_form_fill(187,3,0.4);
 	    invoice_simple_form_fill(14,3,0.4);
+	    $page = $pdf->ezStopPageNumbers(1,1,$page);
 	    break;
 	default:
 	    require($template);
     }
-    if(!isset($invoice['last'])) $id=$pdf->newPage(1,$id,'after');
+
+    if(!isset($invoice['last'])) $pdf->ezNewPage();
 }
 
 require_once(LIB_DIR.'/pdf.php');
 
 $pdf =& init_pdf('A4', 'portrait', trans('Invoices'));
 
-$id = $pdf->getFirstPageId();
-
 if(isset($_GET['print']) && $_GET['print'] == 'cached')
 {
 	$SESSION->restore('ilm', $ilm);
 	$SESSION->remove('ilm');
 
-	if(sizeof($_POST['marks']))
+	if(isset($_POST['marks']))
 		foreach($_POST['marks'] as $idx => $mark)
 			$ilm[$idx] = $mark;
 
@@ -552,7 +853,7 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached')
 		foreach($ilm as $mark)
 			$ids[] = $mark;
 
-	if(!sizeof($ids))
+	if(!isset($ids))
 	{
 		$SESSION->close();
 		die;
@@ -582,6 +883,7 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached')
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
 		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
+
 		foreach($which as $type)
 		{
 			$i++;
@@ -594,11 +896,17 @@ elseif(isset($_GET['fetchallinvoices']))
 {
 	$ids = $DB->GetCol('SELECT id FROM documents d
 				WHERE cdate >= ? AND cdate <= ? AND (type = ? OR type = ?)'
-				.($_GET['customerid'] ? ' AND customerid = '.$_GET['customerid'] : '')
+				.(!empty($_GET['customerid']) ? ' AND d.customerid = '.intval($_GET['customerid']) : '')
+				.(!empty($_GET['numberplanid']) ? ' AND d.numberplanid = '.intval($_GET['numberplanid']) : '')
+				.(!empty($_GET['groupid']) ?
+				' AND '.(!empty($_GET['groupexclude']) ? 'NOT' : '').'
+					EXISTS (SELECT 1 FROM customerassignments a
+					WHERE a.customergroupid = '.intval($_GET['groupid']).'
+						AND a.customerid = d.customerid)' : '')
 				.' AND NOT EXISTS (
 				        SELECT 1 FROM customerassignments a
-					JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
-					WHERE e.userid = lms_current_user() AND a.customerid = d.customerid)'
+				        JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
+				        WHERE e.userid = lms_current_user() AND a.customerid = d.customerid)'
 				.' ORDER BY CEIL(cdate/86400), id',
 				array($_GET['from'], $_GET['to'], DOC_INVOICE, DOC_CNOTE));
 	if(!$ids)
@@ -620,6 +928,7 @@ elseif(isset($_GET['fetchallinvoices']))
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
 		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
+
 		foreach($which as $type)
 		{
 			$i++;
@@ -628,22 +937,36 @@ elseif(isset($_GET['fetchallinvoices']))
 		}
 	}
 }
-elseif(isset($_GET['fetchsingle']))
-{
-	$invoice = $LMS->GetInvoiceContent($_GET['id']);
-	$invoice['last'] = TRUE;
-	$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
-	$type = trans('ORIGINAL');
-	invoice_body();
-}
 elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 {
 	$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
-	$type = trans('ORIGINAL');
-	invoice_body();
-	$type = trans('COPY');
-	$invoice['last'] = TRUE;
-	invoice_body();
+
+	$which = array();
+
+	if(isset($_GET['original'])) $which[] = trans('ORIGINAL');
+        if(isset($_GET['copy'])) $which[] = trans('COPY');
+        if(isset($_GET['duplicate'])) $which[] = trans('DUPLICATE');
+	
+	if(!sizeof($which))
+	{
+		$tmp = explode(',', $CONFIG['invoices']['default_printpage']);
+		foreach($tmp as $t)
+			if(trim($t) == 'original') $which[] = trans('ORIGINAL');
+			elseif(trim($t) == 'copy') $which[] = trans('COPY');
+			elseif(trim($t) == 'duplicate') $which[] = trans('DUPLICATE');
+
+		if(!sizeof($which)) $which[] = trans('ORIGINAL');
+	}
+	
+	$count = sizeof($which);
+	$i=0;
+
+	foreach($which as $type)
+	{
+		$i++;
+		if($i == $count) $invoice['last'] = TRUE;
+		invoice_body();
+	}
 }
 else
 {
