@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoiceedit.php,v 1.23.2.1 2007/08/17 13:15:24 alec Exp $
+ *  $Id: invoiceedit.php,v 1.33 2009/02/10 22:08:36 ceho Exp $
  */
 
 $taxeslist = $LMS->GetTaxes();
@@ -47,14 +47,14 @@ if(isset($_GET['id']) && $action=='edit')
         $nitem['valuebrutto']	= str_replace(',','.',$item['value']);
 	$nitem['s_valuenetto']	= str_replace(',','.',$item['totalbase']);
         $nitem['s_valuebrutto']	= str_replace(',','.',$item['total']);
-	$nitem['tax']		= $taxeslist[$item['taxid']]['label'];
+	$nitem['tax']		= isset($taxeslist[$item['taxid']]) ? $taxeslist[$item['taxid']]['label'] : '';
 	$nitem['taxid']		= $item['taxid'];
 	$nitem['posuid']	= $i;
 	$SESSION->restore('invoicecontents', $invoicecontents);
 	$invoicecontents[] = $nitem;
 	$SESSION->save('invoicecontents', $invoicecontents);
     }
-    $SESSION->save('invoicecustomer', $LMS->GetCustomer($invoice['customerid']));
+    $SESSION->save('invoicecustomer', $LMS->GetCustomer($invoice['customerid'], true));
     $invoice['oldcdate'] = $invoice['cdate'];
     $SESSION->save('invoice', $invoice);
     $SESSION->save('invoiceid', $invoice['id']);
@@ -89,12 +89,12 @@ switch($action)
 			elseif($itemdata['valuebrutto'] != 0)
 			{
 			    	$itemdata['valuebrutto'] = f_round($itemdata['valuebrutto'] - $itemdata['valuebrutto'] * f_round($itemdata['discount'])/100);
-				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ($taxvalue + 100) * 100, 2);
+				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ($taxvalue / 100 + 1),2);
 			}
 			
 			// str_replace here is needed because of bug in some PHP versions (4.3.10)
-			$itemdata['s_valuenetto'] = str_replace(',','.',$itemdata['valuenetto'] * $itemdata['count']);
 			$itemdata['s_valuebrutto'] = str_replace(',','.',$itemdata['valuebrutto'] * $itemdata['count']);
+			$itemdata['s_valuenetto'] = str_replace(',','.',$itemdata['s_valuebrutto'] / ($taxvalue / 100 + 1));
 			$itemdata['valuenetto'] = str_replace(',','.',$itemdata['valuenetto']);
 			$itemdata['valuebrutto'] = str_replace(',','.',$itemdata['valuebrutto']);
 			$itemdata['count'] = str_replace(',','.',$itemdata['count']);
@@ -119,6 +119,7 @@ switch($action)
 		unset($invoice); 
 		unset($customer);
 		unset($error);
+		$error = NULL;
 		
 		if($invoice = $_POST['invoice'])
 			foreach($invoice as $key => $val)
@@ -135,7 +136,16 @@ switch($action)
 			list($year, $month, $day) = split('/',$invoice['cdate']);
 			if(checkdate($month, $day, $year))
 			{
-				$invoice['cdate'] = mktime(date('G',time()),date('i',time()),date('s',time()),$month,$day,$year);
+				$oldday = date('d', $invoice['oldcdate']);
+				$oldmonth = date('m', $invoice['oldcdate']);
+			        $oldyear = date('Y', $invoice['oldcdate']);
+				
+				if($oldday != $day || $oldmonth != $month || $oldyear != $year)
+				{
+					$invoice['cdate'] = mktime(date('G',time()),date('i',time()),date('s',time()),$month,$day,$year);
+				}
+				else // save hour/min/sec value if date is the same
+					$invoice['cdate'] = $invoice['oldcdate'];
 			}
 			else
 				$error['cdate'] = trans('Incorrect date format!');
@@ -144,8 +154,8 @@ switch($action)
 		$invoice['customerid'] = $_POST['customerid'];
 		
 		if(!$error)
-			if($LMS->CustomerExists(($_GET['customerid'] != '' ? $_GET['customerid'] : $_POST['customerid'])))
-				$customer = $LMS->GetCustomer(($_GET['customerid'] != '' ? $_GET['customerid'] : $_POST['customerid']));
+			if($LMS->CustomerExists($invoice['customerid']))
+				$customer = $LMS->GetCustomer($invoice['customerid'], true);
 	break;
 
 	case 'save':
@@ -155,13 +165,16 @@ switch($action)
 			$SESSION->restore('invoiceid', $invoice['id']);
 			$invoice['type'] = DOC_INVOICE;
 			$LMS->InvoiceUpdate(array('customer' => $customer, 'contents' => $contents, 'invoice' => $invoice));
-			$SESSION->redirect('?m=invoice&id='.$invoice['id']);
+			
+			if(isset($_GET['print']))
+				$SESSION->save('invoiceprint', array('invoice' => $invoice['id'],
+					'original' => !empty($_GET['original']) ? 1 : 0,
+			        	'copy' => !empty($_GET['copy']) ? 1 : 0,
+					'duplicate' => !empty($_GET['duplicate']) ? 1 : 0));
+				
+			$SESSION->redirect('?m=invoicelist');
 		}
 	break;
-
-	case 'invoicedel':
-	    $LMS->InvoiceDelete($_GET['id']);
-	    $SESSION->redirect('?m=invoicelist');
 }
 
 if($invoice['paytype'] == '')
@@ -174,7 +187,7 @@ $SESSION->save('invoiceediterror', $error);
 
 if($action != '')
 {
-	// redirect, eby refreshem nie spierdoli faktury
+	// redirect needed because we don't want to destroy contents of invoice in order of page refresh
 	$SESSION->redirect('?m=invoiceedit');
 }
 
