@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicelist.php,v 1.42.2.3 2007/09/11 11:08:49 alec Exp $
+ *  $Id: invoicelist.php,v 1.58 2009/01/27 18:40:51 alec Exp $
  */
 
-function GetInvoicesList($search=NULL, $cat=NULL, $group=NULL, $order)
+function GetInvoicesList($search=NULL, $cat=NULL, $group=NULL, $order, $pagelimit=100, $page=NULL)
 {
 	global $DB;
 	
@@ -68,26 +68,37 @@ function GetInvoicesList($search=NULL, $cat=NULL, $group=NULL, $order)
 			case 'cdate':
 				$where = ' AND cdate >= '.$search.' AND cdate < '.($search+86400);
 			break;
+			case 'month':
+				$last = mktime(23,59,59, date('n',$search) + 1, 0, date('Y', $search));
+				$where = ' AND cdate >= '.$search.' AND cdate <= '.$last;
+			break;
 			case 'ten':
 			        $where = ' AND ten = \''.$search.'\'';
 			break;
 			case 'customerid':
-				$where = ' AND customerid = '.intval($search);
+				$where = ' AND d.customerid = '.intval($search);
 			break;
 			case 'name':
-				$where = ' AND UPPER(name) ?LIKE? UPPER(\'%'.$search.'%\')';
+				$where = ' AND UPPER(d.name) ?LIKE? UPPER(\'%'.$search.'%\')';
 			break;
 			case 'address':
 				$where = ' AND UPPER(address) ?LIKE? UPPER(\'%'.$search.'%\')';
 			break;
+			case 'value':
+				$having = ' HAVING CASE reference WHEN 0 THEN
+					    SUM(a.value*a.count) 
+					    ELSE
+					    SUM((a.value+b.value)*(a.count+b.count)) - SUM(b.value*b.count)
+					    END = '.str_replace(',','.',f_round($search)).' ';
+			break;
 		}
 	}
         
 	if($cat=='notclosed')
 		$where = ' AND closed = 0';
 
-	if($result = $DB->GetAll('SELECT d.id AS id, number, cdate, type,
-			customerid, name, address, zip, city, template, closed, 
+	if($res = $DB->Exec('SELECT d.id AS id, number, cdate, type,
+			d.customerid, d.name, address, zip, city, countries.name AS country, template, closed, 
 			CASE reference WHEN 0 THEN
 			    SUM(a.value*a.count) 
 			ELSE
@@ -95,56 +106,54 @@ function GetInvoicesList($search=NULL, $cat=NULL, $group=NULL, $order)
 			END AS value, 
 			COUNT(a.docid) AS count
 	    		FROM documents d
-			LEFT JOIN invoicecontents a ON (a.docid = d.id)
+			JOIN invoicecontents a ON (a.docid = d.id)
+			LEFT JOIN countries ON (countries.id = d.countryid)
 			LEFT JOIN invoicecontents b ON (d.reference = b.docid AND a.itemid = b.itemid)
 			LEFT JOIN numberplans ON (d.numberplanid = numberplans.id)
-			WHERE (type = '.DOC_CNOTE.(($cat != 'cnotes') ? ' OR type = '.DOC_INVOICE : '').')'
+			LEFT JOIN (
+				SELECT DISTINCT a.customerid FROM customerassignments a
+			        JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
+				WHERE e.userid = lms_current_user()
+				) e ON (e.customerid = d.customerid) 
+			WHERE e.customerid IS NULL AND 
+				(type = '.DOC_CNOTE.(($cat != 'cnotes') ? ' OR type = '.DOC_INVOICE : '').')'
 			.$where
-			.' AND NOT EXISTS (
-			        SELECT 1 FROM customerassignments a
-				JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
-				WHERE e.userid = lms_current_user() AND a.customerid = d.customerid)'
-			.' GROUP BY d.id, number, cdate, customerid, 
-			name, address, zip, city, template, closed, type, reference '
+			.(!empty($group['group']) ?
+			            ' AND '.(!empty($group['exclude']) ? 'NOT' : '').' EXISTS (
+			            SELECT 1 FROM customerassignments WHERE customergroupid = '.intval($group['group']).'
+			            AND customerid = d.customerid)' : '')
+			.' GROUP BY d.id, number, cdate, d.customerid, 
+			d.name, address, zip, city, template, closed, type, reference, countries.name '
+			.(isset($having) ? $having : '')
 	    		.$sqlord.' '.$direction))
 	{
-		$result1 = array();
+		if ($page > 0) {
+	                $start =  ($page - 1) * $pagelimit;
+		        $stop = $start + $pagelimit;
+		}
+		$id = 0;
 
-		if($search!='' && $cat=='value')
+		while($row = $DB->FetchRow($res))
 		{
-			$val = f_round($search);
-
-			foreach($result as $idx => $row)
+			$result[$id] = $row;
+			// free memory for rows which will not be displayed
+	                if($page > 0)
 			{
-				if($row['value']==$val)
-					$result1[] = $result[$idx];
+			        if(($id < $start || $id > $stop) && isset($result[$id]))
+			                $result[$id] = NULL;
 			}
+			elseif(isset($result[$id-$pagelimit]))
+			                $result[$id-$pagelimit] = NULL;
 
-			$result = $result1;
-			unset($result1);
+			$id++;
 		}
 
-		if($group['group'])
-		{
-			$customers = $DB->GetAllByKey('SELECT customerid AS id
-		        	FROM customerassignments WHERE customergroupid=?', 
-				'id', array($group['group']));
-		
-			foreach($result as $idx => $row)
-			{
-				if(!$group['exclude'] && $customers[$result[$idx]['customerid']])
-					$result1[] = $result[$idx];
-				elseif($group['exclude'] && !$customers[$result[$idx]['customerid']])
-					$result1[] = $result[$idx];
-			}
-
-			$result = $result1;
-			unset($result1);
-		}
+		$result['page'] = $page > 0 ? $page : ceil($id / $pagelimit);
 	}
 
 	$result['order'] = $order;
 	$result['direction'] = $direction;
+			
 	return $result;
 }																																																																																																					       
 
@@ -185,32 +194,46 @@ if(isset($_POST['group'])) {
 $SESSION->save('ilg', $g);
 $SESSION->save('ilge', $ge);
 
-if($c == 'cdate' && $s)
+if($c == 'cdate' && $s && ereg('^[0-9]{4}/[0-9]{2}/[0-9]{2}$', $s))
 {
 	list($year, $month, $day) = explode('/', $s);
 	$s = mktime(0,0,0, $month, $day, $year);
 }
+elseif($c == 'month' && $s && ereg('^[0-9]{4}/[0-9]{2}$', $s))
+{
+	list($year, $month) = explode('/', $s);
+        $s = mktime(0,0,0, $month, 1, $year);
+}
 
-$invoicelist = GetInvoicesList($s, $c, array('group' => $g, 'exclude'=> $ge), $o);
+$pagelimit = $CONFIG['phpui']['invoicelist_pagelimit'];
+$page = !isset($_GET['page']) ? 0 : intval($_GET['page']);
+
+$invoicelist = GetInvoicesList($s, $c, array('group' => $g, 'exclude'=> $ge), $o, $pagelimit, $page);
 
 $SESSION->restore('ilc', $listdata['cat']);
 $SESSION->restore('ils', $listdata['search']);
 $SESSION->restore('ilg', $listdata['group']);
 $SESSION->restore('ilge', $listdata['groupexclude']);
+
 $listdata['order'] = $invoicelist['order'];
 $listdata['direction'] = $invoicelist['direction'];
+$page = $invoicelist['page'];
+
+unset($invoicelist['page']);
 unset($invoicelist['order']);
 unset($invoicelist['direction']);
 
 $listdata['total'] = sizeof($invoicelist);
 
-$pagelimit = $CONFIG['phpui']['invoicelist_pagelimit'];
-$page = !isset($_GET['page']) ? ceil($listdata['total']/$pagelimit) : intval($_GET['page']);
-$start = ($page - 1) * $pagelimit;
+if($invoice = $SESSION->get('invoiceprint'))
+{
+        $SMARTY->assign('invoice', $invoice);
+        $SESSION->remove('invoiceprint');
+}
 
 $SMARTY->assign('listdata',$listdata);
 $SMARTY->assign('pagelimit',$pagelimit);
-$SMARTY->assign('start',$start);
+$SMARTY->assign('start',($page - 1) * $pagelimit);
 $SMARTY->assign('page',$page);
 $SMARTY->assign('marks',$marks);
 $SMARTY->assign('grouplist',$LMS->CustomergroupGetAll());
