@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicenew.php,v 1.56.2.2 2007/09/05 13:33:18 alec Exp $
+ *  $Id: invoicenew.php,v 1.72 2009/02/11 09:47:18 alec Exp $
  */
 
 // Invoiceless liabilities: Zobowiazania/obciazenia na ktore nie zostala wystawiona faktura
@@ -33,7 +33,7 @@ function GetCustomerCovenants($customerid)
 	
 	return $DB->GetAll('SELECT c.time, c.value*-1 AS value, c.comment, c.taxid, 
 			taxes.label AS tax, c.id AS cashid,
-			ROUND(c.value / (taxes.value+100)*100, 2)*-1 AS net
+			ROUND(c.value / (taxes.value/100+1), 2)*-1 AS net
 			FROM cash c
 			LEFT JOIN taxes ON (c.taxid = taxes.id)
 			WHERE c.customerid = ? AND c.docid = 0 AND c.value < 0
@@ -63,11 +63,23 @@ switch($action)
     		unset($error);
 
 		// get default invoice's numberplanid and next number
-		$invoice['numberplanid'] = $DB->GetOne('SELECT id FROM numberplans WHERE doctype=? AND isdefault=1', array(DOC_INVOICE));
 		$invoice['cdate'] = time();
 		$invoice['paytime'] = 14;
 		if(isset($_GET['customerid']) && $_GET['customerid'] != '' && $LMS->CustomerExists($_GET['customerid']))
-			$customer = $LMS->GetCustomer($_GET['customerid']);
+		{
+			$customer = $LMS->GetCustomer($_GET['customerid'], true);
+			if($customer['paytime'] != -1)
+				$invoice['paytime'] = $customer['paytime'];
+			
+			$invoice['numberplanid'] = $DB->GetOne('SELECT n.id FROM numberplans n
+				JOIN numberplanassignments a ON (n.id = numberplanid)
+				WHERE n.doctype = ? AND n.isdefault = 1 AND a.divisionid = ?',
+				array(DOC_INVOICE, $customer['divisionid']));
+		}
+	
+		if(empty($invoice['numberplanid']))
+			$invoice['numberplanid'] = $DB->GetOne('SELECT id FROM numberplans
+				WHERE doctype = ? AND isdefault = 1', array(DOC_INVOICE));
 	break;
 
 	case 'additem':
@@ -86,12 +98,12 @@ switch($action)
 			elseif($itemdata['valuebrutto'] != 0)
 			{
 				$itemdata['valuebrutto'] = f_round($itemdata['valuebrutto'] - $itemdata['valuebrutto'] * f_round($itemdata['discount'])/100);
-				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ($taxvalue + 100) * 100, 2);
+				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ($taxvalue / 100 + 1), 2);
 			}
 			
 			// str_replace->f_round here is needed because of bug in some PHP versions
-			$itemdata['s_valuenetto'] = f_round($itemdata['valuenetto'] * $itemdata['count']);
 			$itemdata['s_valuebrutto'] = f_round($itemdata['valuebrutto'] * $itemdata['count']);
+			$itemdata['s_valuenetto'] = f_round($itemdata['s_valuebrutto'] /  ($taxvalue / 100 + 1));
 			$itemdata['valuenetto'] = f_round($itemdata['valuenetto']);
 			$itemdata['valuebrutto'] = f_round($itemdata['valuebrutto']);
 			$itemdata['count'] = f_round($itemdata['count']);
@@ -114,13 +126,13 @@ switch($action)
 				$itemdata['cashid'] = $id;
 				$itemdata['name'] = $cash['comment'];
 				$itemdata['taxid'] = $cash['taxid'];
-				$itemdata['tax'] = $taxeslist[$itemdata['taxid']]['label'];
+				$itemdata['tax'] = isset($taxeslist[$itemdata['taxid']]) ? $taxeslist[$itemdata['taxid']]['label'] : '';
 				$itemdata['discount'] = 0;
 				$itemdata['count'] = f_round($_POST['l_count'][$id]);
 				$itemdata['valuebrutto'] = f_round((-$cash['value'])/$itemdata['count']);
 				$itemdata['s_valuebrutto'] = f_round(-$cash['value']);
-				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ($taxeslist[$itemdata['taxid']]['value'] + 100) * 100, 2);
-				$itemdata['s_valuenetto'] = round($itemdata['s_valuebrutto'] / ($taxeslist[$itemdata['taxid']]['value'] + 100) * 100, 2);
+				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ((isset($taxeslist[$itemdata['taxid']]) ? $taxeslist[$itemdata['taxid']]['value'] : 0) / 100 + 1), 2);
+				$itemdata['s_valuenetto'] = round($itemdata['s_valuebrutto'] / ((isset($taxeslist[$itemdata['taxid']]) ? $taxeslist[$itemdata['taxid']]['value'] : 0) / 100 + 1), 2);
 				$itemdata['prodid'] = $_POST['l_prodid'][$id];
 				$itemdata['jm'] = $_POST['l_jm'][$id];
 				$itemdata['posuid'] = (string) (getmicrotime()+$id);
@@ -160,6 +172,7 @@ switch($action)
 			if(checkdate($month, $day, $year)) 
 			{
 				$invoice['cdate'] = mktime(date('G',time()),date('i',time()),date('s',time()),$month,$day,$year);
+				$currmonth = $month;
 			}
 			else
 			{
@@ -171,14 +184,17 @@ switch($action)
 
 		if($invoice['cdate'] && !isset($invoice['cdatewarning']))
 		{
-			$maxdate = $DB->GetOne('SELECT MAX(cdate) FROM documents WHERE type = ? AND numberplanid = ?', array(DOC_INVOICE, $invoice['numberplanid']));
-			
+			$maxdate = $DB->GetOne('SELECT MAX(cdate) FROM documents WHERE type = ? AND numberplanid = ?', 
+					array(DOC_INVOICE, $invoice['numberplanid']));
+	
 			if($invoice['cdate'] < $maxdate)
 			{
 				$error['cdate'] = trans('Last date of invoice settlement is $0. If sure, you want to write invoice with date of $1, then click "Submit" again.',date('Y/m/d H:i', $maxdate), date('Y/m/d H:i', $invoice['cdate']));
 				$invoice['cdatewarning'] = 1;
 			}
 		}
+		elseif(!$invoice['cdate'])
+			$invoice['cdate'] = time();
 
 		if($invoice['number'])
 		{
@@ -192,7 +208,16 @@ switch($action)
 		{
 			$cid = isset($_GET['customerid']) && $_GET['customerid'] != '' ? intval($_GET['customerid']) : intval($_POST['customerid']);
 			if($LMS->CustomerExists($cid))
-				$customer = $LMS->GetCustomer($cid);
+				$customer = $LMS->GetCustomer($cid, true);
+
+			// finally check if selected customer can use selected numberplan
+			if($invoice['numberplanid'] && isset($customer))
+				if(!$DB->GetOne('SELECT 1 FROM numberplanassignments
+					WHERE planid = ? AND divisionid = ?', array($invoice['numberplanid'], $customer['divisionid'])))
+				{
+					$error['number'] = trans('Selected numbering plan doesn\'t match customer\'s division!');
+					unset($customer);
+				}
 		}
 	break;
 
@@ -201,8 +226,8 @@ switch($action)
 		if($contents && $customer)
 		{
 			$DB->BeginTrans();
-			$DB->LockTables('documents');
-			
+			$DB->LockTables(array('documents', 'cash', 'invoicecontents', 'numberplans'));
+
 			if(!$invoice['number'])
 				$invoice['number'] = $LMS->GetNewDocumentNumber(DOC_INVOICE, $invoice['numberplanid'], $invoice['cdate']);
 			else
@@ -218,8 +243,9 @@ switch($action)
 				
 			$invoice['type'] = DOC_INVOICE;
 			$iid = $LMS->AddInvoice(array('customer' => $customer, 'contents' => $contents, 'invoice' => $invoice));
-		
+
 			// usuwamy wczesniejsze zobowiazania bez faktury
+			// @todo: można to zrobić jednym zapytaniem
 			foreach($contents as $item)
 				if(isset($item['cashid']))
 					$DB->Execute('DELETE FROM cash WHERE id = ?', array($item['cashid']));
@@ -231,7 +257,13 @@ switch($action)
 			$SESSION->remove('invoicecustomer');
 			$SESSION->remove('invoice');
 			$SESSION->remove('invoicenewerror');
-			$SESSION->redirect('?m=invoice&id='.$iid);
+			
+			if(isset($_GET['print']))
+				$SESSION->save('invoiceprint', array('invoice' => $iid,
+					'original' => !empty($_GET['original']) ? 1 : 0,
+					'copy' => !empty($_GET['copy']) ? 1 : 0));
+
+			$SESSION->redirect('?m=invoicenew&action=init');
 		}
 	break;
 }
@@ -246,7 +278,7 @@ $SESSION->save('invoicenewerror', isset($error) ? $error : NULL);
 
 if($action)
 {
-	// redirect, eby refreshem nie spierdoli faktury
+	// redirect needed because we don't want to destroy contents of invoice in order of page refresh
 	$SESSION->redirect('?m=invoicenew');
 }
 
@@ -275,13 +307,19 @@ if(!isset($CONFIG['phpui']['big_networks']) || !chkconfig($CONFIG['phpui']['big_
         $SMARTY->assign('customers', $LMS->GetCustomerNames());
 }
 
+if($newinvoice = $SESSION->get('invoiceprint'))
+{
+        $SMARTY->assign('newinvoice', $newinvoice);
+        $SESSION->remove('invoiceprint');
+}
+
 $SMARTY->assign('covenantlist', $covenantlist);
 $SMARTY->assign('error', $error);
 $SMARTY->assign('contents', $contents);
 $SMARTY->assign('customer', $customer);
 $SMARTY->assign('invoice', $invoice);
 $SMARTY->assign('tariffs', $LMS->GetTariffs());
-$SMARTY->assign('numberplanlist', $LMS->GetNumberPlans(DOC_INVOICE));
+$SMARTY->assign('numberplanlist', $LMS->GetNumberPlans(DOC_INVOICE, date('Y/m', $invoice['cdate'])));
 $SMARTY->assign('taxeslist', $taxeslist);
 $SMARTY->display('invoicenew.html');
 
