@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicenote.php,v 1.25.2.2 2007/09/25 07:51:00 alec Exp $
+ *  $Id: invoicenote.php,v 1.39 2009/02/11 09:47:18 alec Exp $
  */
 
 $taxeslist = $LMS->GetTaxes();
@@ -45,7 +45,7 @@ if(isset($_GET['id']) && $action=='init')
     		$nitem['valuebrutto']	= str_replace(',','.',$item['value']);
 		$nitem['s_valuenetto']	= str_replace(',','.',$item['totalbase']);
     		$nitem['s_valuebrutto']	= str_replace(',','.',$item['total']);
-		$nitem['tax']		= $taxeslist[$item['taxid']]['label'];
+		$nitem['tax']		= isset($taxeslist[$item['taxid']]) ? $taxeslist[$item['taxid']]['label'] : 0;
 		$nitem['taxid']		= $item['taxid'];
 		$nitem['itemid']	= $item['itemid'];
 		$invoicecontents[$nitem['itemid']] = $nitem;
@@ -54,7 +54,8 @@ if(isset($_GET['id']) && $action=='init')
 	$cnote['numberplanid'] = $DB->GetOne('SELECT id FROM numberplans WHERE doctype = ? AND isdefault = 1', array(DOC_CNOTE));
 	$cnote['cdate'] = time();
 	$cnote['reason'] = '';
-	
+	$cnote['paytype'] = $invoice['paytype'];
+
 	$t = $invoice['cdate'] + $invoice['paytime']*86400;
 	$deadline = mktime(23, 59, 59, date('m',$t), date('d',$t), date('Y',$t));
 	
@@ -128,6 +129,16 @@ switch($action)
 			elseif($LMS->DocumentExists($cnote['number'], DOC_CNOTE, $cnote['numberplanid'], $cnote['cdate']))
 			        $error['number'] = trans('Credit note number $0 already exists!', $cnote['number']);
 		}
+                
+		// finally check if selected customer can use selected numberplan
+		if($cnote['numberplanid'] && !$DB->GetOne('SELECT 1 FROM numberplanassignments
+			WHERE planid = ? AND divisionid = ?', array($cnote['numberplanid'], $invoice['divisionid'])))
+		{
+		        $error['number'] = trans('Selected numbering plan doesn\'t match customer\'s division!');
+		}
+
+		if(!isset($cnote['paytype']) || $cnote['paytype'] == '')
+			$cnote['paytype'] = trans('TRANSFER');
 	break;
 
 	case 'save':
@@ -179,7 +190,7 @@ switch($action)
 				$contents[$idx]['count'] = $contents[$idx]['count'] - $item['count'];
 			}
 			
-			$DB->LockTables('documents');
+			$DB->LockTables(array('documents', 'numberplans'));
 			
 			if(!isset($cnote['number']) || !$cnote['number'])
 				$cnote['number'] = $LMS->GetNewDocumentNumber(DOC_CNOTE, $cnote['numberplanid'], $cnote['cdate']);
@@ -194,14 +205,15 @@ switch($action)
 					$cnote['number'] = $LMS->GetNewDocumentNumber(DOC_CNOTE, $cnote['numberplanid'], $cnote['cdate']);
 			}
 			
-			$DB->Execute('INSERT INTO documents (number, numberplanid, type, cdate, paytime, paytype, userid, customerid, name, address, ten, ssn, zip, city, reference, reason)
-		                	VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)',
+			$DB->Execute('INSERT INTO documents (number, numberplanid, type, cdate, paytime, paytype,
+				userid, customerid, name, address, ten, ssn, zip, city, countryid, reference, reason, divisionid)
+		                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)',
 					array($cnote['number'],
 				    		$cnote['numberplanid'] ? $cnote['numberplanid'] : 0,
 						DOC_CNOTE,
 		    				$cnote['cdate'],
 			    			$cnote['paytime'],
-						$invoice['paytype'],
+						$cnote['paytype'],
 						$AUTH->id,
 						$invoice['customerid'],
 						$invoice['name'],
@@ -210,11 +222,14 @@ switch($action)
 						$invoice['ssn'],
 						$invoice['zip'],
 						$invoice['city'],
+						$invoice['countryid'],
 						$invoice['id'],
-						$cnote['reason']
+						$cnote['reason'],
+						$invoice['divisionid'],
 					));
 																																																							    	
-			$id = $DB->GetOne('SELECT id FROM documents WHERE number = ? AND cdate = ? AND type = ?', array($cnote['number'],$cnote['cdate'],DOC_CNOTE));
+			$id = $DB->GetOne('SELECT id FROM documents WHERE number = ? AND cdate = ? AND type = ?',
+				array($cnote['number'],$cnote['cdate'],DOC_CNOTE));
 
 			$DB->UnLockTables();
 
@@ -251,7 +266,7 @@ switch($action)
 						        $idx
 						));
 			}
-			
+
 			$DB->CommitTrans();
 			
 			$SESSION->remove('invoice');
@@ -259,15 +274,15 @@ switch($action)
 			$SESSION->remove('cnote');
 			$SESSION->remove('invoicecontents');
 			$SESSION->remove('cnoteerror');
-			$SESSION->redirect('?m=invoice&id='.$id);
+			
+			if(isset($_GET['print']))
+			        $SESSION->save('invoiceprint', array('invoice' => $id,
+				        'original' => !empty($_GET['original']) ? 1 : 0,
+					'copy' => !empty($_GET['copy']) ? 1 : 0));
+
+                        $SESSION->redirect('?m=invoicelist');
 		}
 	break;
-	
-	case 'invoicedel':
-	    
-	        $LMS->InvoiceDelete($_GET['id']);
-	        $SESSION->redirect('?m=invoicelist');
-	break;				
 }
 
 $SESSION->save('invoice', $invoice);
