@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicepaid.php,v 1.26.2.1 2007/08/17 13:15:25 alec Exp $
+ *  $Id: invoicepaid.php,v 1.30 2009/01/26 14:03:52 alec Exp $
  */
 
 $SESSION->restore('ilm', $ilm);
@@ -38,9 +38,33 @@ if(sizeof($ilm))
 if(sizeof($ids))
 {
 	foreach($ids as $invoiceid)
+	{
+		// add payment
+		if(chkconfig($CONFIG['phpui']['invoice_check_payment'])
+			&& ($cid = $DB->GetOne('SELECT customerid FROM documents
+				WHERE id = ? AND closed = 0', array($invoiceid))))
+		{
+			$value = $DB->GetOne('SELECT CASE reference WHEN 0 THEN SUM(a.value*a.count)
+				ELSE SUM((a.value+b.value)*(a.count+b.count)) - SUM(b.value*b.count) END
+				FROM documents d
+				JOIN invoicecontents a ON (a.docid = d.id)
+				LEFT JOIN invoicecontents b ON (d.reference = b.docid AND a.itemid = b.itemid)
+				WHERE d.id = ?', array($invoiceid));
+
+			if ($value != 0)
+				$LMS->AddBalance(array(
+					'type' => 1,
+				        'time' => time(),
+					'value' => $value,
+					'customerid' => $cid,
+					'comment' => trans('Accounted'),
+				));
+		}
+
 		$DB->Execute('UPDATE documents SET closed = 
-				    (CASE closed WHEN 0 THEN 1 ELSE 0 END)
-				WHERE id = ?', array($invoiceid));
+			(CASE closed WHEN 0 THEN 1 ELSE 0 END)
+			WHERE id = ?', array($invoiceid));
+	}
 }
 
 $SESSION->redirect('?'.$SESSION->get('backto'));
