@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,13 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: logout.php,v 1.30.2.1 2007/08/17 13:15:25 alec Exp $
+ *  $Id: logout.php,v 1.34 2009/01/13 07:45:51 alec Exp $
  */
 
 if($_GET['is_sure'] == '1') 
 {
 	$AUTH->LogOut();
-	header('Location: ?m=welcome');
+	header('Location: ?');
 } else
 	header('Location: ?m='.$SESSION->get('lastmodule'));
 
