@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,13 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: mailing.php,v 1.56.2.2 2007/08/24 12:45:55 alec Exp $
+ *  $Id: mailing.php,v 1.63 2009/02/03 18:26:45 alec Exp $
  */
 
-function GetEmails($group, $network=NULL, $customergroup=NULL)
+function GetEmails($filter)
 {
 	global $DB, $LMS;
 	
+	$group = $filter['group'];
+	$network = $filter['network'];
+	$customergroup = $filter['customergroup'];
+	$nodegroup = $filter['nodegroup'];
+	$linktype = $filter['linktype'];
+	
 	if($group == 4)
 	{
 		$deleted = 1;
@@ -47,16 +53,22 @@ function GetEmails($group, $network=NULL, $customergroup=NULL)
 		$net = $LMS->GetNetworkParams($network);
 	
 	if($emails = $DB->GetAll('SELECT c.id AS id, email, '.$DB->Concat('c.lastname', "' '", 'c.name').' AS customername, pin, '
-		.'COALESCE(SUM(value), 0.00) AS balance '
-		.'FROM customersview c LEFT JOIN cash ON (c.id = cash.customerid) '
-		.($network ? 'LEFT JOIN nodes ON (c.id = ownerid) ' : '')
-		.($customergroup ? 'LEFT JOIN customerassignments ON (c.id = customerassignments.customerid) ' : '')
+		.'(SELECT COALESCE(SUM(value),0) FROM cash WHERE customerid = c.id) AS balance '
+		.'FROM customersview c '
 		.' WHERE deleted = '.$deleted
 		.' AND email != \'\''
 		.($group!=0 ? ' AND status = '.$group : '')
-		.($network ? ' AND (ipaddr > '.$net['address'].' AND ipaddr < '.$net['broadcast'].')' : '')
-		.($customergroup ? ' AND customergroupid='.$customergroup : '')
-		.' GROUP BY email, c.lastname, c.name, c.id, pin ORDER BY customername'))
+		.($network ? ' AND c.id IN (SELECT ownerid FROM nodes WHERE 
+			(ipaddr > '.$net['address'].' AND ipaddr < '.$net['broadcast'].') 
+			OR (ipaddr_pub > '.$net['address'].' AND ipaddr_pub < '.$net['broadcast'].'))' : '')
+		.($customergroup ? ' AND c.id IN (SELECT customerid FROM customerassignments
+			WHERE customergroupid = '.intval($customergroup).')' : '')
+		.($nodegroup ? ' AND c.id IN (SELECT ownerid FROM nodes
+			JOIN nodegroupassignments ON (nodeid = nodes.id)
+			WHERE nodegroupid = '.intval($nodegroup).')' : '')
+		.($linktype != '' ? ' AND c.id IN (SELECT ownerid FROM nodes
+			WHERE linktype = '.intval($linktype).')' : '')
+		.' ORDER BY customername'))
 	{
 		if($disabled)
 			$access = $DB->GetAllByKey('SELECT ownerid AS id FROM nodes GROUP BY ownerid HAVING (SUM(access) != COUNT(access))','id'); 
@@ -136,19 +148,20 @@ if(isset($_POST['mailing']))
 	if(!$error)
 	{
 		$layout['nomenu'] = TRUE;
-		//$mailing['body'] = textwrap($mailing['body']);
 		$mailing['body'] = wordwrap($mailing['body'],76,"\n");
 		$mailing['body'] = str_replace("\r", '', $mailing['body']);
 		$SMARTY->assign('mailing', $mailing);
 		$SMARTY->display('header.html');
 		
-		$emails = GetEmails($mailing['group'], $mailing['network'], $mailing['customergroup']);
+		$emails = GetEmails($mailing);
 		
 		$SMARTY->assign('recipcount', sizeof($emails));
 		$SMARTY->display('mailingsend.html');
 		
 		if(sizeof($emails))
 		{
+			set_time_limit(0);
+		
 			$files = NULL;
 			if (isset($file))
 			{
@@ -157,8 +170,8 @@ if(isset($_POST['mailing']))
 				$files[0]['data'] = $file;
 			}
 
-			if(isset($LMS->CONFIG['phpui']['debug_email']))
-				echo '<B>'.trans('Warning! Debug mode (using address $0).',$LMS->CONFIG['phpui']['debug_email']).'</B><BR>';
+			if(!empty($CONFIG['phpui']['debug_email']))
+				echo '<B>'.trans('Warning! Debug mode (using address $0).',$CONFIG['phpui']['debug_email']).'</B><BR>';
 			
 			$headers['Date'] = date('r');
 			$headers['From'] = '"'.$mailing['from'].'" <'.$mailing['sender'].'>';
@@ -167,8 +180,8 @@ if(isset($_POST['mailing']))
 			
 			foreach($emails as $key => $row)
 			{
-				if(isset($LMS->CONFIG['phpui']['debug_email']))
-					$row['email'] = $LMS->CONFIG['phpui']['debug_email'];
+				if(!empty($CONFIG['phpui']['debug_email']))
+					$row['email'] = $CONFIG['phpui']['debug_email'];
 				
 				$body = $mailing['body'];
 				
@@ -193,7 +206,7 @@ if(isset($_POST['mailing']))
 				}
 				
 				$headers['To'] = '<'.$row['email'].'>';
-				
+
 				echo '<img src="img/mail.gif" border="0" align="absmiddle" alt=""> '.trans('$0 of $1 ($2): $3 &lt;$4&gt;', ($key+1), sizeof($emails), sprintf('%02.1f%%',round((100/sizeof($emails))*($key+1),1)), $row['customername'], $row['email']);
 				echo '<font color=red> '.$LMS->SendMail($row['email'], $headers, $body, $files)."</font><BR>\n";
 			}
@@ -210,6 +223,7 @@ if(isset($_POST['mailing']))
 $SMARTY->assign('error', $error);
 $SMARTY->assign('networks', $LMS->GetNetworks());
 $SMARTY->assign('customergroups', $LMS->CustomergroupGetAll());
+$SMARTY->assign('nodegroups', $LMS->GetNodeGroupNames());
 $SMARTY->assign('userinfo', $LMS->GetUserInfo($AUTH->id));
 $SMARTY->display('mailing.html');
 
