@@ -1,9 +1,9 @@
 <?
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: modinfo-sample.php,v 1.6.2.1 2007/08/17 13:15:25 alec Exp $
+ *  $Id: modinfo-sample.php,v 1.10 2009/01/13 07:45:51 alec Exp $
  */
 		      
 $_MODINFO['sample'] = array(
@@ -29,14 +29,14 @@ $_MODINFO['sample'] = array(
 			'en' => 'Example template for modinfo.php',
 			'pl' => 'Przykładowy szablon dla modinfo.php'
 			),
-		'version' => '1.10.2 Roham', // version
+		'version' => '1.11.7 Bastet', // version
 		'description' => array( // description
 			'en' => 'This is sample module that contains template for modinfo.php',
 			'pl' => 'To jest przykładowy moduł, który tak naprawdę zawiera tylko przykładowy modinfo.php',
 			),
 		'author' => 'LMS-developers', // author information
 		'url' => 'http://www.lms.org.pl', // url of module homepage
-		'revision' => '$Revision: 1.6.2.1 $', // cvs revision, optiona
+		'revision' => '$Revision: 1.10 $', // cvs revision, optiona
 		'notpublic' => TRUE, // notpublic - this means, that user can't access any actions of this module
 					// directly, ie. using modified URL
 		'menus' => array( // this part of modinfo contains information about menus that this module provides
@@ -48,7 +48,7 @@ $_MODINFO['sample'] = array(
 					),
 				'img' => 'users.gif', // image from img directory, that we use in menu
 				'tip' => array( // tiptext
-					'en' => 'Systems informations and management',
+					'en' => 'Systems information and management',
 					'pl' => 'Informacja o systemie i administracja',
 					),
 				),
@@ -129,7 +129,7 @@ $_MODINFO['sample'] = array(
 					'pl' => 'Informacje',
 					),
 				'tip' => array(
-					'en' => 'Basic system informations',
+					'en' => 'Basic system information',
 					'pl' => 'Podstawowe informacje o systemie',
 					),
 				'menu' => 'core_administration',
