@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevinfo.php,v 1.28.2.1 2007/08/17 13:15:25 alec Exp $
+ *  $Id: netdevinfo.php,v 1.32 2009/01/13 07:45:51 alec Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
@@ -33,7 +33,6 @@ $netdevinfo = $LMS->GetNetDev($_GET['id']);
 $netdevconnected = $LMS->GetNetDevConnectedNames($_GET['id']);
 $netcomplist = $LMS->GetNetdevLinkedNodes($_GET['id']);
 $netdevlist = $LMS->GetNotConnectedDevices($_GET['id']);
-$nodelist = $LMS->GetNodeList();
 $replacelist = $LMS->GetNetDevList();
 
 $replacelisttotal = $replacelist['total'];
@@ -44,12 +43,6 @@ unset($replacelist['direction']);
 $nodelist = $LMS->GetUnlinkedNodes();
 $netdevips = $LMS->GetNetDevIPs($_GET['id']);
 
-unset($nodelist['total']);
-unset($nodelist['order']);
-unset($nodelist['totalon']);
-unset($nodelist['totaloff']);
-unset($nodelist['direction']);
-
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $layout['pagetitle'] = trans('Device Info: $0 $1 $2', $netdevinfo['name'], $netdevinfo['producer'], $netdevinfo['model']);
@@ -66,8 +59,15 @@ $SMARTY->assign('replacelist',$replacelist);
 $SMARTY->assign('replacelisttotal',$replacelisttotal);
 $SMARTY->assign('devlinktype',$SESSION->get('devlinktype'));
 $SMARTY->assign('nodelinktype',$SESSION->get('nodelinktype'));
+
 if(isset($_GET['ip']))
+{
 	$SMARTY->assign('nodeipdata',$LMS->GetNode($_GET['ip']));
-$SMARTY->display('netdevinfo.html');
+	$SMARTY->display('netdevipinfo.html');
+}
+else
+{
+	$SMARTY->display('netdevinfo.html');
+}
 
 ?>
