@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netedit.php,v 1.54.2.1 2007/08/17 13:15:26 alec Exp $
+ *  $Id: netedit.php,v 1.59 2009/01/13 07:45:51 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
@@ -29,12 +29,20 @@ if(!$LMS->NetworkExists($_GET['id']))
 	$SESSION->redirect('?m=netlist');
 }
 
-if($SESSION->is_set('ntlp.'.$_GET['id']) && ! isset($_GET['page']))
-	$SESSION->restore('ntlp.'.$_GET['id'], $_GET['page']);
+if(isset($_GET['id']) && isset($_GET['networkset']))
+{
+	$LMS->NetworkSet($_GET['id']);
+	$SESSION->redirect('?m=netlist#'.$_GET['id']);
+}
 
-$SESSION->save('ntlp.'.$_GET['id'], $_GET['page']);
+if($SESSION->is_set('ntlp.'.$_GET['id']) && ! isset($_GET['page']))
+	$SESSION->restore('ntlp.'.$_GET['id'], $page);
+else
+	$page = empty($_GET['page']) ? 0 : $_GET['page']; 
+
+$SESSION->save('ntlp.'.$_GET['id'], $page);
 	
-$network = $LMS->GetNetworkRecord($_GET['id'],$_GET['page'], $CONFIG['phpui']['networkhosts_pagelimit']);
+$network = $LMS->GetNetworkRecord($_GET['id'], $page, $CONFIG['phpui']['networkhosts_pagelimit']);
 
 if(isset($_POST['networkdata']))
 {
@@ -167,14 +175,15 @@ if(isset($_POST['networkdata']))
 	$network['dns2'] = $networkdata['dns2'];
 }
 
-$prefixlist = $LMS->GetPrefixList();
 $networks = $LMS->GetNetworks();
+
 $layout['pagetitle'] = trans('Network Edit: $0',$network['name']);
+
 $SMARTY->assign('unlockedit',TRUE);
 $SMARTY->assign('network',$network);
 $SMARTY->assign('networks',$networks);
 $SMARTY->assign('netlistsize',sizeof($networks));
-$SMARTY->assign('prefixlist',$prefixlist);
+$SMARTY->assign('prefixlist', $LMS->GetPrefixList());
 $SMARTY->assign('error',$error);
 $SMARTY->display('netinfo.html');
 
