@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeadd.php,v 1.78.2.2 2007/10/09 07:18:55 alec Exp $
+ *  $Id: nodeadd.php,v 1.86 2009/01/13 07:45:52 alec Exp $
  */
 
 $nodedata['access'] = 1;
@@ -70,8 +70,8 @@ if(isset($_POST['nodedata']))
 	
 	if($nodedata['name']=='')
 		$error['name'] = trans('Node name is required!');
-	elseif(strlen($nodedata['name']) > 16)
-		$error['name'] = trans('Node name is too long (max.16 characters)!');
+	elseif(strlen($nodedata['name']) > 32)
+		$error['name'] = trans('Node name is too long (max.32 characters)!');
 	elseif($LMS->GetNodeIDByName($nodedata['name']))
 		$error['name'] = trans('Specified name is in use!');
 	elseif(!eregi('^[_a-z0-9-]+$',$nodedata['name']))
@@ -126,19 +126,44 @@ if(isset($_POST['nodedata']))
 
 	if($nodedata['netdev'])
 	{
-		$netdev = $LMS->GetNetDev($nodedata['netdev']); 
-		if($netdev['ports'] <= $netdev['takenports']) 
+		$ports = $DB->GetOne('SELECT ports FROM netdevices WHERE id = ?', array($nodedata['netdev']));
+	        $takenports = $LMS->CountNetDevLinks($nodedata['netdev']);
+
+		if($ports <= $takenports) 
 			$error['netdev'] = trans('No free ports on device!');
+		elseif($nodedata['port'])
+		{
+		        if(!ereg('^[0-9]+$', $nodedata['port']) || $nodedata['port'] > $ports)
+		        {
+		                $error['port'] = trans('Incorrect port number!');
+		        }
+		        elseif($DB->GetOne('SELECT id FROM nodes WHERE netdev=? AND port=? AND ownerid>0',
+		        		array($nodedata['netdev'], $nodedata['port']))
+			        || $DB->GetOne('SELECT 1 FROM netlinks WHERE (src = ? OR dst = ?)
+			                AND (CASE src WHEN ? THEN srcport ELSE dstport END) = ?',
+			                array($nodedata['netdev'], $nodedata['netdev'], $nodedata['netdev'], $nodedata['port'])))
+			{
+			        $error['port'] = trans('Selected port number is taken by other device or node!');
+			}
+		}
 	}
 	else
 		$nodedata['netdev'] = 0;
 
+
 	if(!isset($nodedata['chkmac']))	$nodedata['chkmac'] = 0;
 	if(!isset($nodedata['halfduplex'])) $nodedata['halfduplex'] = 0;
 
 	if(!$error)
 	{
 		$nodeid = $LMS->NodeAdd($nodedata);
+
+		if($nodedata['nodegroup'] != '0')
+		{
+			$DB->Execute('INSERT INTO nodegroupassignments (nodeid, nodegroupid)
+				VALUES (?, ?)', array($nodeid, intval($nodedata['nodegroup'])));
+		}
+
 		if(!isset($nodedata['reuse']))
 		{
 			$SESSION->redirect('?m=nodeinfo&id='.$nodeid);
@@ -166,6 +191,7 @@ if($nodedata['ownerid'])
 	$SMARTY->assign('customergroups', $LMS->CustomergroupGetForCustomer($nodedata['ownerid']));
 	$SMARTY->assign('customernodes', $LMS->GetCustomerNodes($nodedata['ownerid']));
 	$SMARTY->assign('othercustomergroups', $LMS->GetGroupNamesWithoutCustomer($nodedata['ownerid']));
+	$SMARTY->assign('allnodegroups', $LMS->GetNodeGroupNames());
 	$SMARTY->assign('documents', $LMS->GetDocuments($nodedata['ownerid'], 10));
 	$SMARTY->assign('taxeslist', $LMS->GetTaxes());
 	$SMARTY->assign('tariffs', $LMS->GetTariffs());
@@ -177,6 +203,7 @@ if($nodedata['ownerid'])
 	}
 }
 
+$SMARTY->assign('allnodegroups',$LMS->GetNodeGroupNames());
 $SMARTY->assign('netdevices', $LMS->GetNetDevNames());
 $SMARTY->assign('customers', $customers);
 $SMARTY->assign('error', $error);
