@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,17 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeedit.php,v 1.95.2.1 2007/08/17 13:15:26 alec Exp $
+ *  $Id: nodeedit.php,v 1.106 2009/01/13 07:45:52 alec Exp $
  */
 
+$action = isset($_GET['action']) ? $_GET['action'] : '';
+
 if(!$LMS->NodeExists($_GET['id']))
 	if(isset($_GET['ownerid']))
 		header('Location: ?m=customerinfo&id='.$_GET['ownerid']);
 	else
 		header('Location: ?m=nodelist');
 
-$action = isset($_GET['action']) ? $_GET['action'] : '';
-
 switch($action)
 {
 	case 'link':
@@ -39,7 +39,8 @@ switch($action)
 
 		if($netdev['ports'] > $netdev['takenports']) 
 		{
-			$LMS->NetDevLinkNode($_GET['id'],$_GET['devid']);
+			$LMS->NetDevLinkNode($_GET['id'],$_GET['devid'],
+				empty($_GET['linktype']) ? 0 : 1, intval($_GET['port']));
 			$SESSION->redirect('?m=nodeinfo&id='.$_GET['id']);
 		}
 		else
@@ -57,18 +58,16 @@ switch($action)
 	break;
 }
 
-$nodeid = $_GET['id'];
+$nodeid = intval($_GET['id']);
 $ownerid = $LMS->GetNodeOwner($nodeid);
-$SESSION->save('backto', $_SERVER['QUERY_STRING']);
-	
+$nodeinfo = $LMS->GetNode($nodeid);
+
 if(!isset($_GET['ownerid']))
 	$SESSION->save('backto', $SESSION->get('backto') . '&ownerid='.$ownerid);
+else
+	$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 							
-$customerinfo = $LMS->GetCustomer($ownerid);
-$layout['pagetitle'] = trans('Node Edit: $0', $LMS->GetNodeName($_GET['id']));
-
-$customernodes = $LMS->GetCustomerNodes($ownerid);
-$nodeinfo = $LMS->GetNode($_GET['id']);
+$layout['pagetitle'] = trans('Node Edit: $0', $nodeinfo['name']);
 
 if(isset($_POST['nodeedit']))
 {
@@ -140,8 +139,8 @@ if(isset($_POST['nodeedit']))
 		$error['name'] = trans('Specified name is in use!');
 	elseif(!eregi('^[_a-z0-9-]+$',$nodeedit['name']))
 		$error['name'] = trans('Specified name contains forbidden characters!');
-	elseif(strlen($nodeedit['name'])>16)
-		$error['name'] = trans('Node name is too long (max.16 characters)!');
+	elseif(strlen($nodeedit['name'])>32)
+		$error['name'] = trans('Node name is too long (max.32 characters)!');
 
 	if(strlen($nodeedit['passwd'])>32)
 		$error['passwd'] = trans('Password is too long (max.32 characters)!');
@@ -153,15 +152,46 @@ if(isset($_POST['nodeedit']))
 
 	if($nodeinfo['netdev'] != $nodeedit['netdev'] && $nodeedit['netdev'] != 0)
 	{
-		$netdev = $LMS->GetNetDev($nodeedit['netdev']); 
-		if($netdev['ports'] <= $netdev['takenports'])
+		$ports = $DB->GetOne('SELECT ports FROM netdevices WHERE id = ?', array($nodeedit['netdev']));
+	        $takenports = $LMS->CountNetDevLinks($nodeedit['netdev']);
+
+		if($ports <= $takenports)
 		    $error['netdev'] = trans('It scans for free ports in selected device!');
 		$nodeinfo['netdev'] = $nodeedit['netdev'];
 	}
 
+	if($nodeedit['netdev'] && ($nodeedit['port'] != $nodeinfo['port'] || $nodeinfo['netdev'] != $nodeedit['netdev']))
+    	{
+		if($nodeedit['port'])
+		{
+			if(!isset($ports))
+				$ports = $DB->GetOne('SELECT ports FROM netdevices WHERE id = ?', array($nodeedit['netdev']));
+		
+		        if(!ereg('^[0-9]+$', $nodeedit['port']) || $nodeedit['port'] > $ports)
+		        {
+		                $error['port'] = trans('Incorrect port number!');
+		        }
+		        elseif($DB->GetOne('SELECT id FROM nodes WHERE netdev=? AND port=? AND ownerid>0',
+		        		array($nodeedit['netdev'], $nodeedit['port']))
+			        || $DB->GetOne('SELECT 1 FROM netlinks WHERE (src = ? OR dst = ?)
+			                AND (CASE src WHEN ? THEN srcport ELSE dstport END) = ?',
+			                array($nodeedit['netdev'], $nodeedit['netdev'], $nodeedit['netdev'], $nodeedit['port'])))
+			{
+			        $error['port'] = trans('Selected port number is taken by other device or node!');
+			}
+		}
+	}
+	
 	if($nodeedit['access'] && $LMS->GetCustomerStatus($nodeedit['ownerid']) < 3)
 		$error['access'] = trans('Node owner is not connected!');
-	
+
+	if(!$error)
+	{
+		$LMS->NodeUpdate($nodeedit, ($ownerid != $nodeedit['ownerid']));
+		$SESSION->redirect('?m=nodeinfo&id='.$nodeedit['id']);
+		die;
+	}
+
 	$nodeinfo['name'] = $nodeedit['name'];
 	$nodeinfo['mac'] = $nodeedit['mac'];
 	$nodeinfo['ip'] = $nodeedit['ipaddr'];
@@ -171,17 +201,13 @@ if(isset($_POST['nodeedit']))
 	$nodeinfo['ownerid'] = $nodeedit['ownerid'];
 	$nodeinfo['chkmac'] = $nodeedit['chkmac'];
 	$nodeinfo['halfduplex'] = $nodeedit['halfduplex'];
-
-	if(!$error)
-	{
-		$LMS->NodeUpdate($nodeedit);
-		header('Location: ?m=nodeinfo&id='.$nodeedit['id']);
-	}
+	$nodeinfo['port'] = $nodeedit['port'];
 
 	if($nodeedit['ipaddr_pub']=='0.0.0.0')
 		$nodeinfo['ipaddr_pub'] = '';
 }
 
+$customerinfo = $LMS->GetCustomer($ownerid);
 $customers = $LMS->GetCustomerNames();
 $tariffs = $LMS->GetTariffs();
 $assignments = $LMS->GetCustomerAssignments($ownerid);
@@ -192,6 +218,9 @@ $documents = $LMS->GetDocuments($ownerid, 10);
 $netdevices = $LMS->GetNetDevNames();
 $taxeslist = $LMS->GetTaxes();
 $customernodes = $LMS->GetCustomerNodes($ownerid);
+$nodegroups = $LMS->GetNodeGroupNamesByNode($nodeid);
+$othernodegroups = $LMS->GetNodeGroupNamesWithoutNode($nodeid);
+$allnodegroups = $LMS->GetNodeGroupNames();
 
 if(isset($CONFIG['phpui']['ewx_support']) && chkconfig($CONFIG['phpui']['ewx_support']))
 {
@@ -202,9 +231,12 @@ if(isset($CONFIG['phpui']['ewx_support']) && chkconfig($CONFIG['phpui']['ewx_sup
 $SMARTY->assign('netdevices',$netdevices);
 $SMARTY->assign('balancelist',$balancelist);
 $SMARTY->assign('assignments',$assignments);
-$SMARTY->assign('customergroups',$customergroups);
 $SMARTY->assign('customernodes',$customernodes);
+$SMARTY->assign('customergroups',$customergroups);
 $SMARTY->assign('othercustomergroups',$othercustomergroups);
+$SMARTY->assign('allnodegroups',$allnodegroups);
+$SMARTY->assign('nodegroups',$nodegroups);
+$SMARTY->assign('othernodegroups',$othernodegroups);
 $SMARTY->assign('tariffs',$tariffs);
 $SMARTY->assign('error',$error);
 $SMARTY->assign('customerinfo',$customerinfo);
