@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeinfo.php,v 1.60.2.1 2007/08/17 13:15:26 alec Exp $
+ *  $Id: nodeinfo.php,v 1.65 2009/01/13 07:45:52 alec Exp $
  */
 
 function NodeStats($id, $dt)
@@ -39,6 +39,16 @@ function NodeStats($id, $dt)
 	return $result;
 }
 
+if(isset($_GET['nodegroups']))
+{
+	$nodegroups = $LMS->GetNodeGroupNamesByNode(intval($_GET['id']));
+	
+	$SMARTY->assign('nodegroups', $nodegroups);
+	$SMARTY->assign('total', sizeof($nodegroups));
+	$SMARTY->display('nodegrouplistshort.html');
+	die;
+}
+
 if(!eregi('^[0-9]+$',$_GET['id']))
 {
 	$SESSION->redirect('?m=nodelist');
@@ -77,6 +87,9 @@ $customergroups = $LMS->CustomergroupGetForCustomer($ownerid);
 $othercustomergroups = $LMS->GetGroupNamesWithoutCustomer($ownerid);
 $taxeslist = $LMS->GetTaxes();
 $customernodes = $LMS->GetCustomerNodes($ownerid);
+$allnodegroups = $LMS->GetNodeGroupNames();
+$nodegroups = $LMS->GetNodeGroupNamesByNode($nodeid);
+$othernodegroups = $LMS->GetNodeGroupNamesWithoutNode($nodeid);
 
 $nodestats['hour'] = NodeStats($nodeid, 60*60);
 $nodestats['day'] = NodeStats($nodeid, 60*60*24);
@@ -106,9 +119,12 @@ $SMARTY->assign('customerinfo',$customerinfo);
 $SMARTY->assign('nodeinfo',$nodeinfo);
 $SMARTY->assign('nodestats',$nodestats);
 $SMARTY->assign('assignments',$assignments);
-$SMARTY->assign('customergroups',$customergroups);
 $SMARTY->assign('customernodes',$customernodes);
+$SMARTY->assign('customergroups',$customergroups);
 $SMARTY->assign('othercustomergroups',$othercustomergroups);
+$SMARTY->assign('allnodegroups',$allnodegroups);
+$SMARTY->assign('nodegroups',$nodegroups);
+$SMARTY->assign('othernodegroups',$othernodegroups);
 $SMARTY->assign('documents', $documents);
 $SMARTY->assign('taxeslist', $taxeslist);
 $SMARTY->assign('tariffs',$tariffs);
