@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodewarn.php,v 1.23.2.1 2007/08/17 13:15:26 alec Exp $
+ *  $Id: nodewarn.php,v 1.28 2009/01/13 07:45:52 alec Exp $
  */
 
 $setwarnings = isset($_POST['setwarnings']) ? $_POST['setwarnings'] : array();
@@ -50,6 +50,14 @@ if(isset($setwarnings['mnodeid']))
 	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
+if(!empty($_POST['marks']))
+{
+        foreach($_POST['marks'] as $id)
+	        $LMS->NodeSetWarn($id, isset($_GET['warning']) ? 1 : 0);
+
+	$SESSION->redirect('?'.$SESSION->get('backto'));
+}
+
 $backid = isset($_GET['ownerid']) ? $_GET['ownerid'] : 0;
 
 if($backid)
@@ -73,7 +81,13 @@ if($backid)
 	if($LMS->NodeExists($backid))
 	{
 		$LMS->NodeSwitchWarn($backid);
-		$SESSION->redirect('?'.$SESSION->get('backto').'#'.$backid);
+		if(!empty($_GET['shortlist']))
+		{
+		        header('Location: ?m=nodelistshort&id='.$LMS->GetNodeOwner($backid));
+			die;
+		}
+		else	
+			$SESSION->redirect('?'.$SESSION->get('backto').'#'.$backid);
 	}
 }
 
