@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: numberplandel.php,v 1.4.2.1 2007/08/17 13:15:26 alec Exp $
+ *  $Id: numberplandel.php,v 1.8 2009/01/13 07:45:52 alec Exp $
  */
 
 $id = $_GET['id'];
@@ -31,6 +31,7 @@ if($_GET['is_sure']==1 && $id)
 	if( !$DB->GetOne('SELECT COUNT(*) FROM documents WHERE numberplanid=?', array($id)))
 	{
 		$DB->Execute('DELETE FROM numberplans WHERE id=?', array($id));
+		$DB->Execute('DELETE FROM numberplanassignments WHERE planid=?', array($id));
 	}
 }	
 
