@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: numberplanedit.php,v 1.5.2.1 2007/08/17 13:15:26 alec Exp $
+ *  $Id: numberplanedit.php,v 1.10 2009/01/13 07:45:52 alec Exp $
  */
 
 $numberplan = $DB->GetRow('SELECT id, period, template, doctype, isdefault
@@ -41,7 +41,7 @@ if(sizeof($numberplanedit))
 	elseif(!preg_match('/%[1-9]{0,1}N/', $numberplanedit['template']))
 		$error['template'] = trans('Template must consist "%N" specifier!');
 
-	if(!$numberplanedit['isdefault'])
+	if(!isset($numberplanedit['isdefault']))
 		$numberplanedit['isdefault'] = 0;
 
 	if($numberplanedit['doctype'] == 0)
@@ -51,11 +51,22 @@ if(sizeof($numberplanedit))
 		$error['period'] = trans('Numbering period is required!');
 	
 	if($numberplanedit['doctype'] && $numberplanedit['isdefault'])
-		if($DB->GetOne('SELECT 1 FROM numberplans WHERE doctype=? AND isdefault=1 AND id!=?', array($numberplanedit['doctype'], $numberplanedit['id'])))
+		if($DB->GetOne('SELECT 1 FROM numberplans n
+			WHERE doctype = ? AND isdefault = 1 AND n.id != ?'
+			.(!empty($numberplanedit['divisions']) ? ' AND EXISTS (
+				SELECT 1 FROM numberplanassignments WHERE planid = n.id
+				AND divisionid IN ('.implode(',', $numberplanedit['divisions']).'))'
+			: ' AND NOT EXISTS (SELECT 1 FROM numberplanassignments
+			        WHERE planid = n.id)'),					
+			array($numberplanedit['doctype'], $numberplanedit['id'])))
+		{
 			$error['doctype'] = trans('Selected document type has already defined default plan!');
-
+		}
+	
 	if(!$error)
 	{
+		$DB->BeginTrans();
+		
 		$DB->Execute('UPDATE numberplans SET template=?, doctype=?, period=?, isdefault=? WHERE id=?',
 			    array(
 				    $numberplanedit['template'],
@@ -63,18 +74,34 @@ if(sizeof($numberplanedit))
 				    $numberplanedit['period'],
 				    $numberplanedit['isdefault'],
 				    $numberplanedit['id']
-				    ));
+			    ));
+		
+		$DB->Execute('DELETE FROM numberplanassignments WHERE planid = ?', array($numberplanedit['id']));
+	
+		if(!empty($numberplanedit['divisions']))
+			foreach($numberplanedit['divisions'] as $div)
+				$DB->Execute('INSERT INTO numberplanassignments (planid, divisionid)
+					VALUES (?, ?)', array($numberplanedit['id'], intval($div)));
+
+		$DB->CommitTrans();
 		
 		$SESSION->redirect('?m=numberplanlist');
 	}
 	$numberplan = $numberplanedit;
-}	
+}
+else
+	$numberplan['divisions'] = $DB->GetCol('SELECT divisionid
+			FROM numberplanassignments WHERE planid = ?', array($numberplan['id']));
 
 $layout['pagetitle'] = trans('Numbering Plan Edit: $0', $template);
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('numberplanedit', $numberplan);
+$SMARTY->assign('divisions', $DB->GetAll('SELECT id, shortname FROM divisions
+		WHERE status = 0 '
+		.(!empty($numberplan['divisions']) ? 'OR id IN ('.implode(',', $numberplan['divisions']).')' : '')
+		.'ORDER BY shortname', array($numberplan['id'])));
 $SMARTY->assign('error', $error);
 $SMARTY->display('numberplanedit.html');
 
