@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentadd.php,v 1.16.2.1 2007/08/17 13:15:26 alec Exp $
+ *  $Id: paymentadd.php,v 1.21 2009/01/13 07:45:52 alec Exp $
  */
 
 $payment = isset($_POST['payment']) ? $_POST['payment'] : NULL;
@@ -51,9 +51,6 @@ if($payment)
 
 	$period = sprintf('%d',$payment['period']);
 	
-	if($period < DAILY || $period > YEARLY)
-		$period = MONTHLY;
-
 	switch($period)
 	{
 		case DAILY:
@@ -64,21 +61,11 @@ if($payment)
 			if($at < 1 || $at > 7)
 				$error['at'] = trans('Incorrect day of week (1-7)!');
 		break;
-		case MONTHLY:
-			$at = sprintf('%d',$payment['at']);
-			if($at == 0)
-			{
-				$at = 1 + date('d',time());
-				if($at > 28)
-					$at = 1;
-			}
-			if($at < 1 || $at > 28)
-		    		$error['at'] = trans('Incorrect day of month (1-28)!');
-		break;
 		case QUARTERLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
 				$error['at'] = trans('Incorrect date format!');
-			else {
+			else
+			{
 				list($d,$m) = split('/',trim($payment['at']));
 				if($d>30 || $d<1)
 					$error['at'] = trans('Incorrect day of month (1-30)!');
@@ -88,14 +75,41 @@ if($payment)
 				$at = ($m-1) * 100 + $d;
 			};
 		break;
+		case HALFYEARLY:
+                        if(!eregi('^[0-9]{2}/[0-9]{2}$',$payment['at']) && $payment['at'])
+		                $error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
+		        else
+		        {
+		                list($d,$m) = split('/',$payment['at']);
+		                if($d>30 || $d<1 || ($d>28 && $m==2))
+		                        $error['at'] = trans('This month doesn\'t contain specified number of days');
+		                if($m>6 || $m<1)
+		                        $error['at'] = trans('Incorrect month number (max.6)!');
+		                $at = ($m-1) * 100 + $d;
+		        }
+		break;
 		case YEARLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
 				$error['at'] = trans('Incorrect date format!');
 			else
+			{
 				list($d,$m) = split('/',trim($payment['at']));
-			$ttime = mktime(12, 0, 0, $m, $d, 1990);
-			$at = date('z',$ttime) + 1;
+				$ttime = mktime(12, 0, 0, $m, $d, 1990);
+				$at = date('z',$ttime) + 1;
+			}
 		break;	
+		default: // MONTHLY
+			$period = MONTHLY;
+			$at = sprintf('%d', $payment['at']);
+			if($at == 0)
+			{
+				$at = 1 + date('d',time());
+				if($at > 28)
+					$at = 1;
+			}
+			if($at < 1 || $at > 28)
+		    		$error['at'] = trans('Incorrect day of month (1-28)!');
+		break;
 	}
 	
 	$payment['period'] = $period;
