@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentedit.php,v 1.18.2.1 2007/08/17 13:15:26 alec Exp $
+ *  $Id: paymentedit.php,v 1.23 2009/01/13 07:45:52 alec Exp $
  */
 
 if(!$LMS->PaymentExists($_GET['id']))
@@ -53,9 +53,6 @@ if(isset($_POST['payment']))
 
 	$period = sprintf('%d',$payment['period']);
 	
-	if($period < DAILY || $period > YEARLY)
-		$period = MONTHLY;
-
 	switch($period)
 	{
 		case DAILY:
@@ -68,22 +65,11 @@ if(isset($_POST['payment']))
 				$error['at'] = trans('Incorrect day of week (1-7)!');
 		break;
 		
-		case MONTHLY:
-			$at = sprintf('%d',$payment['at']);
-			if($at == 0)
-			{
-				$at = 1 + date('d',time());
-				if($at > 28)
-					$at = 1;
-			}
-			if($at < 1 || $at > 28)
-				$error['at'] = trans('Incorrect day of month (1-28)!');
-		break;
-			
 		case QUARTERLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
 				$error['at'] = trans('Incorrect date format!');
-			else {
+			else
+			{
 				list($d,$m) = split('/',trim($payment['at']));
 				if($d>30 || $d<1)
 					$error['at'] = trans('Incorrect day of month (1-30)!');
@@ -94,13 +80,43 @@ if(isset($_POST['payment']))
 			};
 		break;
 		
+		case HALFYEARLY:
+                        if(!eregi('^[0-9]{2}/[0-9]{2}$',$payment['at']) && $payment['at'])
+		                $error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
+		        else
+			{
+		                list($d,$m) = split('/',$payment['at']);
+			        
+				if($d>30 || $d<1 || ($d>28 && $m==2))
+			        	$error['at'] = trans('This month doesn\'t contain specified number of days');
+			        if($m>6 || $m<1)
+			        	$error['at'] = trans('Incorrect month number (max.6)!');
+			        $at = ($m-1) * 100 + $d;
+			}
+		break;
+		
 		case YEARLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
 				$error['at'] = trans('Incorrect date format!');
 			else
+			{
 				list($d,$m) = split('/',trim($payment['at']));
-			$ttime = mktime(12, 0, 0, $m, $d, 1990);
-			$at = date('z',$ttime) + 1;
+				$ttime = mktime(12, 0, 0, $m, $d, 1990);
+				$at = date('z',$ttime) + 1;
+			}
+		break;
+		
+		default: // MONTHLY
+			$period = MONTHLY;
+			$at = sprintf('%d',$payment['at']);
+			if($at == 0)
+			{
+				$at = 1 + date('d',time());
+				if($at > 28)
+					$at = 1;
+			}
+			if($at < 1 || $at > 28)
+				$error['at'] = trans('Incorrect day of month (1-28)!');
 		break;
 	}
 	
@@ -121,8 +137,10 @@ else
 
 	if($payment['period'] == YEARLY)
 		$payment['at'] = date('d/m',($payment['at']-1)*86400);
-	if($payment['period'] == QUARTERLY)
+	elseif($payment['period'] == QUARTERLY)
 		$payment['at'] = sprintf('%02d/%02d',($payment['at']%100),$payment['at']/100+1);
+	elseif($payment['period'] == HALFYEARLY)
+                $payment['at'] = sprintf('%02d/%02d', $payment['at']%100, $payment['at']/100+1);
 }
 	
 $layout['pagetitle'] = trans('Payment Edit: $0',$payment['name']);
