@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: print.php,v 1.118.2.4 2007/11/12 08:03:09 alec Exp $
+ *  $Id: print.php,v 1.131 2009/01/28 16:31:25 alec Exp $
  */
 
 $type = isset($_GET['type']) ? $_GET['type'] : '';
@@ -34,10 +34,16 @@ switch($type)
 		$to = $_POST['to'];
 
 		// date format 'yyyy/mm/dd'	
-		list($year, $month, $day) = split('/',$from);
-		$date['from'] = mktime(0, 0, 0, (int)$month, (int)$day, (int)$year);
+		if($from && ereg('^[0-9]{4}/[0-9]{2}/[0-9]{2}$', $from))
+		{
+			list($year, $month, $day) = split('/',$from);
+    			$date['from'] = mktime(0, 0, 0, (int)$month, (int)$day, (int)$year);
+		}
+		else
+			$date['from'] = 0;
 
-		if($to) {
+		if($to && ereg('^[0-9]{4}/[0-9]{2}/[0-9]{2}$', $to))
+		{
 			list($year, $month, $day) = split('/',$to);
 			$date['to'] = mktime(23,59,59,$month,$day,$year);
 		} else { 
@@ -49,6 +55,13 @@ switch($type)
 
 		$layout['pagetitle'] = trans('Customer $0 Balance Sheet ($1 to $2)',$LMS->GetCustomerName($id), ($from ? $from : ''), $to);
 
+		$list['balance'] = 0;
+		$list['income'] = 0;
+		$list['expense'] = 0;
+		$list['liability'] = 0;
+		$list['summary'] = 0;
+		$list['customerid'] = $id;
+
 		if($tslist = $DB->GetAll('SELECT c.id AS id, time, type, c.value AS value, 
 				    taxes.label AS taxlabel, customerid, comment, name AS username 
 				    FROM cash c
@@ -65,6 +78,8 @@ switch($type)
 			foreach($tslist as $row)
 				foreach($row as $column => $value)
 					$saldolist[$column][] = $value;
+			
+			$saldolist['balance'] = 0;
 
 			foreach($saldolist['id'] as $i => $v)
 			{
@@ -100,11 +115,7 @@ switch($type)
 			}
 			
 			$list['total'] = sizeof($list['id']);
-
-		} else
-			$list['balance'] = 0;
-
-		$list['customerid'] = $id;
+		}
 		
 		$SMARTY->assign('balancelist', $list);
 		$SMARTY->display('printcustomerbalance.html');
@@ -116,6 +127,9 @@ switch($type)
 		$to = $_POST['balanceto'];
 		$net = intval($_POST['network']);
 		$group = intval($_POST['customergroup']);
+		$division = intval($_POST['division']);
+		$types = isset($_POST['types']) ? $_POST['types'] : NULL;
+		$docs = $_POST['docs'];
 
 		// date format 'yyyy/mm/dd'
 		if($from)
@@ -139,6 +153,28 @@ switch($type)
 			$layout['pagetitle'] = trans('Balance Sheet of User: $0 ($1 to $2)', $LMS->GetUserName($user), ($from ? $from : ''), $to);
 		else
 			$layout['pagetitle'] = trans('Balance Sheet ($0 to $1)', ($from ? $from : ''), $to);
+	
+		if($types)
+		{
+			foreach($types as $tt)
+				switch($tt)
+				{
+					case 1:
+						$typewhere[] = 'c.type = 0';
+						$typetxt[] = trans('Liability');
+					break;
+					case 2:
+						$typewhere[] = '(c.type = 1 AND c.value > 0)';
+						$typetxt[] = trans('Income');
+					break;
+					case 3: // expense
+						$typewhere[] = '(c.type = 1 AND c.value < 0)';
+						$typetxt[] = trans('Expense');
+					break;
+				}
+			
+			$typewhere = ' AND ('.implode(' OR ', $typewhere).')';
+		}
 		
 		$customerslist = $DB->GetAllByKey('SELECT id, '.$DB->Concat('UPPER(lastname)',"' '",'name').' AS customername FROM customers','id');
 		
@@ -147,8 +183,11 @@ switch($type)
 					FROM cash c '
 					.($group ? 'LEFT JOIN customerassignments a ON (c.customerid = a.customerid) ' : '')
 					.'WHERE time<?'
+					.($docs ? ($docs == 'documented' ? ' AND c.docid > 0' : ' AND c.docid = 0') : '')
 					.($group ? ' AND a.customergroupid = '.$group : '')
 					.($net ? ' AND EXISTS (SELECT 1 FROM nodes WHERE c.customerid = ownerid AND ((ipaddr > '.$net['address'].' AND ipaddr < '.$net['broadcast'].') OR (ipaddr_pub > '.$net['address'].' AND ipaddr_pub < '.$net['broadcast'].')))' : '')
+					.($division ? ' AND EXISTS (SELECT 1 FROM customers WHERE id = c.customerid AND divisionid = '.$division.')' : '')
+					.($types ? $typewhere : '')
 					.' AND NOT EXISTS (
 			        		SELECT 1 FROM customerassignments a
 						JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
@@ -163,9 +202,12 @@ switch($type)
 					LEFT JOIN taxes ON (taxid = taxes.id) '
 					.($group ? 'LEFT JOIN customerassignments a ON (c.customerid = a.customerid)  ' : '')
 					.'WHERE time <= ? '
+					.($docs ? ($docs == 'documented' ? ' AND c.docid > 0' : ' AND c.docid = 0') : '')
 					.(isset($date['from']) ? ' AND time >= '.$date['from'] : '')
 					.($group ? ' AND a.customergroupid = '.$group : '')
 					.($net ? ' AND EXISTS (SELECT 1 FROM nodes WHERE c.customerid = ownerid AND ((ipaddr > '.$net['address'].' AND ipaddr < '.$net['broadcast'].') OR (ipaddr_pub > '.$net['address'].' AND ipaddr_pub < '.$net['broadcast'].')))' : '')
+					.($division ? ' AND EXISTS (SELECT 1 FROM customers WHERE id = c.customerid AND divisionid = '.$division.')' : '')
+					.($types ? $typewhere : '')
 					.' AND NOT EXISTS (
 			        		SELECT 1 FROM customerassignments a
 						JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
@@ -227,9 +269,13 @@ switch($type)
 
 		if($net)
 			$SMARTY->assign('net', $net['name']);
+		if($types)
+			$SMARTY->assign('types', implode(', ', $typetxt));
 		if($group)
 			$SMARTY->assign('group', $DB->GetOne('SELECT name FROM customergroups WHERE id = ?', array($group)));
-		
+		if($division)
+    			$SMARTY->assign('division', $DB->GetOne('SELECT name FROM divisions WHERE id = ?', array($division)));
+								
 		$SMARTY->display('printbalancelist.html');
 	break;
 
@@ -295,7 +341,16 @@ switch($type)
 		if(!$type) $type = '&oryginal=1';
 		
 		$layout['pagetitle'] = trans('Invoices');
-		header('Location: ?m=invoice&fetchallinvoices=1'.$type.'&customerid='.$_POST['customer'].'&from='.$date['from'].'&to='.$date['to']);
+	
+		header('Location: ?m=invoice&fetchallinvoices=1'
+			.$type
+			.'&from='.$date['from']
+			.'&to='.$date['to']
+			.(!empty($_POST['customer']) ? '&customerid='.intval($_POST['customer']) : '')
+			.(!empty($_POST['group']) ? '&groupid='.intval($_POST['group']) : '')
+			.(!empty($_POST['numberplan']) ? '&numberplanid='.intval($_POST['numberplan']) : '')
+			.(!empty($_POST['groupexclude']) ? '&groupexclude=1' : '')
+		);
 	break;	
 
 	case 'transferforms': /********************************************/
@@ -303,10 +358,6 @@ switch($type)
 		$from = $_POST['invoicefrom'];
 		$to = $_POST['invoiceto'];
 
-		// date format 'yyyy/mm/dd'	
-		list($year, $month, $day) = split('/',$from);
-		$date['from'] = mktime(0,0,0,(int)$month,(int)$day,(int)$year);
-
 		if($to) {
 			list($year, $month, $day) = split('/',$to);
 			$date['to'] = mktime(23,59,59,$month,$day,$year);
@@ -314,10 +365,22 @@ switch($type)
 			$to = date('Y/m/d',time());
 			$date['to'] = mktime(23,59,59); //koniec dnia dzisiejszego
 		}
+
+		if($from) {
+			list($year, $month, $day) = split('/',$from);
+			$date['from'] = mktime(0,0,0,$month,$day,$year);
+		} else { 
+			$from = date('Y/m/d',time());
+			$date['from'] = mktime(0,0,0); //pocztek dnia dzisiejszego
+		}
 		
 		$_GET['from'] = $date['from'];
 		$_GET['to'] = $date['to'];
 		$_GET['customerid'] = $_POST['customer'];
+		$_GET['groupid'] = $_POST['group'];
+		$_GET['numberplan'] = $_POST['numberplan'];
+		$_GET['groupexclude'] = !empty($_POST['groupexclude']) ? 1 : 0;
+		$which = '';
 		
 		require_once(MODULES_DIR.'/transferforms.php');
 		
@@ -514,6 +577,7 @@ switch($type)
 
 		$registry = intval($_POST['registry']);
 		$user = intval($_POST['user']);
+		$group = intval($_POST['group']);
 		$where = '';
 		
 		if($registry)
@@ -524,12 +588,22 @@ switch($type)
 			$where .= ' AND cdate <= '.$to;
 		if($user)
 			$where .= ' AND userid = '.$user;
-			
+		if($group)
+		{
+		        $groupwhere = ' AND '.(isset($_POST['groupexclude']) ? 'NOT' : '').'
+			            EXISTS (SELECT 1 FROM customerassignments a
+				            WHERE a.customergroupid = '.$group.'
+					    AND a.customerid = d.customerid)';
+			$where .= $groupwhere;
+		}
+											
 		if($from > 0)
 			$listdata['startbalance'] = $DB->GetOne('SELECT SUM(value) FROM receiptcontents
 						LEFT JOIN documents d ON (docid = d.id AND type = ?) 
 						WHERE cdate < ?'
 						.($registry ? ' AND regid='.$registry : '')
+						.($user ? ' AND userid='.$user : '')
+						.($group ? $groupwhere : '')
 						.' AND NOT EXISTS (
 						        SELECT 1 FROM customerassignments a
 							JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
@@ -591,11 +665,20 @@ switch($type)
 			$period = $from.' - '.$to;
 
 		$layout['pagetitle'] = trans('Cash Report').' '.$period;
-		$layout['registry'] = trans('Registry: $0', ($registry ? $DB->GetOne('SELECT name FROM cashregs WHERE id=?', array($registry)) : trans('all')));
 		
+		if($registry)
+			$layout['registry'] = trans('Registry: $0', ($registry ? $DB->GetOne('SELECT name FROM cashregs WHERE id=?', array($registry)) : trans('all')));
 		if($user)
 			$layout['username'] = trans('Cashier: $0', $DB->GetOne('SELECT name FROM users WHERE id=?', array($user)));
-		
+		if($group)
+		{
+			$groupname = $DB->GetOne('SELECT name FROM customergroups WHERE id=?', array($group));
+	
+			if(isset($_POST['groupexclude']))
+				$layout['group'] = trans('Group: all excluding $0', $groupname);
+			else	
+				$layout['group'] = trans('Group: $0', $groupname);
+		}
 		$SMARTY->assign('receiptlist', $list);
 		$SMARTY->assign('listdata', $listdata);
 
@@ -605,7 +688,7 @@ switch($type)
 			$totals = array();
 					
 			// hidden option: max records count for one page of printout
-			// I thinks 20 records is fine, but someone needs 19.
+			// I think 20 records is fine, but someone needs 19.
 			$rows = isset($CONFIG['phpui']['printout_pagelimit']) ? $CONFIG['phpui']['printout_pagelimit'] : 20;
 
 			// create a new array and do some calculations 
@@ -674,6 +757,7 @@ switch($type)
 		$SMARTY->assign('customergroups', $LMS->CustomergroupGetAll());
 		$SMARTY->assign('numberplans', $LMS->GetNumberPlans(array(DOC_INVOICE, DOC_CNOTE)));
 		$SMARTY->assign('cashreglist', $DB->GetAllByKey('SELECT id, name FROM cashregs ORDER BY name', 'id'));
+		$SMARTY->assign('divisions', $DB->GetAll('SELECT id, shortname FROM divisions ORDER BY shortname'));
 		$SMARTY->assign('printmenu', 'finances');
 		$SMARTY->display('printindex.html');
 	break;
