@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,15 +21,9 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: quicksearch.php,v 1.47.2.3 2007/11/07 09:16:43 alec Exp $
+ *  $Id: quicksearch.php,v 1.63 2009/01/13 07:45:53 alec Exp $
  */
 
-function escape_js($string)
-{
-        // escape quotes and backslashes, newlines, etc.
-        return strtr($string, array('\\'=>'\\\\',"'"=>"\\'",'"'=>'\\"',"\r"=>'\\r',"\n"=>'\\n','</'=>'<\/'));
-}
-
 function macformat($mac)
 {
 	$res = str_replace('-', ':', $mac);
@@ -59,16 +53,19 @@ function macformat($mac)
 
 $mode = '';
 
-if(isset($_POST['qscustomer']) && $_POST['qscustomer']) {
+if(!empty($_POST['qscustomer'])) {
 	$mode = 'customer'; 
 	$search = urldecode(trim($_POST['qscustomer']));
-} elseif(isset($_POST['qsnode']) && $_POST['qsnode']) {
+} elseif(!empty($_POST['qsnode'])) {
 	$mode = 'node'; 
 	$search = urldecode(trim($_POST['qsnode']));
-} elseif(isset($_POST['qsticket']) && $_POST['qsticket']) {
+} elseif(!empty($_POST['qsticket'])) {
 	$mode = 'ticket'; 
 	$search = urldecode(trim($_POST['qsticket']));
-} else {
+} elseif(!empty($_POST['qsaccount'])) {
+	$mode = 'account'; 
+	$search = urldecode(trim($_POST['qsaccount']));
+} elseif(!empty($_GET['what'])) {
 	$search = urldecode(trim($_GET['what']));
 	$mode = $_GET['mode'];
 }
@@ -79,19 +76,21 @@ switch($mode)
 		if(isset($_GET['ajax'])) // support for AutoSuggest
 		{
 			$candidates = $DB->GetAll('SELECT id, lastname, name, email, address, deleted 
-					    FROM customersview 
-					    WHERE id ?LIKE? \''.$search.'%\' 
-						    OR LOWER(lastname) ?LIKE? LOWER(\'%'.$search.'%\') 
-						    OR LOWER(name) ?LIKE? LOWER(\'%'.$search.'%\') 
-						    OR LOWER(address) ?LIKE? LOWER(\'%'.$search.'%\') 
-						    OR LOWER(email) ?LIKE? LOWER(\'%'.$search.'%\') 
-						    ORDER by deleted, lastname, name, email, address LIMIT 15');
+				FROM customersview 
+				WHERE '.(ereg('^[0-9]+$', $search) ? 'id = '.intval($search).' OR ' : '').' 
+					LOWER(lastname) ?LIKE? LOWER(\'%'.$search.'%\')
+					OR LOWER(name) ?LIKE? LOWER(\'%'.$search.'%\') 
+					OR LOWER(address) ?LIKE? LOWER(\'%'.$search.'%\') 
+					OR LOWER(email) ?LIKE? LOWER(\'%'.$search.'%\') 
+				ORDER by deleted, lastname, name, email, address 
+				LIMIT 15');
+
 			$eglible=array(); $actions=array(); $descriptions=array();
 			if ($candidates)
 			foreach($candidates as $idx => $row) {
 				$actions[$row['id']] = '?m=customerinfo&id='.$row['id'];
 				$eglible[$row['id']] = escape_js(($row['deleted'] ? '<font class="blend">' : '').$row['lastname'].' '.$row['name'].($row['deleted'] ? '</font>' : ''));
-				if (preg_match("~^$search~i",$row['id'])) 	{ $descriptions[$row['id']] = escape_js(trans('Id:').' '.$row['id']); continue; }
+				if (preg_match("~^$search\$~i",$row['id'])) 	{ $descriptions[$row['id']] = escape_js(trans('Id:').' '.$row['id']); continue; }
 //				if (preg_match("~$search~i",$row['lastname'])) 	{ $descriptions[$row['id']] = escape_js(trans('Name/Surname:').' '.$row['lastname']); continue; }
 //				if (preg_match("~$search~i",$row['name'])) 	{ $descriptions[$row['id']] = escape_js(trans('First name:').' '.$row['name']); continue; }
 				if (preg_match("~$search~i",$row['address'])) 	{ $descriptions[$row['id']] = escape_js(trans('Address:').' '.$row['address']); continue; }
@@ -125,13 +124,14 @@ switch($mode)
 		$s['city'] = $search;
 		$s['phone'] = $search;
 		$s['email'] = $search;
+
 		$SESSION->save('customersearch', $s);
-		$SESSION->save('uslk', 'OR');
+		$SESSION->save('cslk', 'OR');
 		
-		$SESSION->remove('uslp');
-		$SESSION->remove('usln');
-		$SESSION->remove('uslg');
-		$SESSION->remove('usls');
+		$SESSION->remove('cslp');
+		$SESSION->remove('csln');
+		$SESSION->remove('cslg');
+		$SESSION->remove('csls');
 		
 		$target = '?m=customersearch&search=1';
 	break;
@@ -140,24 +140,25 @@ switch($mode)
 		if(isset($_GET['ajax'])) // support for AutoSuggest
 		{
 			$candidates = $DB->GetAll('SELECT n.id, n.name, INET_NTOA(ipaddr) as ip, INET_NTOA(ipaddr_pub) AS ip_pub, mac 
-				    FROM nodes n
-				    WHERE (n.id ?LIKE? \''.$search.'%\' 
-					    OR LOWER(n.name) ?LIKE? LOWER(\'%'.$search.'%\') 
-					    OR INET_NTOA(ipaddr) ?LIKE? \'%'.$search.'%\' 
-					    OR INET_NTOA(ipaddr_pub) ?LIKE? \'%'.$search.'%\' 
-					    OR LOWER(mac) ?LIKE? LOWER(\'%'.macformat($search).'%\')
-					    ) 
-				    AND NOT EXISTS (
+				FROM nodes n
+				WHERE ('.(ereg('^[0-9]+$',$search) ? 'n.id = '.intval($search).' OR ' : '').' 
+					LOWER(n.name) ?LIKE? LOWER(\'%'.$search.'%\') 
+					OR INET_NTOA(ipaddr) ?LIKE? \'%'.$search.'%\' 
+					OR INET_NTOA(ipaddr_pub) ?LIKE? \'%'.$search.'%\' 
+					OR LOWER(mac) ?LIKE? LOWER(\'%'.macformat($search).'%\')
+					) 
+					AND NOT EXISTS (
                     			    SELECT 1 FROM customerassignments a
 			                    JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
 					    WHERE e.userid = lms_current_user() AND a.customerid = n.ownerid)
-				    ORDER BY n.name LIMIT 15');
+				ORDER BY n.name LIMIT 15');
+			
 			$eglible=array(); $actions=array(); $descriptions=array();
 			if ($candidates)
 			foreach($candidates as $idx => $row) {
 				$actions[$row['id']] = '?m=nodeinfo&id='.$row['id'];
 				$eglible[$row['id']] = escape_js($row['name']);
-				if (preg_match("~^$search~i",$row['id'])) 	{ $descriptions[$row['id']] = escape_js(trans('Id').': '.$row['id']); continue; }
+				if (preg_match("~^$search\$~i",$row['id'])) 	{ $descriptions[$row['id']] = escape_js(trans('Id').': '.$row['id']); continue; }
 //				if (preg_match("~$search~i",$row['name'])) 	{ $descriptions[$row['id']] = escape_js(trans('Name').': '.$row['name']); continue; }
 				if (preg_match("~$search~i",$row['ip'])) 	{ $descriptions[$row['id']] = trans('IP').': '.$row['ip']; continue; }
 				if (preg_match("~$search~i",$row['ip_pub'])) 	{ $descriptions[$row['id']] = trans('IP').': '.$row['ip_pub']; continue; }
@@ -188,24 +189,35 @@ switch($mode)
 		$s['name'] = $search;
 		$s['mac'] = $search;
 		$s['ipaddr'] = $search;
+		
 		$SESSION->save('nodesearch', $s);
 		$SESSION->save('nslk', 'OR');
 
 		$SESSION->remove('nslp');
 
-		$target = '?m=nodesearch&search=1';
+		$target = '?m=nodesearch&search';
 	break;
 	
 	case 'ticket':
 		if(isset($_GET['ajax'])) // support for AutoSuggest
 		{
-			$candidates = $DB->GetAll('SELECT rttickets.id, rttickets.subject, rttickets.requestor, customers.name, customers.lastname FROM rttickets LEFT JOIN customers on rttickets.customerid=customers.id WHERE rttickets.id ?LIKE? \''.$search.'%\' OR lower(rttickets.subject) ?LIKE? lower(\'%'.$search.'%\') OR lower(rttickets.requestor) ?LIKE? lower(\'%'.$search.'%\') OR lower(customers.name) ?LIKE? lower(\''.$search.'%\') OR lower(customers.lastname) ?LIKE? lower(\''.$search.'%\') ORDER BY rttickets.subject, rttickets.id, customers.lastname, customers.name, rttickets.requestor LIMIT 15');
+			$candidates = $DB->GetAll('SELECT t.id, t.subject, t.requestor, c.name, c.lastname 
+				FROM rttickets t
+				LEFT JOIN customersview c on (t.customerid = c.id)
+				WHERE  '.(ereg('^[0-9]+$',$search) ? 't.id = '.intval($search).' OR ' : '').' 
+					lower(t.subject) ?LIKE? lower(\'%'.$search.'%\') 
+					OR lower(t.requestor) ?LIKE? lower(\'%'.$search.'%\') 
+					OR lower(c.name) ?LIKE? lower(\''.$search.'%\') 
+					OR lower(c.lastname) ?LIKE? lower(\''.$search.'%\')
+					ORDER BY t.subject, t.id, c.lastname, c.name, t.requestor
+					LIMIT 15');
+		
 			$eglible=array(); $actions=array(); $descriptions=array();
 			if ($candidates)
 			foreach($candidates as $idx => $row) {
 				$actions[$row['id']] = '?m=rtticketview&id='.$row['id'];
 				$eglible[$row['id']] = escape_js($row['subject']);
-				if (preg_match("~$search~i",$row['id'])) 	{ $descriptions[$row['id']] = trans('Id').': '.$row['id']; continue; }
+				if (preg_match("~^$search\$~i",$row['id'])) 	{ $descriptions[$row['id']] = trans('Id').': '.$row['id']; continue; }
 				if (preg_match("~$search~i",$row['subject'])) 	{ $descriptions[$row['id']] = escape_js(trans('Subject:').' '.$row['subject']); continue; }
 				if (preg_match("~$search~i",$row['requestor'])) { $descriptions[$row['id']] = escape_js(trans('First/last name').': '.preg_replace('/ <.*/','',$row['requestor'])); continue; }
 				if (preg_match("~^$search~i",$row['name'])) 	{ $descriptions[$row['id']] = escape_js(trans('First/last name').': '.$row['name']); continue; }
@@ -227,12 +239,65 @@ switch($mode)
 			$target = '?m=rtticketview&id='.intval($search);
 		else
 		{
-			$SESSION->save('rtsearch', array('name' => $search));
-			$target = '?m=rtsearch&search=1';
+			$SESSION->save('rtsearch', array('name' => $search, 
+					'subject' => $search,
+					'operator' => 'OR'));
+			
+			$target = '?m=rtsearch&s=1';
 		}
 	break;
+
+	case 'account':
+		$ac = explode('@', $search);
+
+		if(isset($_GET['ajax'])) // support for AutoSuggest
+		{
+			$candidates = $DB->GetAll('(SELECT p.id, p.login, d.name AS domain, 0 AS type 
+					FROM passwd p
+					JOIN domains d ON (p.domainid = d.id)
+					WHERE p.login ?LIKE? LOWER(\'%'.$ac[0].'%\')
+					'.(!empty($ac[1]) ? 'AND d.name ?LIKE? LOWER(\''.$ac[1].'%\')' : '').')
+					UNION 
+					(SELECT a.id, a.login, d.name AS domain, 1 AS type 
+					FROM aliases a
+					JOIN domains d ON (a.domainid = d.id)
+					WHERE a.login ?LIKE? LOWER(\'%'.$ac[0].'%\')
+					'.(!empty($ac[1]) ? 'AND d.name ?LIKE? LOWER(\''.$ac[1].'%\')' : '').')
+					ORDER BY login, domain
+					LIMIT 15');
+		
+			$eglible=array(); $actions=array(); $descriptions=array();
+			
+			if ($candidates) foreach($candidates as $idx => $row)
+			{
+				if($row['type'])
+					$actions[$row['id']] = '?m=aliasinfo&id='.$row['id'];
+				else
+					$actions[$row['id']] = '?m=accountinfo&id='.$row['id'];				
+			
+				$eglible[$row['id']] = escape_js($row['login'].'@'.$row['domain']);
+				$descriptions[$row['id']] = '';
+			}
+			header('Content-type: text/plain');
+			if ($eglible) {
+				print preg_replace('/$/',"\");\n","this.eligible = new Array(\"".implode('","',$eglible));
+				print preg_replace('/$/',"\");\n","this.descriptions = new Array(\"".implode('","',$descriptions));
+				print preg_replace('/$/',"\");\n","this.actions = new Array(\"".implode('","',$actions));
+			} else {
+				print "false;\n";
+			}
+			exit;
+		}
+		
+		$search = array();
+		$search['login'] = $ac[0];
+		if(!empty($ac[1])) $search['domain'] = $ac[1];
+
+		$SESSION->save('accountsearch', $search);
+		$target = '?m=accountsearch&s=1';
+	break;
 }
 
-$SESSION->redirect($target ? $target : '?m=welcome');
+$SESSION->redirect(!empty($target) ? $target : '?'.$SESSION->get('backto'));
 
 ?>
