@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: receipt.php,v 1.16.2.1 2007/08/17 13:15:27 alec Exp $
+ *  $Id: receipt.php,v 1.22 2009/01/29 16:39:20 alec Exp $
  */
 
 function GetReceipt($id)
@@ -67,7 +67,7 @@ if(strtolower($CONFIG['receipts']['type']) == 'pdf')
 }
 
 header('Content-Type: '.$CONFIG['receipts']['content_type']);
-if(isset($CONFIG['receipts']['attachment_name']) &&  $CONFIG['receipts']['attachment_name'] != '')
+if(!empty($CONFIG['receipts']['attachment_name']))
 	header('Content-Disposition: attachment; filename='.$CONFIG['receipts']['attachment_name']);
 
 if(isset($_GET['print']) && $_GET['print'] == 'cached' && sizeof($_POST['marks']))
@@ -88,7 +88,7 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached' && sizeof($_POST['marks']
 		die;
 	}
 								
-	if($_GET['cash'])
+	if(!empty($_GET['cash']))
 	{
 		foreach($ids as $cashid)
 			if($rid = $DB->GetOne('SELECT docid FROM cash, documents WHERE docid = documents.id AND documents.type = 2 AND cash.id = ?', array($cashid)))
@@ -99,8 +99,8 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached' && sizeof($_POST['marks']
 	sort($ids);
 
 	$layout['pagetitle'] = trans('Cash Receipts');
-	$SMARTY->display('clearheader.html');
-	$SMARTY->assign('type', $_GET['which']);
+	$SMARTY->display('receiptheader.html');
+	$SMARTY->assign('type', !empty($_GET['which']) ? $_GET['which'] : '');
 	
 	$i = 0;
 	$count = sizeof($ids);
@@ -110,6 +110,7 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached' && sizeof($_POST['marks']
 		{
 			$i++;
 		        if($i == $count) $receipt['last'] = TRUE;
+			$receipt['first'] = $i > 1 ? FALSE : TRUE;
 
 			$SMARTY->assign('receipt',$receipt);
 			$SMARTY->display($CONFIG['receipts']['template_file']);
@@ -130,9 +131,10 @@ elseif($receipt = GetReceipt($_GET['id']))
 	$layout['pagetitle'] = trans('Cash Receipt No. $0', $receipt['number']);
 	
 	$receipt['last'] = TRUE;
+	$receipt['first'] = TRUE;
 	$SMARTY->assign('type', isset($_GET['which']) ? $_GET['which'] : NULL);
 	$SMARTY->assign('receipt',$receipt);
-	$SMARTY->display('clearheader.html');
+	$SMARTY->display('receiptheader.html');
 	$SMARTY->display($CONFIG['receipts']['template_file']);
 	$SMARTY->display('clearfooter.html');
 }
