@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: receipt_pdf.php,v 1.8.2.1 2007/08/17 13:15:27 alec Exp $
+ *  $Id: receipt_pdf.php,v 1.12 2009/01/29 16:39:20 alec Exp $
  */
 
 function receipt_header($x,$y)
@@ -145,7 +145,7 @@ function receipt_footer($x,$y)
     $pdf->line($xmax, $yy, $xmax, $y);
     $pdf->line($x, $y, $xmax, $y);
     
-    $y -= text_align_right($xmax,$y-6,$font_size/2,iconv("UTF-8","ISO-8859-2",'Copyright (C) 2001-2007 LMS Developers'));
+    $y -= text_align_right($xmax,$y-6,$font_size/2,iconv("UTF-8","ISO-8859-2",'Copyright (C) 2001-2009 LMS Developers'));
     $y -= 15;
     $pdf->setLineStyle(0.5, NULL, NULL, array(2,2));
     $pdf->line($x-10, $y, $xmax+10, $y);
@@ -265,7 +265,7 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached' && sizeof($_POST['marks']
 	        die;
 	}
 	
-	if($_GET['cash'])
+	if(!empty($_GET['cash']))
 	{
 	        foreach($ids as $cashid)
 	                if($rid = $DB->GetOne('SELECT docid FROM cash, documents WHERE docid = documents.id AND documents.type = 2 AND cash.id = ?', array($cashid)))
@@ -284,6 +284,7 @@ if(isset($_GET['print']) && $_GET['print'] == 'cached' && sizeof($_POST['marks']
 			$type = $_GET['which'];
 		        $i++;
 		        if($i == $count) $receipt['last'] = TRUE;
+			$receipt['first'] = $i > 1 ? FALSE : TRUE;
 			receipt_body();
 		}
 	}
@@ -292,6 +293,7 @@ elseif($receipt = GetReceipt($_GET['id']))
 {
 	$type = isset($_GET['which']) ? $_GET['which'] : '';
 	$receipt['last'] = TRUE;
+	$receipt['first'] = TRUE;
 	receipt_body();
 }
 else
