@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: receiptadd.php,v 1.49.2.2 2007/11/14 07:57:53 alec Exp $
+ *  $Id: receiptadd.php,v 1.62 2009/02/11 09:47:18 alec Exp $
  */
 
 function GetCustomerCovenants($id)
@@ -38,7 +38,7 @@ function GetCustomerCovenants($id)
 			WHERE cash.customerid = ? AND d.type IN (?,?) AND d.closed = 0
 			GROUP BY docid, cdate, number, template, reference
 			HAVING SUM(value) < 0
-			ORDER BY cdate DESC LIMIT 10', 'id', array($id, DOC_INVOICE, DOC_CNOTE)))
+			ORDER BY cdate DESC', 'id', array($id, DOC_INVOICE, DOC_CNOTE)))
 	{
 		foreach($invoicelist as $idx => $row)
 		{
@@ -92,7 +92,7 @@ function GetCustomerNotes($id)
 			WHERE cash.customerid = ? AND documents.type = ? AND documents.closed = 0
 			GROUP BY docid, cdate, number, template
 			HAVING SUM(value) > 0
-			ORDER BY cdate DESC LIMIT 10', array($id, DOC_CNOTE)))
+			ORDER BY cdate DESC', array($id, DOC_CNOTE)))
 	{
 		foreach($invoicelist as $idx => $row)
 		{
@@ -103,6 +103,21 @@ function GetCustomerNotes($id)
 	}
 }
 
+// receipt positions adding with double click protection
+function additem(&$content, $item)
+{
+	for($i=0, $x=sizeof($content); $i<$x; $i++)
+		if($content[$i]['value'] == $item['value']
+			&& $content[$i]['description'] == $item['description']
+			&& $content[$i]['posuid'] + 1 > $item['posuid'])
+		{
+			break;
+		}
+
+	if($i == $x)
+		$content[] = $item;
+}
+
 $SESSION->restore('receiptcontents', $contents);
 $SESSION->restore('receiptcustomer', $customer);
 $SESSION->restore('receipt', $receipt);
@@ -157,7 +172,7 @@ switch($action)
 
 		if(!isset($error) && $receipt['customerid'] && $LMS->CustomerExists($receipt['customerid']))
 		{
-			$customer = $LMS->GetCustomer($receipt['customerid']);
+			$customer = $LMS->GetCustomer($receipt['customerid'], true);
 			$customer['groups'] = $LMS->CustomergroupGetForCustomer($receipt['customerid']);
 			if(!isset($CONFIG['receipts']['show_notes']) || !chkconfig($CONFIG['receipts']['show_notes']))
 				unset($customer['notes']);
@@ -166,11 +181,42 @@ switch($action)
 			if(isset($CONFIG['receipts']['show_documents_warning']) && chkconfig($CONFIG['receipts']['show_documents_warning']))
 				if($DB->GetOne('SELECT COUNT(*) FROM documents WHERE customerid = ? AND closed = 0 AND type < 0', array($receipt['customerid'])))
 				{
-					if($CONFIG['receipts']['documents_warning'])
+					if(!empty($CONFIG['receipts']['documents_warning']))
 						$customer['docwarning'] = $CONFIG['receipts']['documents_warning'];
 					else
 						$customer['docwarning'] = trans('Customer has got unconfirmed documents!');
 				}
+
+			// jesli klient posiada zablokowane komputery poinformujmy
+			// o tym kasjera, moze po wplacie trzeba bedzie zmienic ich status
+			if(isset($CONFIG['receipts']['show_nodes_warning']) && chkconfig($CONFIG['receipts']['show_nodes_warning']))
+				if($DB->GetOne('SELECT COUNT(*) FROM nodes WHERE ownerid = ? AND access = 0', array($receipt['customerid'])))
+				{
+					if(!empty($CONFIG['receipts']['nodes_warning']))
+						$customer['nodeswarning'] = $CONFIG['receipts']['nodes_warning'];
+					else
+						$customer['nodeswarning'] = trans('Customer has got disconnected nodes!');
+				}
+
+			// jesli klient posiada komputery przypisane do wybranych grup..., u mnie
+			// komputery zadluzonych dodawane sa do grupy "zadluzenie"
+			if(!empty($CONFIG['receipts']['show_nodegroups_warning']))
+			{
+				$list = preg_split("/\s+/", $CONFIG['receipts']['show_nodegroups_warning']);
+				if($DB->GetOne('SELECT COUNT(*) FROM nodes n
+						JOIN nodegroupassignments a ON (n.id = a.nodeid)
+						JOIN nodegroups g ON (g.id = a.nodegroupid)
+						WHERE n.ownerid = ? AND UPPER(g.name) IN (UPPER(\''
+						.implode("'),UPPER('", $list).'\'))', 
+						array($receipt['customerid'])))
+				{
+					if(!empty($CONFIG['receipts']['nodegroups_warning']))
+						$customer['nodegroupswarning'] = $CONFIG['receipts']['nodegroups_warning'];
+					else
+						$customer['nodegroupswarning'] = trans('Customer has got nodes in groups: <b>$0</b>!', 
+							$CONFIG['receipts']['show_nodegroups_warning']);
+				}
+			}
 		}
 	break;
 
@@ -235,7 +281,7 @@ switch($action)
 		}
 	
 		if(!$error && $itemdata['value'] && $itemdata['description'])
-			$contents[] = $itemdata;
+			additem($contents, $itemdata);
 	break;
 	
 	case 'additemlist':
@@ -305,7 +351,8 @@ switch($action)
 					}
 				}
 
-				$contents[] = $itemdata;
+				if(!$error)
+					additem($contents, $itemdata);
 			}
 		}
 	break;
@@ -340,7 +387,7 @@ switch($action)
 				$receipt['numberplanid'] = $DB->GetOne('SELECT out_numberplanid FROM cashregs WHERE id=?', array($receipt['regid']));
 		}
 
-		if($receipt['cdate'])
+		if(isset($receipt['cdate']) && $receipt['cdate'])
 		{
 			list($year, $month, $day) = split('/',$receipt['cdate']);
 			if(checkdate($month, $day, $year)) 
@@ -369,7 +416,7 @@ switch($action)
 			}
 		}
 
-		if($receipt['number'])
+		if(isset($receipt['number']) && $receipt['number'])
 		{
 			if(!eregi('^[0-9]+$', $receipt['number']))
 				$error['number'] = trans('Receipt number must be integer!');
@@ -383,13 +430,15 @@ switch($action)
 
 		$rights = $DB->GetOne('SELECT rights FROM cashrights WHERE regid=? AND userid=?', array($receipt['regid'], $AUTH->id));
 		
-		switch($receipt['o_type'])
+		if(isset($receipt['o_type'])) switch($receipt['o_type'])
 		{
 			case 'customer': if(($rights & 2)!=2) $rightserror = true; break; 
 			case 'move': if(($rights & 4)!=4) $rightserror = true; break; 
 			case 'advance': if(($rights & 8)!=8) $rightserror = true; break; 
 			case 'other': if(($rights & 16)!=16) $rightserror = true; break;
-		}	
+		}
+		else
+			$receipt['o_type'] = 'customer';
 
 		if(!$receipt['regid'])
 			$error['regid'] = trans('Registry not selected!');
@@ -436,7 +485,7 @@ switch($action)
 
 				if(!isset($error))
 				{
-					$customer = $LMS->GetCustomer($cid);
+					$customer = $LMS->GetCustomer($cid, true);
 					$customer['groups'] = $LMS->CustomergroupGetForCustomer($cid);
 					if(!isset($CONFIG['receipts']['show_notes']) || !chkconfig($CONFIG['receipts']['show_notes']))
 						unset($customer['notes']);
@@ -445,12 +494,43 @@ switch($action)
 					if(isset($CONFIG['receipts']['show_documents_warning']) && chkconfig($CONFIG['receipts']['show_documents_warning']))
 						if($DB->GetOne('SELECT COUNT(*) FROM documents WHERE customerid = ? AND closed = 0 AND type < 0', array($cid)))
 						{
-							if($CONFIG['receipts']['documents_warning'])
+							if(!empty($CONFIG['receipts']['documents_warning']))
 								$customer['docwarning'] = $CONFIG['receipts']['documents_warning'];
 							else
 								$customer['docwarning'] = trans('Customer has got unconfirmed documents!');
 						}
 					
+					// jesli klient posiada zablokowane komputery poinformujmy
+	    				// o tym kasjera, moze po wplacie trzeba bedzie zmienic ich status
+					if(isset($CONFIG['receipts']['show_nodes_warning']) && chkconfig($CONFIG['receipts']['show_nodes_warning']))
+						if($DB->GetOne('SELECT COUNT(*) FROM nodes WHERE ownerid = ? AND access = 0', array($cid)))
+						{
+							if(!empty($CONFIG['receipts']['nodes_warning']))
+								$customer['nodeswarning'] = $CONFIG['receipts']['nodes_warning'];
+							else
+								$customer['nodeswarning'] = trans('Customer has got disconnected nodes!');
+						}
+
+					// jesli klient posiada komputery przypisane do wybranych grup, u mnie
+					// komputery zadluzonych dodawane sa do grupy "zadluzenie"
+	    				if(!empty($CONFIG['receipts']['show_nodegroups_warning']))
+					{
+						$list = preg_split("/\s+/", $CONFIG['receipts']['show_nodegroups_warning']);
+		
+						if($DB->GetOne('SELECT COUNT(*) FROM nodes n
+			    				JOIN nodegroupassignments a ON (n.id = a.nodeid)
+				    			JOIN nodegroups g ON (g.id = a.nodegroupid)
+					    		WHERE n.ownerid = ? AND UPPER(g.name) IN (UPPER(\''
+						    	.implode("'),UPPER('", $list).'\'))', 
+	    						array($cid)))
+						{
+							if(!empty($CONFIG['receipts']['nodegroups_warning']))
+								$customer['nodegroupswarning'] = $CONFIG['receipts']['nodegroups_warning'];
+							else
+								$customer['nodegroupswarning'] = trans('Customer has got nodes in group(s): <b>$0</b>!', $CONFIG['receipts']['show_nodegroups_warning']);
+						}
+					}
+
 					// remove positions if customer was changed
 					if($oldcid != $customer['id'])
 						unset($contents);
@@ -466,8 +546,8 @@ switch($action)
 		if($contents && $customer)
 		{
 			$DB->BeginTrans();
-			$DB->LockTables('documents');
-		
+			$DB->LockTables(array('documents', 'numberplans'));
+
 			if(!$receipt['number'])
 				$receipt['number'] = $LMS->GetNewDocumentNumber(DOC_RECEIPT, $receipt['numberplanid'], $receipt['cdate']);
 			else
@@ -495,10 +575,9 @@ switch($action)
 						$customer['zip'],
 						$customer['city']
 						));
+			$DB->UnLockTables();		
 						
-			$rid = $DB->GetOne('SELECT id FROM documents 
-						WHERE type=? AND number=? AND cdate=?', 
-						array(DOC_RECEIPT, $receipt['number'], $receipt['cdate'])); 
+			$rid = $DB->GetLastInsertId('documents');
 			
 			$iid = 0;
 			foreach($contents as $item)
@@ -537,7 +616,6 @@ switch($action)
 						$DB->Execute('UPDATE documents SET closed=1 WHERE id=?', array($ref));
 			}
 
-			$DB->UnLockTables();		
 			$DB->CommitTrans();
 			
 			$print = TRUE;
@@ -545,6 +623,7 @@ switch($action)
 		elseif($contents && ($receipt['o_type'] == 'other' || $receipt['o_type'] == 'advance'))
 		{
 			$DB->BeginTrans();
+			$DB->LockTables(array('documents', 'numberplans'));
 
 			if(!$receipt['number'])
 				$receipt['number'] = $LMS->GetNewDocumentNumber(DOC_RECEIPT, $receipt['numberplanid'], $receipt['cdate']);
@@ -570,8 +649,9 @@ switch($action)
 						$receipt['o_type'] == 'advance' ? $receipt['adv_name'] : $receipt['other_name'],
 						$receipt['o_type'] == 'advance' ? 0 : 1
 						));
+			$DB->UnLockTables();		
 						
-			$rid = $DB->GetOne('SELECT id FROM documents WHERE type=? AND number=? AND cdate=?', array(DOC_RECEIPT, $receipt['number'], $receipt['cdate'])); 
+			$rid = $DB->GetLastInsertId('documents');
 			
 			$iid = 0;
 			foreach($contents as $item)
@@ -616,9 +696,10 @@ switch($action)
 			$SESSION->remove('receiptadderror');
 
 			if(isset($_GET['print']))
-				$SESSION->redirect('?m=receiptlist&receipt='.$rid.(isset($_GET['which']) ? '&which='.$_GET['which'] : '').'&regid='.$receipt['regid'].'#'.$rid);
-			else
-				$SESSION->redirect('?m=receiptlist&regid='.$receipt['regid'].'#'.$rid);
+				$SESSION->save('receiptprint', array('receipt' => $rid,
+					'which' => (isset($_GET['which']) ? $_GET['which'] : '')));
+
+			$SESSION->redirect('?m=receiptlist&regid='.$receipt['regid'].'#'.$rid);
 		}
 	break;
 
@@ -711,9 +792,10 @@ switch($action)
 			$SESSION->remove('receiptadderror');
 			
 			if(isset($_GET['print']))
-				$SESSION->redirect('?m=receiptlist&receipt='.$rid.(isset($_GET['which']) ? '&which='.$_GET['which'] : '').'&regid='.$receipt['regid'].'#'.$rid);
-			else
-				$SESSION->redirect('?m=receiptlist&regid='.$receipt['regid'].'#'.$rid);
+				$SESSION->save('receiptprint', array('receipt' => $rid,
+					'which' => (isset($_GET['which']) ? $_GET['which'] : '')));
+
+			$SESSION->redirect('?m=receiptlist&regid='.$receipt['regid'].'#'.$rid);
 		}
 	break;
 
@@ -749,21 +831,20 @@ switch($receipt['type'])
 $invoicelist = array();
 
 if(isset($list))
+{
 	if($contents)
 		foreach($list as $idx => $row)
 		{
-			$i = 0;
-			foreach($contents as $item)
-				if($row['id'] == $item['docid'])
-				{
-					$i = 1;
+			for($i=0, $x=sizeof($contents); $i<$x; $i++)
+				if(isset($contents[$i]['docid']) && $row['id'] == $contents[$i]['docid'])
 					break;
-				}
-			if(!$i)
+			if($i == $x)
 				$invoicelist[$idx] = $row;
 		}
 	else
 		$invoicelist = $list;
+	$invoicelist = array_slice($invoicelist, 0, 10);
+}
 
 if(!isset($CONFIG['phpui']['big_networks']) || !chkconfig($CONFIG['phpui']['big_networks']))
 {
