@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: receiptedit.php,v 1.27.2.2 2007/11/14 07:57:53 alec Exp $
+ *  $Id: receiptedit.php,v 1.38 2009/02/11 09:47:18 alec Exp $
  */
 
 if(isset($_GET['id']))
@@ -75,20 +75,50 @@ if(isset($_GET['id']))
 	
 	if($receipt['customerid'])
 	{
-		$customer = $LMS->GetCustomer($receipt['customerid']);
+		$customer = $LMS->GetCustomer($receipt['customerid'], true);
     		$customer['groups'] = $LMS->CustomergroupGetForCustomer($receipt['customerid']);
-		if(!chkconfig($CONFIG['receipts']['show_notes']))
-                        unset($customer['notes']);		
+		if(empty($CONFIG['receipts']['show_notes']) || !chkconfig($CONFIG['receipts']['show_notes']))
+                        unset($customer['notes']);
 
 		// niezatwierdzone dokumenty klienta
-		if(chkconfig($CONFIG['receipts']['show_documents_warning']))
+		if(isset($CONFIG['receipts']['show_documents_warning']) && chkconfig($CONFIG['receipts']['show_documents_warning']))
 			if($DB->GetOne('SELECT COUNT(*) FROM documents WHERE customerid = ? AND closed = 0 AND type < 0', array($receipt['customerid'])))
 			{
-				if($CONFIG['receipts']['documents_warning'])
+				if(!empty($CONFIG['receipts']['documents_warning']))
 					$customer['docwarning'] = $CONFIG['receipts']['documents_warning'];
 				else
 					$customer['docwarning'] = trans('Customer has got unconfirmed documents!');
 			}
+		
+		// jesli klient posiada zablokowane komputery poinformujmy
+		// o tym kasjera, moze po wplacie trzeba bedzie zmienic ich status
+		if(isset($CONFIG['receipts']['show_nodes_warning']) && chkconfig($CONFIG['receipts']['show_nodes_warning']))
+		        if($DB->GetOne('SELECT COUNT(*) FROM nodes WHERE ownerid = ? AND access = 0', array($receipt['customerid'])))
+			{
+			        if(!empty($CONFIG['receipts']['nodes_warning']))
+			        	$customer['nodeswarning'] = $CONFIG['receipts']['nodes_warning'];
+				else
+					$customer['nodeswarning'] = trans('Customer has got disconnected nodes!');
+			}
+		// jesli klient posiada komputery przypisane do wybranych grup..., u mnie
+    		// komputery zadluzonych dodawane sa do grupy "zadluzenie"
+		if(!empty($CONFIG['receipts']['show_nodegroups_warning']))
+		{
+		        $list = preg_split("/\s+/", $CONFIG['receipts']['show_nodegroups_warning']);
+		        if($DB->GetOne('SELECT COUNT(*) FROM nodes n
+			                JOIN nodegroupassignments a ON (n.id = a.nodeid)
+					JOIN nodegroups g ON (g.id = a.nodegroupid)
+					WHERE n.ownerid = ? AND UPPER(g.name) IN (UPPER(\''
+					.implode("'),UPPER('", $list).'\'))',
+					array($receipt['customerid'])))
+			{
+			        if(!empty($CONFIG['receipts']['nodegroups_warning']))
+			                $customer['nodegroupswarning'] = $CONFIG['receipts']['nodegroups_warning'];
+			        else
+			        	$customer['nodegroupswarning'] = trans('Customer has got nodes in groups: <b>$0</b>!',
+			                            $CONFIG['receipts']['show_nodegroups_warning']);
+			}
+		}
 	}
 	    
 	if($receipt['numberplanid'] && !$receipt['extnumber'])
@@ -103,12 +133,29 @@ if(isset($_GET['id']))
 	$SESSION->save('receiptediterror', $error);
 }
 
+// receipt positions adding with double click protection
+function additem(&$content, $item)
+{
+        for($i=0, $x=sizeof($content); $i<$x; $i++)
+	        if($content[$i]['value'] == $item['value']
+			&& $content[$i]['description'] == $item['description']
+			&& $content[$i]['posuid'] > $item['posuid'] - 1)
+		{
+			break;
+		}
+	
+	if($i == $x)
+	        $content[] = $item;
+}
+
 $SESSION->restore('receiptcontents', $contents);
 $SESSION->restore('receiptcustomer', $customer);
 $SESSION->restore('receipt', $receipt);
 $SESSION->restore('receiptediterror', $error);
 
-$receipt['titlenumber'] = docnumber($receipt['number'], $receipt['template'], $receipt['cdate'], $receipt['extnumber']);
+$receipt['titlenumber'] = docnumber($receipt['number'], $receipt['template'], $receipt['cdate'], 
+			    isset($receipt['extnumber']) ? $receipt['extnumber'] : '');
+
 if($receipt['type']=='in')
 	$layout['pagetitle'] = trans('Cash-in Receipt Edit: $0', $receipt['titlenumber']);
 else
@@ -127,7 +174,7 @@ switch($action)
 		$itemdata['posuid'] = (string) getmicrotime();
 	
 		if($itemdata['value'] && $itemdata['description'])
-			$contents[] = $itemdata;
+			additem($contents, $itemdata);
 	break;
 	case 'deletepos':
 
@@ -148,7 +195,7 @@ switch($action)
 		
 		unset($receipt);
 		unset($customer);
-		unset($error);
+		$error = NULL;
 		
 		if($receipt = $_POST['receipt'])
 			foreach($receipt as $key => $val)
@@ -167,9 +214,6 @@ switch($action)
 				$receipt['numberplanid'] = $DB->GetOne('SELECT out_numberplanid FROM cashregs WHERE id=?', array($receipt['regid']));
 			
 			$receipt['number'] = 0;
-			
-//			if($DB->GetOne('SELECT rights FROM cashrights WHERE regid=? AND userid=?', array($receipt['regid'], $AUTH->id))<2)
-//			        $error['regid'] = trans('You don\'t have permission to add receipt in selected cash registry!');
 		}
 		
 		if($receipt['cdate'])
@@ -201,7 +245,7 @@ switch($action)
 				}
 			}
 		}
-		else // przywracamy pierwotn godzin utworzenia dokumentu
+		else // przywracamy pierwotna godzine utworzenia dokumentu
 			$receipt['cdate'] = $oldcdate;
 			
 		if(!$receipt['number'])
@@ -243,29 +287,61 @@ switch($action)
 			break;
 		}
 		
-		$cid = $_GET['customerid'] != '' ? $_GET['customerid'] : $_POST['customerid'];
+		$cid = !empty($_GET['customerid']) ? $_GET['customerid'] : $_POST['customerid'];
 		
 		if(!$cid)
 			$cid = $oldcid;
 		
-		if(!$error)
+		if(!isset($error))
 			if($LMS->CustomerExists(($cid)))
 			{
-				$customer = $LMS->GetCustomer(($_GET['customerid'] != '' ? $_GET['customerid'] : $_POST['customerid']));
+				$customer = $LMS->GetCustomer($cid, true);
 	                        $customer['groups'] = $LMS->CustomergroupGetForCustomer($customer['id']);
-		        	if(!chkconfig($CONFIG['receipts']['show_notes']))
+		        	
+				if(empty($CONFIG['receipts']['show_notes']) || !chkconfig($CONFIG['receipts']['show_notes']))
 				        unset($customer['notes']);
 				
 				// niezatwierdzone dokumenty klienta
-				if(chkconfig($CONFIG['receipts']['show_documents_warning']))
+				if(isset($CONFIG['receipts']['show_nodes_warning']) && chkconfig($CONFIG['receipts']['show_documents_warning']))
 					if($DB->GetOne('SELECT COUNT(*) FROM documents WHERE customerid = ? AND closed = 0 AND type < 0', array($customer['id'])))
 					{
-						if($CONFIG['receipts']['documents_warning'])
+						if(!empty($CONFIG['receipts']['documents_warning']))
 							$customer['docwarning'] = $CONFIG['receipts']['documents_warning'];
 						else
 							$customer['docwarning'] = trans('Customer has got unconfirmed documents!');
 					}
+				
+				// jesli klient posiada zablokowane komputery poinformujmy
+				// o tym kasjera, moze po wplacie trzeba bedzie zmienic ich status
+				if(isset($CONFIG['receipts']['show_nodes_warning']) && chkconfig($CONFIG['receipts']['show_nodes_warning']))
+				        if($DB->GetOne('SELECT COUNT(*) FROM nodes WHERE ownerid = ? AND access = 0', array($customer['id'])))
+					{
+					        if(!empty($CONFIG['receipts']['nodes_warning']))
+					        	$customer['nodeswarning'] = $CONFIG['receipts']['nodes_warning'];
+						else
+							$customer['nodeswarning'] = trans('Customer has got disconnected nodes!');
+					}
 
+				// jesli klient posiada komputery przypisane do wybranych grup..., u mnie
+                    		// komputery zadluzonych dodawane sa do grupy "zadluzenie"
+			        if(!empty($CONFIG['receipts']['show_nodegroups_warning']))
+				{
+				        $list = preg_split("/\s+/", $CONFIG['receipts']['show_nodegroups_warning']);
+				        if($DB->GetOne('SELECT COUNT(*) FROM nodes n
+				                JOIN nodegroupassignments a ON (n.id = a.nodeid)
+						JOIN nodegroups g ON (g.id = a.nodegroupid)
+						WHERE n.ownerid = ? AND UPPER(g.name) IN (UPPER(\''
+						.implode("'),UPPER('", $list).'\'))',
+						array($customer['id'])))
+					{
+					        if(!empty($CONFIG['receipts']['nodegroups_warning']))
+					                $customer['nodegroupswarning'] = $CONFIG['receipts']['nodegroups_warning'];
+					        else
+					        	$customer['nodegroupswarning'] = trans('Customer has got nodes in groups: <b>$0</b>!',
+					                            $CONFIG['receipts']['show_nodegroups_warning']);
+					}
+				}
+				
 				$receipt['selected'] = TRUE;
 			}
 
@@ -279,8 +355,6 @@ switch($action)
 
 			// delete old receipt 
 			$DB->Execute('DELETE FROM documents WHERE id = ?', array($receipt['id']));
-			$DB->Execute('DELETE FROM receiptcontents WHERE docid = ?', array($receipt['id']));
-			$DB->Execute('DELETE FROM cash WHERE docid = ?', array($receipt['id']));
 		
 			// re-add receipt 
 			$DB->Execute('INSERT INTO documents (type, number, extnumber, numberplanid, cdate, customerid, userid, name, address, zip, city, closed)
@@ -298,8 +372,13 @@ switch($action)
 						$customer['city'],
 						$receipt['closed']
 						));
+			$DB->UnLockTables();
 						
-			$rid = $DB->GetOne('SELECT id FROM documents WHERE type=? AND number=? AND cdate=?', array(DOC_RECEIPT, $receipt['number'], $receipt['cdate'])); 
+			$rid = $DB->GetLastInsertId('documents');
+
+			// delete old receipt content and assignments
+			$DB->Execute('DELETE FROM receiptcontents WHERE docid = ?', array($receipt['id']));
+			$DB->Execute('DELETE FROM cash WHERE docid = ?', array($receipt['id']));
 			
 			$iid = 0;
 			foreach($contents as $item)
@@ -331,8 +410,7 @@ switch($action)
 							$customer['id']
 						));
 			}
-			
-			$DB->UnLockTables();
+
 			$DB->CommitTrans();
 		}
 		elseif($contents && ($receipt['o_type'] == 'other' || $receipt['o_type'] == 'advance'))
@@ -342,8 +420,6 @@ switch($action)
 			
 			// delete old receipt 
 			$DB->Execute('DELETE FROM documents WHERE id = ?', array($receipt['id']));
-			$DB->Execute('DELETE FROM receiptcontents WHERE docid = ?', array($receipt['id']));
-			$DB->Execute('DELETE FROM cash WHERE docid = ?', array($receipt['id']));
 			
 			$DB->Execute('INSERT INTO documents (type, number, extnumber, numberplanid, cdate, userid, name, closed)
 			    		VALUES(?, ?, ?, ?, ?, ?, ?, ?)',
@@ -356,8 +432,13 @@ switch($action)
 						$receipt['o_type'] == 'advance' ? $receipt['adv_name'] : $receipt['other_name'],
 						$receipt['closed']
 					));
+			$DB->UnLockTables();
 						
-			$rid = $DB->GetOne('SELECT id FROM documents WHERE type=? AND number=? AND cdate=?', array(DOC_RECEIPT, $receipt['number'], $receipt['cdate'])); 
+			$rid = $DB->GetLastInsertId('documents');
+
+			// delete old receipt content and assignments
+			$DB->Execute('DELETE FROM receiptcontents WHERE docid = ?', array($receipt['id']));
+			$DB->Execute('DELETE FROM cash WHERE docid = ?', array($receipt['id']));
 			
 			$iid = 0;
 			foreach($contents as $item)
@@ -389,7 +470,6 @@ switch($action)
 					));
 			}
 
-			$DB->UnLockTables();
 			$DB->CommitTrans();
 		}
 		else
@@ -401,9 +481,10 @@ switch($action)
 		$SESSION->remove('receiptediterror');
 		
 		if(isset($_GET['print']))
-			$SESSION->redirect('?m=receiptlist&receipt='.$rid.'&which='.$_GET['which'].'&regid='.$receipt['regid'].'#'.$rid);
-		else
-			$SESSION->redirect('?m=receiptlist&regid='.$receipt['regid'].'#'.$rid);
+			$SESSION->save('receiptprint', array('receipt' => $rid,
+		                'which' => (isset($_GET['which']) ? $_GET['which'] : '')));
+
+		$SESSION->redirect('?m=receiptlist&regid='.$receipt['regid'].'#'.$rid);
 	break;
 }
 
