@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.11-cvs
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: reload.php,v 1.44.2.3 2007/09/28 11:25:59 alec Exp $
+ *  $Id: reload.php,v 1.51 2009/01/13 07:45:53 alec Exp $
  */
 
 $layout['pagetitle'] = trans('Configuration Reload');
@@ -51,12 +51,18 @@ switch($_RELOAD_TYPE)
 					foreach($execlist as $execcmd)
 					{
 						$execcmd = str_replace('%host', $host['name'], $execcmd);
-						echo '<B>'.$execcmd.'</B>';
-						echo '<PRE>';
+						$execcmd_buffer = popen ("$execcmd", "r");
+						echo '<P><B>'.$execcmd.'</B>:</P>';
 						flush();
-						echo passthru($execcmd);
-						flush();
-						echo '</PRE>';
+
+						while(!feof($execcmd_buffer)) 
+						{
+							$output = fread($execcmd_buffer, 1);
+							echo nl2br($output);
+							flush();
+							ob_flush();
+						}
+					    pclose($execcmd_buffer);
 					}
 					echo '</TD></TR></TABLE>';
 					
