@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketedit.php,v 1.31.2.1 2007/08/17 13:15:27 alec Exp $
+ *  $Id: rtticketedit.php,v 1.35 2009/01/13 07:45:54 alec Exp $
  */
 
 if(($id = $_GET['id']) && !isset($_POST['ticket']))
@@ -168,7 +168,7 @@ if(isset($_POST['ticket']))
 				{
 					if(in_array($email, (array)$oldrecipients)) continue;					
 				
-					if(isset($CONFIG['phpui']['debug_email']) && $CONFIG['phpui']['debug_email'])
+					if(!empty($CONFIG['phpui']['debug_email']))
 						$recip = $CONFIG['phpui']['debug_email'];
 					else
 						$recip = $email;
