@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,12 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffdel.php,v 1.2.2.1 2007/08/17 13:15:27 alec Exp $
+ *  $Id: tariffdel.php,v 1.6 2009/01/13 07:45:54 alec Exp $
  */
 
-if(!$LMS->GetCustomersWithTariff($_GET['id']) && $_GET['is_sure']=="1")
+$id = intval($_GET['id']);
+
+if($id && $_GET['is_sure']=="1" && $LMS->TariffExists($id))
 {
-	$LMS->TariffDelete($_GET['id']);	
+	if(!$DB->GetOne('SELECT COUNT(customerid) FROM assignments WHERE tariffid = ?', array($id)))
+		$LMS->TariffDelete($id);	
 }
 
 $SESSION->redirect('?m=tarifflist');
