@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: transferforms.php,v 1.16.2.2 2007/08/30 09:23:18 alec Exp $
+ *  $Id: transferforms.php,v 1.21 2009/01/13 07:45:55 alec Exp $
  */
 
 
@@ -106,22 +106,22 @@ $pdf->setLineStyle(2);
 
 $id = $pdf->getFirstPageId();
 
-$_NAME = (! $CONFIG['finances']['name'] ? trans('Not set') : $CONFIG['finances']['name']);
-$_SHORT_NAME = (! $CONFIG['finances']['shortname'] ? trans('Not set') : $CONFIG['finances']['shortname']);
-$_ADDRESS = (! $CONFIG['finances']['address'] ? trans('Not set') : $CONFIG['finances']['address']);
-$_ZIP = (! $CONFIG['finances']['zip'] ? trans('Not set') : $CONFIG['finances']['zip']);
-$_CITY = (! $CONFIG['finances']['city'] ? trans('Not set') : $CONFIG['finances']['city']);
-
 $control_lines = 0;
 
 $ids = $DB->GetCol('SELECT id FROM documents d
         WHERE cdate > ? AND cdate < ? AND type = 1'
-        .($_GET['customerid'] ? ' AND customerid = '.$_GET['customerid'] : '')
+	.(!empty($_GET['customerid']) ? ' AND d.customerid = '.intval($_GET['customerid']) : '')
+        .(!empty($_GET['numberplanid']) ? ' AND d.numberplanid = '.intval($_GET['numberplanid']) : '')
+	.(!empty($_GET['groupid']) ?
+	' AND '.(!empty($_GET['groupexclude']) ? 'NOT' : '').'
+	        EXISTS (SELECT 1 FROM customerassignments a
+			WHERE a.customergroupid = '.intval($_GET['groupid']).'
+			AND a.customerid = d.customerid)' : '')
 	.' AND NOT EXISTS (
-                SELECT 1 FROM customerassignments a
+	        SELECT 1 FROM customerassignments a
 		JOIN excludedgroups e ON (a.customergroupid = e.customergroupid)
 		WHERE e.userid = lms_current_user() AND a.customerid = d.customerid)'
-	.' ORDER BY customerid',
+	.' ORDER BY CEIL(cdate/86400), id',
         array($_GET['from'], $_GET['to']));
 
 if(!$ids)
@@ -130,6 +130,8 @@ if(!$ids)
     die;
 }
 
+$DIVISIONS = $DB->GetAllByKey('SELECT * FROM divisions', 'id');
+										
 $count = (strstr($which, '+') ? sizeof($ids)*2 : sizeof($ids));
 $i=0;
 
@@ -137,6 +139,18 @@ foreach($ids as $idx => $invoiceid)
 {
     $invoice = $LMS->GetInvoiceContent($invoiceid);
     $invoice['t_number'] = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
+
+    if($invoice['divisionid'] && isset($DIVISIONS[$invoice['divisionid']]))
+    {
+	$_NAME = $DIVISIONS[$invoice['divisionid']]['name'];
+	$_SHORT_NAME = $DIVISIONS[$invoice['divisionid']]['shortname'];
+	$_ADDRESS = $DIVISIONS[$invoice['divisionid']]['address'];
+	$_ZIP = $DIVISIONS[$invoice['divisionid']]['zip'];
+	$_CITY = $DIVISIONS[$invoice['divisionid']]['city'];
+    }
+    else
+	$_NAME = $_SHORT_NAME = $_ADDRESS = $_ZIP = $_CITY = '';
+
     main_fill(177,12,0.395);
     main_fill(177,313,0.396);
     simple_fill_mip(5,12,0.395);
