@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.10.2 Roham
+ * LMS version 1.11.7 Bastet
  *
- *  (C) Copyright 2001-2007 LMS Developers
+ *  (C) Copyright 2001-2009 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: transferforms2.php,v 1.14.2.2 2007/08/22 14:05:06 alec Exp $
+ *  $Id: transferforms2.php,v 1.21 2009/01/13 07:45:55 alec Exp $
  */
 
 // Przygotowane dla drukw firmy Michalczyk i Prokop Sp. z o.o.
@@ -50,7 +50,7 @@ function truncate($str, $max=60)
 function main_form($x, $y, $data)
 {
     global $pdf;
-    global $_NAME, $_ADDRESS, $_ZIP, $_CITY, $_ACCOUNT, $_TITLE, $_LMARGIN, $_BMARGIN;
+    global $_TITLE, $_LMARGIN, $_BMARGIN;
     
     $balance = $data['balance'] < 0 ? -$data['balance'] : $data['balance'];
 
@@ -60,15 +60,15 @@ function main_form($x, $y, $data)
     $y += $_BMARGIN;
 
     $y += 275;
-    $pdf->addtext($x,$y,$font_size,iconv('UTF-8', 'ISO-8859-2',$_NAME));
+    $pdf->addtext($x,$y,$font_size,iconv('UTF-8', 'ISO-8859-2',$data['d_name']));
     $y -= $lineh;
-    $pdf->addtext($x,$y,$font_size,iconv('UTF-8', 'ISO-8859-2',trim($_ZIP.' '.$_CITY.' '.$_ADDRESS)));
+    $pdf->addtext($x,$y,$font_size,iconv('UTF-8', 'ISO-8859-2',trim($data['d_zip'].' '.$data['d_city'].' '.$data['d_address'])));
     $y -= $lineh;
 //    for($i=0; $i<26; $i++)
 //    {
 //	    $pdf->addtext($x+$i*14.6,$y,$font_size,$_ACCOUNT[$i]);
 //    }
-    $pdf->addtext($x,$y,$font_size,$_ACCOUNT);
+    $pdf->addtext($x,$y,$font_size, bankaccount($data['id']);
     $y -= $lineh;
     $pdf->addtext($x+220,$y,$font_size,sprintf('%.2f',$balance));
     $y -= $lineh;
@@ -86,15 +86,21 @@ function main_form($x, $y, $data)
 $balance = $_POST['balance'] ? $_POST['balance'] : 0;
 $customer = isset($_POST['customer']) ? intval($_POST['customer']) : 0;
 $group = isset($_POST['customergroup']) ? intval($_POST['customergroup']) : 0;
+$exclgroup = isset($_POST['groupexclude']) ? 1 : 0;
 
-$list = $DB->GetAll('SELECT c.id AS id, address, zip, city, '
+$list = $DB->GetAll('SELECT c.id, c.address, c.zip, c.city, 
+	d.name AS d_name, d.address AS d_address, d.zip AS d_zip, d.city AS d_city, '
 	.$DB->Concat('UPPER(lastname)',"' '",'c.name').' AS customername,   
 	COALESCE(SUM(value), 0.00) AS balance
-	FROM customersview c LEFT JOIN cash ON (c.id=cash.customerid) '
-	.($group ? 'LEFT JOIN customerassignments ON (c.id=customerassignments.customerid)' : '')
-	.'WHERE deleted = 0'
-	.($customer ? ' AND c.id='.$customer : '')
-	.($group ? ' AND customergroupid='.$group : '')
+	FROM customersview c 
+	LEFT JOIN cash ON (c.id = cash.customerid)
+	LEFT JOIN divisions d ON (d.id = c.divisionid)
+	WHERE deleted = 0'
+	.($customer ? ' AND c.id = '.$customer : '')
+	.($group ?
+        ' AND '.($exclgroup ? 'NOT' : '').'
+	        EXISTS (SELECT 1 FROM customerassignments a
+		WHERE a.customergroupid = '.$group.' AND a.customerid = c.id)' : '')						
 	.' GROUP BY c.id, lastname, c.name, address, zip, city
 	HAVING COALESCE(SUM(value), 0.00) < ? ORDER BY c.id',
 	array(str_replace(',','.',$balance)));
@@ -105,12 +111,7 @@ if(!$list)
     die;
 }
 
-$_NAME = (!isset($CONFIG['finances']['name']) ? trans("Not set") : $CONFIG['finances']['name']);
-$_ADDRESS = (!isset($CONFIG['finances']['address']) ? trans("Not set") : $CONFIG['finances']['address']);
-$_ZIP = (!isset($CONFIG['finances']['zip']) ? trans("Not set") : $CONFIG['finances']['zip']);
-$_CITY = (!isset($CONFIG['finances']['city']) ? trans("Not set") : $CONFIG['finances']['city']);
-$_ACCOUNT = (!isset($CONFIG['finances']['account']) ? '00000000000000000000000000' : $CONFIG['finances']['account']);
-$_TITLE = (!isset($CONFIG['finances']['pay_title']) ? trans("Not set") : $CONFIG['finances']['pay_title']);
+$_TITLE = (!isset($CONFIG['finances']['pay_title']) ? trans('Not set') : $CONFIG['finances']['pay_title']);
 $_LMARGIN = (!isset($CONFIG['finances']['leftmargin']) ? 0 : $CONFIG['finances']['leftmargin']);
 $_BMARGIN = (!isset($CONFIG['finances']['bottommargin']) ? 0 : $CONFIG['finances']['bottommargin']);
 
